# Code generated by lark_sdk_gen. DO NOT EDIT.

"""Feishu/Lark Open API Python Sdk, Support ALL Open API and Event Callback."""
from pylark.api_service_acs import LarkACSService
from pylark.api_service_acs_access_record_list import (
    GetACSAccessRecordListReqUserIDType,
    GetACSAccessRecordListReq,
    GetACSAccessRecordListRespItem,
    GetACSAccessRecordListResp,
)
from pylark.api_service_acs_access_record_photo_get import (
    GetACSAccessRecordPhotoReq,
    GetACSAccessRecordPhotoRespFile,
    GetACSAccessRecordPhotoResp,
    GetACSAccessRecordPhotoResp,
)
from pylark.api_service_acs_device_list import (
    GetACSDeviceListReq,
    GetACSDeviceListRespItem,
    GetACSDeviceListResp,
)
from pylark.api_service_acs_user_face_get import (
    GetACSUserFaceReqUserIDType,
    GetACSUserFaceReq,
    GetACSUserFaceRespFile,
    GetACSUserFaceResp,
    GetACSUserFaceResp,
)
from pylark.api_service_acs_user_face_update import (
    UpdateACSUserFaceReqFileType,
    UpdateACSUserFaceReqFiles,
    UpdateACSUserFaceReqUserIDType,
    UpdateACSUserFaceReq,
    UpdateACSUserFaceResp,
)
from pylark.api_service_acs_user_get import (
    GetACSUserReqUserIDType,
    GetACSUserReq,
    GetACSUserRespUserFeature,
    GetACSUserRespUser,
    GetACSUserResp,
)
from pylark.api_service_acs_user_list import (
    GetACSUserListReqUserIDType,
    GetACSUserListReq,
    GetACSUserListRespItemFeature,
    GetACSUserListRespItem,
    GetACSUserListResp,
)
from pylark.api_service_acs_user_update import (
    UpdateACSUserReqFeature,
    UpdateACSUserReqUserIDType,
    UpdateACSUserReq,
    UpdateACSUserResp,
)
from pylark.api_service_admin import LarkAdminService
from pylark.api_service_admin_admin_dept_stats_get import (
    GetAdminDeptStatsReqDepartmentIDType,
    GetAdminDeptStatsReq,
    GetAdminDeptStatsRespItem,
    GetAdminDeptStatsResp,
)
from pylark.api_service_admin_admin_user_stats_get import (
    GetAdminUserStatsReqDepartmentIDType,
    GetAdminUserStatsReqUserIDType,
    GetAdminUserStatsReq,
    GetAdminUserStatsRespItem,
    GetAdminUserStatsResp,
)
from pylark.api_service_ai import LarkAIService
from pylark.api_service_ai_detect_face_attributes import (
    DetectFaceAttributesReq,
    DetectFaceAttributesRespFaceInfoQualityOccludeRightEye,
    DetectFaceAttributesRespFaceInfoQualityOccludeLeftEye,
    DetectFaceAttributesRespFaceInfoQualityOccludeChin,
    DetectFaceAttributesRespFaceInfoQualityOccludeMouth,
    DetectFaceAttributesRespFaceInfoQualityOccludeCheek,
    DetectFaceAttributesRespFaceInfoQualityOccludeNose,
    DetectFaceAttributesRespFaceInfoQualityOccludeEyebrow,
    DetectFaceAttributesRespFaceInfoQualityOcclude,
    DetectFaceAttributesRespFaceInfoQualityBrightness,
    DetectFaceAttributesRespFaceInfoQualitySharpness,
    DetectFaceAttributesRespFaceInfoQuality,
    DetectFaceAttributesRespFaceInfoAttributeMaskProbability,
    DetectFaceAttributesRespFaceInfoAttributeMask,
    DetectFaceAttributesRespFaceInfoAttributeGlassProbability,
    DetectFaceAttributesRespFaceInfoAttributeGlass,
    DetectFaceAttributesRespFaceInfoAttributeHatProbability,
    DetectFaceAttributesRespFaceInfoAttributeHat,
    DetectFaceAttributesRespFaceInfoAttributePose,
    DetectFaceAttributesRespFaceInfoAttributeEmotionProbability,
    DetectFaceAttributesRespFaceInfoAttributeEmotion,
    DetectFaceAttributesRespFaceInfoAttributeGenderProbability,
    DetectFaceAttributesRespFaceInfoAttributeGender,
    DetectFaceAttributesRespFaceInfoAttribute,
    DetectFaceAttributesRespFaceInfoPositionLowerRightY,
    DetectFaceAttributesRespFaceInfoPositionLowerRightX,
    DetectFaceAttributesRespFaceInfoPositionLowerRight,
    DetectFaceAttributesRespFaceInfoPositionUpperLeftY,
    DetectFaceAttributesRespFaceInfoPositionUpperLeftX,
    DetectFaceAttributesRespFaceInfoPositionUpperLeft,
    DetectFaceAttributesRespFaceInfoPosition,
    DetectFaceAttributesRespFaceInfo,
    DetectFaceAttributesRespImageInfo,
    DetectFaceAttributesResp,
)
from pylark.api_service_ai_detect_text_language import (
    DetectTextLanguageReq,
    DetectTextLanguageResp,
)
from pylark.api_service_ai_recognize_basic_image import (
    RecognizeBasicImageReq,
    RecognizeBasicImageResp,
)
from pylark.api_service_ai_recognize_speech_file import (
    RecognizeSpeechFileReqConfig,
    RecognizeSpeechFileReqSpeech,
    RecognizeSpeechFileReq,
    RecognizeSpeechFileResp,
)
from pylark.api_service_ai_recognize_speech_stream import (
    RecognizeSpeechStreamReqConfig,
    RecognizeSpeechStreamReqSpeech,
    RecognizeSpeechStreamReq,
    RecognizeSpeechStreamResp,
)
from pylark.api_service_ai_translate_text import (
    TranslateTextReqGlossary,
    TranslateTextReq,
    TranslateTextResp,
)
from pylark.api_service_application import LarkApplicationService
from pylark.api_service_application_app_admin_user_list import (
    GetApplicationAppAdminUserListReq,
    GetApplicationAppAdminUserListRespUserOpenID,
    GetApplicationAppAdminUserListRespUser,
    GetApplicationAppAdminUserListResp,
)
from pylark.api_service_application_app_list import (
    GetApplicationAppListReq,
    GetApplicationAppListRespAppList,
    GetApplicationAppListResp,
)
from pylark.api_service_application_app_visibility_get import (
    GetApplicationAppVisibilityReq,
    GetApplicationAppVisibilityRespUsers,
    GetApplicationAppVisibilityRespDepartments,
    GetApplicationAppVisibilityResp,
)
from pylark.api_service_application_app_visibility_update import (
    UpdateApplicationAppVisibilityReqAddUsers,
    UpdateApplicationAppVisibilityReqDelUsers,
    UpdateApplicationAppVisibilityReq,
    UpdateApplicationAppVisibilityResp,
)
from pylark.api_service_application_is_user_admin import (
    IsApplicationUserAdminReq,
    IsApplicationUserAdminResp,
)
from pylark.api_service_application_message_detail import (
    GetApplicationMessageDetailReq,
    GetApplicationMessageDetailRespUsersRead,
    GetApplicationMessageDetailRespTarget,
    GetApplicationMessageDetailRespMessageType,
    GetApplicationMessageDetailRespChatType,
    GetApplicationMessageDetailResp,
)
from pylark.api_service_application_message_overview import (
    GetApplicationMessageOverviewReqMessageType,
    GetApplicationMessageOverviewReqChatType,
    GetApplicationMessageOverviewReq,
    GetApplicationMessageOverviewRespGroupReadPv,
    GetApplicationMessageOverviewRespGroupRead,
    GetApplicationMessageOverviewRespGroupReceivedPv,
    GetApplicationMessageOverviewRespGroupReceived,
    GetApplicationMessageOverviewRespGroupSentPv,
    GetApplicationMessageOverviewRespGroupSent,
    GetApplicationMessageOverviewRespP2pReadPv,
    GetApplicationMessageOverviewRespP2pRead,
    GetApplicationMessageOverviewRespP2pReceivedPv,
    GetApplicationMessageOverviewRespP2pReceived,
    GetApplicationMessageOverviewRespP2pSentPv,
    GetApplicationMessageOverviewRespP2pSent,
    GetApplicationMessageOverviewResp,
)
from pylark.api_service_application_message_trend import (
    GetApplicationMessageTrendReqMessageType,
    GetApplicationMessageTrendReqChatType,
    GetApplicationMessageTrendReq,
    GetApplicationMessageTrendRespGroupReadTimestamp,
    GetApplicationMessageTrendRespGroupRead,
    GetApplicationMessageTrendRespGroupReceivedTimestamp,
    GetApplicationMessageTrendRespGroupReceived,
    GetApplicationMessageTrendRespGroupSentTimestamp,
    GetApplicationMessageTrendRespGroupSent,
    GetApplicationMessageTrendRespP2pReadTimestamp,
    GetApplicationMessageTrendRespP2pRead,
    GetApplicationMessageTrendRespP2pReceivedTimestamp,
    GetApplicationMessageTrendRespP2pReceived,
    GetApplicationMessageTrendRespP2pSentTimestamp,
    GetApplicationMessageTrendRespP2pSent,
    GetApplicationMessageTrendResp,
)
from pylark.api_service_application_order_get import (
    GetApplicationOrderReq,
    GetApplicationOrderRespOrder,
    GetApplicationOrderResp,
)
from pylark.api_service_application_order_list import (
    GetApplicationOrderListReq,
    GetApplicationOrderListRespOrderList,
    GetApplicationOrderListResp,
)
from pylark.api_service_application_paid_scope_check_user import (
    CheckUserIsInApplicationPaidScopeReq,
    CheckUserIsInApplicationPaidScopeResp,
)
from pylark.api_service_application_usage_detail import (
    GetApplicationUsageDetailReqFilter,
    GetApplicationUsageDetailReq,
    GetApplicationUsageDetailRespUser,
    GetApplicationUsageDetailResp,
)
from pylark.api_service_application_usage_overview import (
    GetApplicationUsageOverviewReqFilter,
    GetApplicationUsageOverviewReq,
    GetApplicationUsageOverviewRespItem,
    GetApplicationUsageOverviewResp,
)
from pylark.api_service_application_usage_trend import (
    GetApplicationUsageTrendReqFilter,
    GetApplicationUsageTrendReq,
    GetApplicationUsageTrendRespItemTrend,
    GetApplicationUsageTrendRespItem,
    GetApplicationUsageTrendResp,
)
from pylark.api_service_application_user_admin_scope_get import (
    GetApplicationUserAdminScopeReq,
    GetApplicationUserAdminScopeResp,
)
from pylark.api_service_application_user_visible_app_get import (
    GetApplicationUserVisibleAppReq,
    GetApplicationUserVisibleAppRespAppList,
    GetApplicationUserVisibleAppResp,
)
from pylark.api_service_approval import LarkApprovalService
from pylark.api_service_approval_approval_get import (
    GetApprovalReq,
    GetApprovalRespViewer,
    GetApprovalRespNode,
    GetApprovalRespForm,
    GetApprovalResp,
)
from pylark.api_service_approval_carbon_copy_create import (
    CreateApprovalCarbonCopyReq,
    CreateApprovalCarbonCopyResp,
)
from pylark.api_service_approval_carbon_copy_search import (
    SearchApprovalCarbonCopyReq,
    SearchApprovalCarbonCopyRespCcLink,
    SearchApprovalCarbonCopyRespCc,
    SearchApprovalCarbonCopyRespInstanceLink,
    SearchApprovalCarbonCopyRespInstance,
    SearchApprovalCarbonCopyRespGroup,
    SearchApprovalCarbonCopyRespApprovalExternal,
    SearchApprovalCarbonCopyRespApproval,
    SearchApprovalCarbonCopyResp,
    SearchApprovalCarbonCopyResp,
)
from pylark.api_service_approval_file_upload import (
    UploadApprovalFileReqContent,
    UploadApprovalFileReq,
    UploadApprovalFileResp,
)
from pylark.api_service_approval_instance_approve import (
    ApproveApprovalInstanceReq,
    ApproveApprovalInstanceResp,
)
from pylark.api_service_approval_instance_cancel import (
    CancelApprovalInstanceReq,
    CancelApprovalInstanceResp,
)
from pylark.api_service_approval_instance_create import (
    CreateApprovalInstanceReqNodeApproverOpenIDList,
    CreateApprovalInstanceReqNodeApproverUserIDList,
    CreateApprovalInstanceReqForm,
    CreateApprovalInstanceReq,
    CreateApprovalInstanceResp,
)
from pylark.api_service_approval_instance_get import (
    GetApprovalInstanceReq,
    GetApprovalInstanceRespTimelineExt,
    GetApprovalInstanceRespTimelineCcUser,
    GetApprovalInstanceRespTimeline,
    GetApprovalInstanceRespComment,
    GetApprovalInstanceRespTask,
    GetApprovalInstanceRespForm,
    GetApprovalInstanceResp,
)
from pylark.api_service_approval_instance_list import (
    GetApprovalInstanceListReq,
    GetApprovalInstanceListResp,
)
from pylark.api_service_approval_instance_reject import (
    RejectApprovalInstanceReq,
    RejectApprovalInstanceResp,
)
from pylark.api_service_approval_instance_search import (
    SearchApprovalInstanceReq,
    SearchApprovalInstanceRespInstanceInstanceLink,
    SearchApprovalInstanceRespInstanceInstance,
    SearchApprovalInstanceRespInstanceApprovalGroup,
    SearchApprovalInstanceRespInstanceApprovalExternal,
    SearchApprovalInstanceRespInstanceApproval,
    SearchApprovalInstanceRespInstance,
    SearchApprovalInstanceResp,
)
from pylark.api_service_approval_instance_transfer import (
    TransferApprovalInstanceReq,
    TransferApprovalInstanceResp,
)
from pylark.api_service_approval_task_search import (
    SearchApprovalTaskReq,
    SearchApprovalTaskRespTaskTaskLink,
    SearchApprovalTaskRespTaskTask,
    SearchApprovalTaskRespTaskInstanceLink,
    SearchApprovalTaskRespTaskInstance,
    SearchApprovalTaskRespTaskGroup,
    SearchApprovalTaskRespTaskApprovalExternal,
    SearchApprovalTaskRespTaskApproval,
    SearchApprovalTaskRespTask,
    SearchApprovalTaskResp,
)
from pylark.api_service_attendance import LarkAttendanceService
from pylark.api_service_attendance_file_download import (
    DownloadAttendanceFileReq,
    DownloadAttendanceFileRespFile,
    DownloadAttendanceFileResp,
    DownloadAttendanceFileResp,
)
from pylark.api_service_attendance_file_upload import (
    UploadAttendanceFileReqFile,
    UploadAttendanceFileReq,
    UploadAttendanceFileRespFile,
    UploadAttendanceFileResp,
)
from pylark.api_service_attendance_group_create_update import (
    CreateUpdateAttendanceGroupReqGroupNoNeedPunchSpecialDay,
    CreateUpdateAttendanceGroupReqGroupNeedPunchSpecialDay,
    CreateUpdateAttendanceGroupReqGroupFreePunchCfg,
    CreateUpdateAttendanceGroupReqGroupLocationLongitude,
    CreateUpdateAttendanceGroupReqGroupLocationLatitude,
    CreateUpdateAttendanceGroupReqGroupLocation,
    CreateUpdateAttendanceGroupReqGroupMachine,
    CreateUpdateAttendanceGroupReqGroup,
    CreateUpdateAttendanceGroupReqEmployeeType,
    CreateUpdateAttendanceGroupReq,
    CreateUpdateAttendanceGroupRespGroupNoNeedPunchSpecialDay,
    CreateUpdateAttendanceGroupRespGroupNeedPunchSpecialDay,
    CreateUpdateAttendanceGroupRespGroupFreePunchCfg,
    CreateUpdateAttendanceGroupRespGroupLocationLongitude,
    CreateUpdateAttendanceGroupRespGroupLocationLatitude,
    CreateUpdateAttendanceGroupRespGroupLocation,
    CreateUpdateAttendanceGroupRespGroupMachine,
    CreateUpdateAttendanceGroupRespGroup,
    CreateUpdateAttendanceGroupResp,
)
from pylark.api_service_attendance_group_delete import (
    DeleteAttendanceGroupReq,
    DeleteAttendanceGroupResp,
)
from pylark.api_service_attendance_group_get import (
    GetAttendanceGroupReqEmployeeType,
    GetAttendanceGroupReq,
    GetAttendanceGroupRespGroupIDNoNeedPunchSpecialDay,
    GetAttendanceGroupRespGroupIDNeedPunchSpecialDay,
    GetAttendanceGroupRespGroupIDFreePunchCfg,
    GetAttendanceGroupRespGroupIDLocationLongitude,
    GetAttendanceGroupRespGroupIDLocationLatitude,
    GetAttendanceGroupRespGroupIDLocation,
    GetAttendanceGroupRespGroupIDMachine,
    GetAttendanceGroupRespGroupID,
    GetAttendanceGroupResp,
)
from pylark.api_service_attendance_remedy_approval_init import (
    InitAttendanceRemedyApprovalReqEmployeeType,
    InitAttendanceRemedyApprovalReq,
    InitAttendanceRemedyApprovalRespUserRemedy,
    InitAttendanceRemedyApprovalResp,
)
from pylark.api_service_attendance_remedy_approval_update import (
    UpdateAttendanceRemedyApprovalReq,
    UpdateAttendanceRemedyApprovalRespApprovalInfo,
    UpdateAttendanceRemedyApprovalResp,
)
from pylark.api_service_attendance_shift_create import (
    CreateAttendanceShiftReqRestTimeRule,
    CreateAttendanceShiftReqLateOffLateOnRule,
    CreateAttendanceShiftReqPunchTimeRule,
    CreateAttendanceShiftReq,
    CreateAttendanceShiftRespShiftRestTimeRule,
    CreateAttendanceShiftRespShiftLateOffLateOnRule,
    CreateAttendanceShiftRespShiftPunchTimeRule,
    CreateAttendanceShiftRespShift,
    CreateAttendanceShiftResp,
)
from pylark.api_service_attendance_shift_delete import (
    DeleteAttendanceShiftReq,
    DeleteAttendanceShiftResp,
)
from pylark.api_service_attendance_shift_get_by_id import (
    GetAttendanceShiftByIDReq,
    GetAttendanceShiftByIDRespRestTimeRule,
    GetAttendanceShiftByIDRespLateOffLateOnRule,
    GetAttendanceShiftByIDRespPunchTimeRule,
    GetAttendanceShiftByIDResp,
)
from pylark.api_service_attendance_shift_get_by_name import (
    GetAttendanceShiftByNameReq,
    GetAttendanceShiftByNameRespRestTimeRule,
    GetAttendanceShiftByNameRespLateOffLateOnRule,
    GetAttendanceShiftByNameRespPunchTimeRule,
    GetAttendanceShiftByNameResp,
)
from pylark.api_service_attendance_statistics_data_get import (
    GetAttendanceStatisticsDataReqEmployeeType,
    GetAttendanceStatisticsDataReq,
    GetAttendanceStatisticsDataRespUserDataDataFeature,
    GetAttendanceStatisticsDataRespUserDataData,
    GetAttendanceStatisticsDataRespUserData,
    GetAttendanceStatisticsDataResp,
)
from pylark.api_service_attendance_statistics_header_get import (
    GetAttendanceStatisticsHeaderReqEmployeeType,
    GetAttendanceStatisticsHeaderReq,
    GetAttendanceStatisticsHeaderRespUserStatsFieldFieldChildField,
    GetAttendanceStatisticsHeaderRespUserStatsFieldField,
    GetAttendanceStatisticsHeaderRespUserStatsField,
    GetAttendanceStatisticsHeaderResp,
)
from pylark.api_service_attendance_user_allowed_remedy_get import (
    GetAttendanceUserAllowedRemedyReqEmployeeType,
    GetAttendanceUserAllowedRemedyReq,
    GetAttendanceUserAllowedRemedyRespUserAllowedRemedys,
    GetAttendanceUserAllowedRemedyResp,
)
from pylark.api_service_attendance_user_approval_create import (
    CreateAttendanceUserApprovalReqUserApprovalTrip,
    CreateAttendanceUserApprovalReqUserApprovalOvertimeWorkDuration,
    CreateAttendanceUserApprovalReqUserApprovalOvertimeWork,
    CreateAttendanceUserApprovalReqUserApprovalLeaveI18nNames,
    CreateAttendanceUserApprovalReqUserApprovalLeave,
    CreateAttendanceUserApprovalReqUserApprovalOutI18nNamesJa,
    CreateAttendanceUserApprovalReqUserApprovalOutI18nNames,
    CreateAttendanceUserApprovalReqUserApprovalOut,
    CreateAttendanceUserApprovalReqUserApproval,
    CreateAttendanceUserApprovalReqEmployeeType,
    CreateAttendanceUserApprovalReq,
    CreateAttendanceUserApprovalRespUserApprovalTrip,
    CreateAttendanceUserApprovalRespUserApprovalOvertimeWorkDuration,
    CreateAttendanceUserApprovalRespUserApprovalOvertimeWork,
    CreateAttendanceUserApprovalRespUserApprovalLeaveI18nNames,
    CreateAttendanceUserApprovalRespUserApprovalLeave,
    CreateAttendanceUserApprovalRespUserApprovalOutI18nNames,
    CreateAttendanceUserApprovalRespUserApprovalOut,
    CreateAttendanceUserApprovalRespUserApproval,
    CreateAttendanceUserApprovalResp,
)
from pylark.api_service_attendance_user_approval_get import (
    GetAttendanceUserApprovalReqEmployeeType,
    GetAttendanceUserApprovalReq,
    GetAttendanceUserApprovalRespUserApprovalTrip,
    GetAttendanceUserApprovalRespUserApprovalOvertimeWorkDuration,
    GetAttendanceUserApprovalRespUserApprovalOvertimeWork,
    GetAttendanceUserApprovalRespUserApprovalLeaveI18nNames,
    GetAttendanceUserApprovalRespUserApprovalLeave,
    GetAttendanceUserApprovalRespUserApprovalOutI18nNames,
    GetAttendanceUserApprovalRespUserApprovalOut,
    GetAttendanceUserApprovalRespUserApproval,
    GetAttendanceUserApprovalResp,
)
from pylark.api_service_attendance_user_daily_shift_create_update import (
    CreateUpdateAttendanceUserDailyShiftReqUserDailyShift,
    CreateUpdateAttendanceUserDailyShiftReqEmployeeType,
    CreateUpdateAttendanceUserDailyShiftReq,
    CreateUpdateAttendanceUserDailyShiftRespUserDailyShift,
    CreateUpdateAttendanceUserDailyShiftResp,
)
from pylark.api_service_attendance_user_daily_shift_get import (
    GetAttendanceUserDailyShiftReqEmployeeType,
    GetAttendanceUserDailyShiftReq,
    GetAttendanceUserDailyShiftRespUserDailyShift,
    GetAttendanceUserDailyShiftResp,
)
from pylark.api_service_attendance_user_flow_batch_create import (
    BatchCreateAttendanceUserFlowReqFlowRecord,
    BatchCreateAttendanceUserFlowReqEmployeeType,
    BatchCreateAttendanceUserFlowReq,
    BatchCreateAttendanceUserFlowRespFlowRecord,
    BatchCreateAttendanceUserFlowResp,
)
from pylark.api_service_attendance_user_flow_batch_get import (
    BatchGetAttendanceUserFlowReqEmployeeType,
    BatchGetAttendanceUserFlowReq,
    BatchGetAttendanceUserFlowRespUserFlowResultLatitude,
    BatchGetAttendanceUserFlowRespUserFlowResultLongitude,
    BatchGetAttendanceUserFlowRespUserFlowResult,
    BatchGetAttendanceUserFlowResp,
)
from pylark.api_service_attendance_user_flow_get import (
    GetAttendanceUserFlowReqEmployeeType,
    GetAttendanceUserFlowReq,
    GetAttendanceUserFlowRespLatitude,
    GetAttendanceUserFlowRespLongitude,
    GetAttendanceUserFlowResp,
)
from pylark.api_service_attendance_user_settings_query import (
    QueryAttendanceUserSettingsReqEmployeeType,
    QueryAttendanceUserSettingsReq,
    QueryAttendanceUserSettingsRespUserSetting,
    QueryAttendanceUserSettingsResp,
)
from pylark.api_service_attendance_user_settings_update import (
    UpdateAttendanceUserSettingsReqUserSetting,
    UpdateAttendanceUserSettingsReqEmployeeType,
    UpdateAttendanceUserSettingsReq,
    UpdateAttendanceUserSettingsRespUserSetting,
    UpdateAttendanceUserSettingsResp,
)
from pylark.api_service_attendance_user_statistics_settings_get import (
    GetAttendanceUserStatisticsSettingsReqEmployeeType,
    GetAttendanceUserStatisticsSettingsReq,
    GetAttendanceUserStatisticsSettingsRespViewItemChildItem,
    GetAttendanceUserStatisticsSettingsRespViewItem,
    GetAttendanceUserStatisticsSettingsRespView,
    GetAttendanceUserStatisticsSettingsResp,
)
from pylark.api_service_attendance_user_statistics_settings_update import (
    UpdateAttendanceUserStatisticsSettingsReqViewItemChildItem,
    UpdateAttendanceUserStatisticsSettingsReqViewItem,
    UpdateAttendanceUserStatisticsSettingsReqView,
    UpdateAttendanceUserStatisticsSettingsReqEmployeeType,
    UpdateAttendanceUserStatisticsSettingsReq,
    UpdateAttendanceUserStatisticsSettingsRespViewItemChildItem,
    UpdateAttendanceUserStatisticsSettingsRespViewItem,
    UpdateAttendanceUserStatisticsSettingsRespView,
    UpdateAttendanceUserStatisticsSettingsResp,
)
from pylark.api_service_attendance_user_task_get import (
    GetAttendanceUserTaskReqEmployeeType,
    GetAttendanceUserTaskReq,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckOutRecordLatitude,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckOutRecordLongitude,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckOutRecord,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckInRecordLatitude,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckInRecordLongitude,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckInRecord,
    GetAttendanceUserTaskRespUserTaskResultRecord,
    GetAttendanceUserTaskRespUserTaskResult,
    GetAttendanceUserTaskResp,
)
from pylark.api_service_attendance_user_task_remedy_get import (
    GetAttendanceUserTaskRemedyReqEmployeeType,
    GetAttendanceUserTaskRemedyReq,
    GetAttendanceUserTaskRemedyRespUserRemedy,
    GetAttendanceUserTaskRemedyResp,
)
from pylark.api_service_auth import LarkAuthService
from pylark.api_service_auth_access_token_get import (
    GetAccessTokenReq,
    GetAccessTokenResp,
)
from pylark.api_service_auth_access_token_refresh import (
    RefreshAccessTokenReq,
    RefreshAccessTokenResp,
)
from pylark.api_service_auth_app_ticket_resend import (
    ResendAppTicketReq,
    ResendAppTicketResp,
)
from pylark.api_service_auth_tenant_access_token_get import (
    GetTenantAccessTokenReq,
    TokenExpire,
)
from pylark.api_service_auth_user_info_get import GetUserInfoReq, GetUserInfoResp
from pylark.api_service_bitable import LarkBitableService
from pylark.api_service_bitable_field_create import (
    CreateBitableFieldReqPropertyOption,
    CreateBitableFieldReqProperty,
    CreateBitableFieldReqUserIDType,
    CreateBitableFieldReq,
    CreateBitableFieldRespFieldPropertyOption,
    CreateBitableFieldRespFieldProperty,
    CreateBitableFieldRespField,
    CreateBitableFieldResp,
)
from pylark.api_service_bitable_field_delete import (
    DeleteBitableFieldReq,
    DeleteBitableFieldResp,
)
from pylark.api_service_bitable_field_list import (
    GetBitableFieldListReq,
    GetBitableFieldListRespItemPropertyOption,
    GetBitableFieldListRespItemProperty,
    GetBitableFieldListRespItem,
    GetBitableFieldListResp,
)
from pylark.api_service_bitable_field_update import (
    UpdateBitableFieldReqPropertyOption,
    UpdateBitableFieldReqProperty,
    UpdateBitableFieldReq,
    UpdateBitableFieldRespFieldPropertyOption,
    UpdateBitableFieldRespFieldProperty,
    UpdateBitableFieldRespField,
    UpdateBitableFieldResp,
)
from pylark.api_service_bitable_meta_get import (
    GetBitableMetaReq,
    GetBitableMetaRespApp,
    GetBitableMetaResp,
)
from pylark.api_service_bitable_record_batch_create import (
    BatchCreateBitableRecordReqRecordFieldValue,
    BatchCreateBitableRecordReqRecordField,
    BatchCreateBitableRecordReqRecord,
    BatchCreateBitableRecordReqUserIDType,
    BatchCreateBitableRecordReq,
    BatchCreateBitableRecordRespRecordFieldValue,
    BatchCreateBitableRecordRespRecordField,
    BatchCreateBitableRecordRespRecord,
    BatchCreateBitableRecordResp,
)
from pylark.api_service_bitable_record_batch_delete import (
    BatchDeleteBitableRecordReq,
    BatchDeleteBitableRecordRespRecord,
    BatchDeleteBitableRecordResp,
)
from pylark.api_service_bitable_record_batch_update import (
    BatchUpdateBitableRecordReqRecordFieldValue,
    BatchUpdateBitableRecordReqRecordField,
    BatchUpdateBitableRecordReqRecord,
    BatchUpdateBitableRecordReqUserIDType,
    BatchUpdateBitableRecordReq,
    BatchUpdateBitableRecordRespRecordFieldValue,
    BatchUpdateBitableRecordRespRecordField,
    BatchUpdateBitableRecordRespRecord,
    BatchUpdateBitableRecordResp,
)
from pylark.api_service_bitable_record_create import (
    CreateBitableRecordReqFieldsValue,
    CreateBitableRecordReqFields,
    CreateBitableRecordReqUserIDType,
    CreateBitableRecordReq,
    CreateBitableRecordRespRecordFieldsValue,
    CreateBitableRecordRespRecordFields,
    CreateBitableRecordRespRecord,
    CreateBitableRecordResp,
)
from pylark.api_service_bitable_record_delete import (
    DeleteBitableRecordReq,
    DeleteBitableRecordResp,
)
from pylark.api_service_bitable_record_get import (
    GetBitableRecordReq,
    GetBitableRecordRespRecordFieldsValue,
    GetBitableRecordRespRecordFields,
    GetBitableRecordRespRecord,
    GetBitableRecordResp,
)
from pylark.api_service_bitable_record_list import (
    GetBitableRecordListReq,
    GetBitableRecordListRespItemFieldsValue,
    GetBitableRecordListRespItemFields,
    GetBitableRecordListRespItem,
    GetBitableRecordListResp,
)
from pylark.api_service_bitable_record_update import (
    UpdateBitableRecordReqFieldsValue,
    UpdateBitableRecordReqFields,
    UpdateBitableRecordReqUserIDType,
    UpdateBitableRecordReq,
    UpdateBitableRecordRespRecordFieldsValue,
    UpdateBitableRecordRespRecordFields,
    UpdateBitableRecordRespRecord,
    UpdateBitableRecordResp,
)
from pylark.api_service_bitable_table_batch_create import (
    BatchCreateBitableTableReqTable,
    BatchCreateBitableTableReqUserIDType,
    BatchCreateBitableTableReq,
    BatchCreateBitableTableResp,
)
from pylark.api_service_bitable_table_batch_delete import (
    BatchDeleteBitableTableReq,
    BatchDeleteBitableTableResp,
)
from pylark.api_service_bitable_table_create import (
    CreateBitableTableReqTable,
    CreateBitableTableReqUserIDType,
    CreateBitableTableReq,
    CreateBitableTableResp,
)
from pylark.api_service_bitable_table_delete import (
    DeleteBitableTableReq,
    DeleteBitableTableResp,
)
from pylark.api_service_bitable_table_list import (
    GetBitableTableListReq,
    GetBitableTableListRespItem,
    GetBitableTableListResp,
)
from pylark.api_service_bitable_view_create import (
    CreateBitableViewReq,
    CreateBitableViewRespApptableview,
    CreateBitableViewResp,
)
from pylark.api_service_bitable_view_delete import (
    DeleteBitableViewReq,
    DeleteBitableViewResp,
)
from pylark.api_service_bitable_view_list import (
    GetBitableViewListReq,
    GetBitableViewListRespItem,
    GetBitableViewListResp,
)
from pylark.api_service_bot import LarkBotService
from pylark.api_service_bot_add import AddBotToChatReq, AddBotToChatResp
from pylark.api_service_bot_info import GetBotInfoReq, GetBotInfoResp
from pylark.api_service_calendar import LarkCalendarService
from pylark.api_service_calendar_acl_create import (
    CreateCalendarACLReqScope,
    CreateCalendarACLReqRole,
    CreateCalendarACLReqUserIDType,
    CreateCalendarACLReq,
    CreateCalendarACLRespScope,
    CreateCalendarACLRespRole,
    CreateCalendarACLResp,
)
from pylark.api_service_calendar_acl_delete import (
    DeleteCalendarACLReq,
    DeleteCalendarACLResp,
)
from pylark.api_service_calendar_acl_get_list import (
    GetCalendarACLListReqUserIDType,
    GetCalendarACLListReq,
    GetCalendarACLListRespACLScope,
    GetCalendarACLListRespACLRole,
    GetCalendarACLListRespACL,
    GetCalendarACLListResp,
)
from pylark.api_service_calendar_acl_subscribe import (
    SubscribeCalendarACLReq,
    SubscribeCalendarACLResp,
)
from pylark.api_service_calendar_calendar_create import (
    CreateCalendarReqPermissions,
    CreateCalendarReq,
    CreateCalendarRespCalendarRole,
    CreateCalendarRespCalendarType,
    CreateCalendarRespCalendarPermissions,
    CreateCalendarRespCalendar,
    CreateCalendarResp,
)
from pylark.api_service_calendar_calendar_delete import (
    DeleteCalendarReq,
    DeleteCalendarResp,
)
from pylark.api_service_calendar_calendar_event_attendee_chat_member_list import (
    GetCalendarEventAttendeeChatMemberListReq,
    GetCalendarEventAttendeeChatMemberListRespItem,
    GetCalendarEventAttendeeChatMemberListResp,
)
from pylark.api_service_calendar_calendar_event_attendee_create import (
    CreateCalendarEventAttendeeReqAttendeeType,
    CreateCalendarEventAttendeeReqAttendee,
    CreateCalendarEventAttendeeReqUserIDType,
    CreateCalendarEventAttendeeReq,
    CreateCalendarEventAttendeeRespAttendeeChatMember,
    CreateCalendarEventAttendeeRespAttendeeType,
    CreateCalendarEventAttendeeRespAttendee,
    CreateCalendarEventAttendeeResp,
)
from pylark.api_service_calendar_calendar_event_attendee_delete import (
    DeleteCalendarEventAttendeeReq,
    DeleteCalendarEventAttendeeResp,
)
from pylark.api_service_calendar_calendar_event_attendee_get_list import (
    GetCalendarEventAttendeeListReqUserIDType,
    GetCalendarEventAttendeeListReq,
    GetCalendarEventAttendeeListRespItemChatMember,
    GetCalendarEventAttendeeListRespItemType,
    GetCalendarEventAttendeeListRespItem,
    GetCalendarEventAttendeeListResp,
)
from pylark.api_service_calendar_calendar_event_create import (
    CreateCalendarEventReqSchema,
    CreateCalendarEventReqReminder,
    CreateCalendarEventReqLocationLongitude,
    CreateCalendarEventReqLocationLatitude,
    CreateCalendarEventReqLocation,
    CreateCalendarEventReqVchat,
    CreateCalendarEventReqEndTime,
    CreateCalendarEventReqStartTime,
    CreateCalendarEventReq,
    CreateCalendarEventRespEventSchema,
    CreateCalendarEventRespEventReminder,
    CreateCalendarEventRespEventLocationLongitude,
    CreateCalendarEventRespEventLocationLatitude,
    CreateCalendarEventRespEventLocation,
    CreateCalendarEventRespEventVchat,
    CreateCalendarEventRespEventEndTime,
    CreateCalendarEventRespEventStartTime,
    CreateCalendarEventRespEvent,
    CreateCalendarEventResp,
)
from pylark.api_service_calendar_calendar_event_delete import (
    DeleteCalendarEventReq,
    DeleteCalendarEventResp,
)
from pylark.api_service_calendar_calendar_event_get import (
    GetCalendarEventReq,
    GetCalendarEventRespEventSchema,
    GetCalendarEventRespEventReminder,
    GetCalendarEventRespEventLocationLongitude,
    GetCalendarEventRespEventLocationLatitude,
    GetCalendarEventRespEventLocation,
    GetCalendarEventRespEventVchat,
    GetCalendarEventRespEventEndTime,
    GetCalendarEventRespEventStartTime,
    GetCalendarEventRespEvent,
    GetCalendarEventResp,
)
from pylark.api_service_calendar_calendar_event_get_list import (
    GetCalendarEventListReq,
    GetCalendarEventListRespItemSchema,
    GetCalendarEventListRespItemReminder,
    GetCalendarEventListRespItemLocationLongitude,
    GetCalendarEventListRespItemLocationLatitude,
    GetCalendarEventListRespItemLocation,
    GetCalendarEventListRespItemVchat,
    GetCalendarEventListRespItemEndTime,
    GetCalendarEventListRespItemStartTime,
    GetCalendarEventListRespItem,
    GetCalendarEventListResp,
)
from pylark.api_service_calendar_calendar_event_patch import (
    UpdateCalendarEventReqSchema,
    UpdateCalendarEventReqReminder,
    UpdateCalendarEventReqLocationLongitude,
    UpdateCalendarEventReqLocationLatitude,
    UpdateCalendarEventReqLocation,
    UpdateCalendarEventReqVchat,
    UpdateCalendarEventReqEndTime,
    UpdateCalendarEventReqStartTime,
    UpdateCalendarEventReq,
    UpdateCalendarEventRespEventSchema,
    UpdateCalendarEventRespEventReminder,
    UpdateCalendarEventRespEventLocationLongitude,
    UpdateCalendarEventRespEventLocationLatitude,
    UpdateCalendarEventRespEventLocation,
    UpdateCalendarEventRespEventVchat,
    UpdateCalendarEventRespEventEndTime,
    UpdateCalendarEventRespEventStartTime,
    UpdateCalendarEventRespEvent,
    UpdateCalendarEventResp,
)
from pylark.api_service_calendar_calendar_event_search import (
    SearchCalendarEventReqFilterEndTime,
    SearchCalendarEventReqFilterStartTime,
    SearchCalendarEventReqFilter,
    SearchCalendarEventReqUserIDType,
    SearchCalendarEventReq,
    SearchCalendarEventRespItemSchema,
    SearchCalendarEventRespItemReminder,
    SearchCalendarEventRespItemLocationLongitude,
    SearchCalendarEventRespItemLocationLatitude,
    SearchCalendarEventRespItemLocation,
    SearchCalendarEventRespItemVchat,
    SearchCalendarEventRespItemEndTime,
    SearchCalendarEventRespItemStartTime,
    SearchCalendarEventRespItem,
    SearchCalendarEventResp,
)
from pylark.api_service_calendar_calendar_event_subscribe import (
    SubscribeCalendarEventReq,
    SubscribeCalendarEventResp,
)
from pylark.api_service_calendar_calendar_freebusy_get_list import (
    GetCalendarFreeBusyListReqUserIDType,
    GetCalendarFreeBusyListReq,
    GetCalendarFreeBusyListRespFreebusy,
    GetCalendarFreeBusyListResp,
)
from pylark.api_service_calendar_calendar_get import (
    GetCalendarReq,
    GetCalendarRespRole,
    GetCalendarRespType,
    GetCalendarRespPermissions,
    GetCalendarResp,
)
from pylark.api_service_calendar_calendar_get_list import (
    GetCalendarListReq,
    GetCalendarListRespCalendarRole,
    GetCalendarListRespCalendarType,
    GetCalendarListRespCalendarPermissions,
    GetCalendarListRespCalendar,
    GetCalendarListResp,
)
from pylark.api_service_calendar_calendar_patch import (
    UpdateCalendarReqPermissions,
    UpdateCalendarReq,
    UpdateCalendarRespCalendarRole,
    UpdateCalendarRespCalendarType,
    UpdateCalendarRespCalendarPermissions,
    UpdateCalendarRespCalendar,
    UpdateCalendarResp,
)
from pylark.api_service_calendar_calendar_search import (
    SearchCalendarReq,
    SearchCalendarRespItemRole,
    SearchCalendarRespItemType,
    SearchCalendarRespItemPermissions,
    SearchCalendarRespItem,
    SearchCalendarResp,
)
from pylark.api_service_calendar_calendar_subscribe import (
    SubscribeCalendarReq,
    SubscribeCalendarRespCalendarRole,
    SubscribeCalendarRespCalendarType,
    SubscribeCalendarRespCalendarPermissions,
    SubscribeCalendarRespCalendar,
    SubscribeCalendarResp,
)
from pylark.api_service_calendar_calendar_subscription import (
    SubscribeCalendarChangeEventReq,
    SubscribeCalendarChangeEventResp,
)
from pylark.api_service_calendar_calendar_timeoff_event_create import (
    CreateCalendarTimeoffEventReqUserIDType,
    CreateCalendarTimeoffEventReq,
    CreateCalendarTimeoffEventResp,
)
from pylark.api_service_calendar_calendar_timeoff_event_delete import (
    DeleteCalendarTimeoffEventReq,
    DeleteCalendarTimeoffEventResp,
)
from pylark.api_service_calendar_calendar_unsubscribe import (
    UnsubscribeCalendarReq,
    UnsubscribeCalendarResp,
)
from pylark.api_service_calendar_generate_caldav_conf import (
    GenerateCaldavConfReq,
    GenerateCaldavConfResp,
)
from pylark.api_service_chat import LarkChatService
from pylark.api_service_chat_announcement_get import (
    GetChatAnnouncementReqUserIDType,
    GetChatAnnouncementReq,
    GetChatAnnouncementRespModifierIDType,
    GetChatAnnouncementRespOwnerIDType,
    GetChatAnnouncementResp,
)
from pylark.api_service_chat_announcement_update import (
    UpdateChatAnnouncementReq,
    UpdateChatAnnouncementResp,
)
from pylark.api_service_chat_create import (
    CreateChatReqMembershipApproval,
    CreateChatReqLeaveMessageVisibility,
    CreateChatReqJoinMessageVisibility,
    CreateChatReqChatType,
    CreateChatReqI18nNames,
    CreateChatReq,
    CreateChatRespModerationPermission,
    CreateChatRespMembershipApproval,
    CreateChatRespLeaveMessageVisibility,
    CreateChatRespJoinMessageVisibility,
    CreateChatRespChatType,
    CreateChatRespEditPermission,
    CreateChatRespAtAllPermission,
    CreateChatRespShareCardPermission,
    CreateChatRespAddMemberPermission,
    CreateChatRespI18nNames,
    CreateChatResp,
)
from pylark.api_service_chat_delete import DeleteChatReq, DeleteChatResp
from pylark.api_service_chat_get import (
    GetChatReqUserIDType,
    GetChatReq,
    GetChatRespModerationPermission,
    GetChatRespMembershipApproval,
    GetChatRespLeaveMessageVisibility,
    GetChatRespJoinMessageVisibility,
    GetChatRespChatType,
    GetChatRespOwnerIDType,
    GetChatRespEditPermission,
    GetChatRespAtAllPermission,
    GetChatRespShareCardPermission,
    GetChatRespAddMemberPermission,
    GetChatRespI18nNames,
    GetChatResp,
)
from pylark.api_service_chat_get_list_of_self import (
    GetChatListOfSelfReqUserIDType,
    GetChatListOfSelfReq,
    GetChatListOfSelfRespItemOwnerIDType,
    GetChatListOfSelfRespItem,
    GetChatListOfSelfResp,
)
from pylark.api_service_chat_join import JoinChatReq, JoinChatResp
from pylark.api_service_chat_member_add import (
    AddChatMemberReqMemberIDType,
    AddChatMemberReq,
    AddChatMemberResp,
)
from pylark.api_service_chat_member_delete import (
    DeleteChatMemberReqMemberIDType,
    DeleteChatMemberReq,
    DeleteChatMemberResp,
)
from pylark.api_service_chat_member_get_list import (
    GetChatMemberListReqMemberIDType,
    GetChatMemberListReq,
    GetChatMemberListRespItemMemberIDType,
    GetChatMemberListRespItem,
    GetChatMemberListResp,
)
from pylark.api_service_chat_member_in import IsInChatReq, IsInChatResp
from pylark.api_service_chat_search import (
    SearchChatReqUserIDType,
    SearchChatReq,
    SearchChatRespItemOwnerIDType,
    SearchChatRespItem,
    SearchChatResp,
)
from pylark.api_service_chat_update import (
    UpdateChatReqMembershipApproval,
    UpdateChatReqLeaveMessageVisibility,
    UpdateChatReqJoinMessageVisibility,
    UpdateChatReqEditPermission,
    UpdateChatReqAtAllPermission,
    UpdateChatReqShareCardPermission,
    UpdateChatReqAddMemberPermission,
    UpdateChatReqI18nNames,
    UpdateChatReqUserIDType,
    UpdateChatReq,
    UpdateChatResp,
)
from pylark.api_service_contact import LarkContactService
from pylark.api_service_contact_custom_attr_list import (
    GetContactCustomAttrListReq,
    GetContactCustomAttrListRespItemI18nName,
    GetContactCustomAttrListRespItemOptionsOption,
    GetContactCustomAttrListRespItemOptions,
    GetContactCustomAttrListRespItem,
    GetContactCustomAttrListResp,
)
from pylark.api_service_contact_department_create import (
    CreateDepartmentReqI18nName,
    CreateDepartmentReqDepartmentIDType,
    CreateDepartmentReqUserIDType,
    CreateDepartmentReq,
    CreateDepartmentRespDepartmentStatus,
    CreateDepartmentRespDepartmentI18nName,
    CreateDepartmentRespDepartment,
    CreateDepartmentResp,
)
from pylark.api_service_contact_department_delete import (
    DeleteDepartmentReqDepartmentIDType,
    DeleteDepartmentReq,
    DeleteDepartmentResp,
)
from pylark.api_service_contact_department_get import (
    GetDepartmentReqDepartmentIDType,
    GetDepartmentReqUserIDType,
    GetDepartmentReq,
    GetDepartmentRespDepartmentStatus,
    GetDepartmentRespDepartmentI18nName,
    GetDepartmentRespDepartment,
    GetDepartmentResp,
)
from pylark.api_service_contact_department_get_list import (
    GetDepartmentListReqDepartmentIDType,
    GetDepartmentListReqUserIDType,
    GetDepartmentListReq,
    GetDepartmentListRespItemStatus,
    GetDepartmentListRespItemI18nName,
    GetDepartmentListRespItem,
    GetDepartmentListResp,
)
from pylark.api_service_contact_department_get_parent import (
    GetParentDepartmentReqDepartmentIDType,
    GetParentDepartmentReqUserIDType,
    GetParentDepartmentReq,
    GetParentDepartmentRespItemStatus,
    GetParentDepartmentRespItemI18nName,
    GetParentDepartmentRespItem,
    GetParentDepartmentResp,
)
from pylark.api_service_contact_department_search import (
    SearchDepartmentReqDepartmentIDType,
    SearchDepartmentReqUserIDType,
    SearchDepartmentReq,
    SearchDepartmentRespItemStatus,
    SearchDepartmentRespItemI18nName,
    SearchDepartmentRespItem,
    SearchDepartmentResp,
)
from pylark.api_service_contact_department_update import (
    UpdateDepartmentReqI18nName,
    UpdateDepartmentReqDepartmentIDType,
    UpdateDepartmentReqUserIDType,
    UpdateDepartmentReq,
    UpdateDepartmentRespDepartmentStatus,
    UpdateDepartmentRespDepartmentI18nName,
    UpdateDepartmentRespDepartment,
    UpdateDepartmentResp,
)
from pylark.api_service_contact_department_update_patch import (
    UpdateDepartmentPatchReqI18nName,
    UpdateDepartmentPatchReqDepartmentIDType,
    UpdateDepartmentPatchReqUserIDType,
    UpdateDepartmentPatchReq,
    UpdateDepartmentPatchRespDepartmentStatus,
    UpdateDepartmentPatchRespDepartmentI18nName,
    UpdateDepartmentPatchRespDepartment,
    UpdateDepartmentPatchResp,
)
from pylark.api_service_contact_employee_type_enums_create import (
    CreateEmployeeTypeEnumReqI18nContent,
    CreateEmployeeTypeEnumReq,
    CreateEmployeeTypeEnumRespEmployeeTypeEnumI18nContent,
    CreateEmployeeTypeEnumRespEmployeeTypeEnum,
    CreateEmployeeTypeEnumResp,
)
from pylark.api_service_contact_employee_type_enums_delete import (
    DeleteEmployeeTypeEnumReq,
    DeleteEmployeeTypeEnumResp,
)
from pylark.api_service_contact_employee_type_enums_list import (
    GetEmployeeTypeEnumListReq,
    GetEmployeeTypeEnumListRespItemI18nContent,
    GetEmployeeTypeEnumListRespItem,
    GetEmployeeTypeEnumListResp,
)
from pylark.api_service_contact_employee_type_enums_update import (
    UpdateEmployeeTypeEnumPatchReqI18nContent,
    UpdateEmployeeTypeEnumPatchReq,
    UpdateEmployeeTypeEnumPatchRespEmployeeTypeEnumI18nContent,
    UpdateEmployeeTypeEnumPatchRespEmployeeTypeEnum,
    UpdateEmployeeTypeEnumPatchResp,
)
from pylark.api_service_contact_user_create import (
    CreateUserReqNotificationOption,
    CreateUserReqCustomAttrValueGenericUser,
    CreateUserReqCustomAttrValue,
    CreateUserReqCustomAttr,
    CreateUserReqOrder,
    CreateUserReqDepartmentIDType,
    CreateUserReqUserIDType,
    CreateUserReq,
    CreateUserRespUserNotificationOption,
    CreateUserRespUserCustomAttrValueGenericUser,
    CreateUserRespUserCustomAttrValue,
    CreateUserRespUserCustomAttr,
    CreateUserRespUserOrder,
    CreateUserRespUserStatus,
    CreateUserRespUserAvatar,
    CreateUserRespUser,
    CreateUserResp,
)
from pylark.api_service_contact_user_delete import (
    DeleteUserReqUserIDType,
    DeleteUserReq,
    DeleteUserResp,
)
from pylark.api_service_contact_user_get import (
    GetUserReqDepartmentIDType,
    GetUserReqUserIDType,
    GetUserReq,
    GetUserRespUserCustomAttrValueGenericUser,
    GetUserRespUserCustomAttrValue,
    GetUserRespUserCustomAttr,
    GetUserRespUserOrder,
    GetUserRespUserStatus,
    GetUserRespUserAvatar,
    GetUserRespUser,
    GetUserResp,
)
from pylark.api_service_contact_user_get_batch import (
    BatchGetUserReq,
    BatchGetUserRespUserInfoCustomAttr,
    BatchGetUserRespUserInfo,
    BatchGetUserResp,
)
from pylark.api_service_contact_user_get_batch_by_id import (
    BatchGetUserByIDReq,
    BatchGetUserByIDRespEmailUser,
    BatchGetUserByIDRespEmailUser,
    BatchGetUserByIDResp,
)
from pylark.api_service_contact_user_get_list import (
    GetUserListReqDepartmentIDType,
    GetUserListReqUserIDType,
    GetUserListReq,
    GetUserListRespItemCustomAttrValueGenericUser,
    GetUserListRespItemCustomAttrValue,
    GetUserListRespItemCustomAttr,
    GetUserListRespItemOrder,
    GetUserListRespItemStatus,
    GetUserListRespItemAvatar,
    GetUserListRespItem,
    GetUserListResp,
)
from pylark.api_service_contact_user_update import (
    UpdateUserReqCustomAttrValueGenericUser,
    UpdateUserReqCustomAttrValue,
    UpdateUserReqCustomAttr,
    UpdateUserReqOrder,
    UpdateUserReqDepartmentIDType,
    UpdateUserReqUserIDType,
    UpdateUserReq,
    UpdateUserRespUserNotificationOption,
    UpdateUserRespUserCustomAttrValueGenericUser,
    UpdateUserRespUserCustomAttrValue,
    UpdateUserRespUserCustomAttr,
    UpdateUserRespUserOrder,
    UpdateUserRespUserStatus,
    UpdateUserRespUserAvatar,
    UpdateUserRespUser,
    UpdateUserResp,
)
from pylark.api_service_contact_user_update_patch import (
    UpdateUserPatchReqCustomAttrValueGenericUser,
    UpdateUserPatchReqCustomAttrValue,
    UpdateUserPatchReqCustomAttr,
    UpdateUserPatchReqOrder,
    UpdateUserPatchReqDepartmentIDType,
    UpdateUserPatchReqUserIDType,
    UpdateUserPatchReq,
    UpdateUserPatchRespUserNotificationOption,
    UpdateUserPatchRespUserCustomAttrValueGenericUser,
    UpdateUserPatchRespUserCustomAttrValue,
    UpdateUserPatchRespUserCustomAttr,
    UpdateUserPatchRespUserOrder,
    UpdateUserPatchRespUserStatus,
    UpdateUserPatchRespUserAvatar,
    UpdateUserPatchRespUser,
    UpdateUserPatchResp,
)
from pylark.api_service_drive import LarkDriveService
from pylark.api_service_drive_comment_create import (
    CreateDriveCommentReqReplyListReplyContentElementPerson,
    CreateDriveCommentReqReplyListReplyContentElementDocsLink,
    CreateDriveCommentReqReplyListReplyContentElementTextRun,
    CreateDriveCommentReqReplyListReplyContentElement,
    CreateDriveCommentReqReplyListReplyContent,
    CreateDriveCommentReqReplyListReply,
    CreateDriveCommentReqReplyList,
    CreateDriveCommentReqUserIDType,
    CreateDriveCommentReqFileType,
    CreateDriveCommentReq,
    CreateDriveCommentRespReplyListReplyContentElementPerson,
    CreateDriveCommentRespReplyListReplyContentElementDocsLink,
    CreateDriveCommentRespReplyListReplyContentElementTextRun,
    CreateDriveCommentRespReplyListReplyContentElement,
    CreateDriveCommentRespReplyListReplyContent,
    CreateDriveCommentRespReplyListReply,
    CreateDriveCommentRespReplyList,
    CreateDriveCommentResp,
)
from pylark.api_service_drive_comment_delete import (
    DeleteDriveCommentReqFileType,
    DeleteDriveCommentReq,
    DeleteDriveCommentResp,
)
from pylark.api_service_drive_comment_get import (
    GetDriveCommentReqUserIDType,
    GetDriveCommentReqFileType,
    GetDriveCommentReq,
    GetDriveCommentRespReplyListReplyContentElementPerson,
    GetDriveCommentRespReplyListReplyContentElementDocsLink,
    GetDriveCommentRespReplyListReplyContentElementTextRun,
    GetDriveCommentRespReplyListReplyContentElement,
    GetDriveCommentRespReplyListReplyContent,
    GetDriveCommentRespReplyListReply,
    GetDriveCommentRespReplyList,
    GetDriveCommentResp,
)
from pylark.api_service_drive_comment_list import (
    GetDriveCommentListReqUserIDType,
    GetDriveCommentListReqFileType,
    GetDriveCommentListReq,
    GetDriveCommentListRespItemReplyListReplyContentElementPerson,
    GetDriveCommentListRespItemReplyListReplyContentElementDocsLink,
    GetDriveCommentListRespItemReplyListReplyContentElementTextRun,
    GetDriveCommentListRespItemReplyListReplyContentElement,
    GetDriveCommentListRespItemReplyListReplyContent,
    GetDriveCommentListRespItemReplyListReply,
    GetDriveCommentListRespItemReplyList,
    GetDriveCommentListRespItem,
    GetDriveCommentListResp,
)
from pylark.api_service_drive_comment_patch import (
    UpdateDriveCommentPatchReqFileType,
    UpdateDriveCommentPatchReq,
    UpdateDriveCommentPatchResp,
)
from pylark.api_service_drive_comment_update import (
    UpdateDriveCommentReqContentElementPerson,
    UpdateDriveCommentReqContentElementDocsLink,
    UpdateDriveCommentReqContentElementTextRun,
    UpdateDriveCommentReqContentElement,
    UpdateDriveCommentReqContent,
    UpdateDriveCommentReqFileType,
    UpdateDriveCommentReq,
    UpdateDriveCommentResp,
)
from pylark.api_service_drive_doc_content_get import (
    GetDriveDocContentReq,
    GetDriveDocContentResp,
)
from pylark.api_service_drive_doc_create import CreateDriveDocReq, CreateDriveDocResp
from pylark.api_service_drive_doc_meta_get import (
    GetDriveDocMetaReq,
    GetDriveDocMetaResp,
)
from pylark.api_service_drive_doc_raw_content_get import (
    GetDriveDocRawContentReq,
    GetDriveDocRawContentResp,
)
from pylark.api_service_drive_file_copy import CopyDriveFileReq, CopyDriveFileResp
from pylark.api_service_drive_file_create import CreateDriveFileReq, CreateDriveFileResp
from pylark.api_service_drive_file_delete import DeleteDriveFileReq, DeleteDriveFileResp
from pylark.api_service_drive_file_download import (
    DownloadDriveFileReqRange,
    DownloadDriveFileReq,
    DownloadDriveFileRespFile,
    DownloadDriveFileResp,
    DownloadDriveFileResp,
)
from pylark.api_service_drive_file_meta_get import (
    GetDriveFileMetaReqRequestDocs,
    GetDriveFileMetaReq,
    GetDriveFileMetaRespDocsMetas,
    GetDriveFileMetaResp,
)
from pylark.api_service_drive_file_search import (
    SearchDriveFileReq,
    SearchDriveFileRespDocsEntity,
    SearchDriveFileResp,
)
from pylark.api_service_drive_file_sheet_delete import (
    DeleteDriveSheetFileReq,
    DeleteDriveSheetFileResp,
)
from pylark.api_service_drive_file_statistics_get import (
    GetDriveFileStatisticsReqFileType,
    GetDriveFileStatisticsReq,
    GetDriveFileStatisticsRespStatistics,
    GetDriveFileStatisticsRespFileType,
    GetDriveFileStatisticsResp,
)
from pylark.api_service_drive_file_upload_all import (
    UploadDriveFileReqFile,
    UploadDriveFileReq,
    UploadDriveFileResp,
)
from pylark.api_service_drive_file_upload_finish import (
    FinishUploadDriveFileReq,
    FinishUploadDriveFileResp,
)
from pylark.api_service_drive_file_upload_part import (
    PartUploadDriveFileReqFile,
    PartUploadDriveFileReq,
    PartUploadDriveFileResp,
)
from pylark.api_service_drive_file_upload_prepare import (
    PrepareUploadDriveFileReq,
    PrepareUploadDriveFileResp,
)
from pylark.api_service_drive_folder_children_get import (
    GetDriveFolderChildrenReq,
    GetDriveFolderChildrenRespChildren,
    GetDriveFolderChildrenResp,
)
from pylark.api_service_drive_folder_create import (
    CreateDriveFolderReq,
    CreateDriveFolderResp,
)
from pylark.api_service_drive_folder_meta import (
    GetDriveFolderMetaReq,
    GetDriveFolderMetaResp,
)
from pylark.api_service_drive_folder_root_meta import (
    GetDriveRootFolderMetaReq,
    GetDriveRootFolderMetaResp,
)
from pylark.api_service_drive_import_task_create import (
    CreateDriveImportTaskReqPoint,
    CreateDriveImportTaskReq,
    CreateDriveImportTaskResp,
)
from pylark.api_service_drive_import_task_get import (
    GetDriveImportTaskReq,
    GetDriveImportTaskRespResult,
    GetDriveImportTaskResp,
)
from pylark.api_service_drive_media_batch_get_tmp_download_url import (
    BatchGetDriveMediaTmpDownloadURLReq,
    BatchGetDriveMediaTmpDownloadURLRespTmpDownloadURL,
    BatchGetDriveMediaTmpDownloadURLResp,
)
from pylark.api_service_drive_media_download import (
    DownloadDriveMediaReqRange,
    DownloadDriveMediaReq,
    DownloadDriveMediaRespFile,
    DownloadDriveMediaResp,
    DownloadDriveMediaResp,
)
from pylark.api_service_drive_media_upload_all import (
    UploadDriveMediaReqFile,
    UploadDriveMediaReq,
    UploadDriveMediaResp,
)
from pylark.api_service_drive_media_upload_finish import (
    FinishUploadDriveMediaReq,
    FinishUploadDriveMediaResp,
)
from pylark.api_service_drive_media_upload_part import (
    PartUploadDriveMediaReqFile,
    PartUploadDriveMediaReq,
    PartUploadDriveMediaResp,
)
from pylark.api_service_drive_media_upload_prepare import (
    PrepareUploadDriveMediaReq,
    PrepareUploadDriveMediaResp,
)
from pylark.api_service_drive_permission_member_check import (
    CheckDriveMemberPermissionReq,
    CheckDriveMemberPermissionResp,
)
from pylark.api_service_drive_permission_member_create import (
    CreateDriveMemberPermissionReq,
    CreateDriveMemberPermissionRespMember,
    CreateDriveMemberPermissionResp,
)
from pylark.api_service_drive_permission_member_create_old import (
    CreateDriveMemberPermissionOldReqMembers,
    CreateDriveMemberPermissionOldReq,
    CreateDriveMemberPermissionOldRespFailMembers,
    CreateDriveMemberPermissionOldResp,
)
from pylark.api_service_drive_permission_member_delete import (
    DeleteDriveMemberPermissionReq,
    DeleteDriveMemberPermissionResp,
)
from pylark.api_service_drive_permission_member_list import (
    GetDriveMemberPermissionListReq,
    GetDriveMemberPermissionListRespMember,
    GetDriveMemberPermissionListResp,
)
from pylark.api_service_drive_permission_member_transfer import (
    TransferDriveMemberPermissionReqOwner,
    TransferDriveMemberPermissionReq,
    TransferDriveMemberPermissionRespOwner,
    TransferDriveMemberPermissionResp,
)
from pylark.api_service_drive_permission_member_update import (
    UpdateDriveMemberPermissionReq,
    UpdateDriveMemberPermissionResp,
)
from pylark.api_service_drive_permission_public_get_v2 import (
    GetDrivePublicPermissionV2Req,
    GetDrivePublicPermissionV2Resp,
)
from pylark.api_service_drive_permission_public_patch import (
    UpdateDrivePublicPermissionReq,
    UpdateDrivePublicPermissionRespPermissionPublic,
    UpdateDrivePublicPermissionResp,
)
from pylark.api_service_drive_permission_public_update_v1_old import (
    UpdateDrivePublicPermissionV1OldReq,
    UpdateDrivePublicPermissionV1OldResp,
)
from pylark.api_service_drive_permission_public_update_v2_old import (
    UpdateDrivePublicPermissionV2OldReq,
    UpdateDrivePublicPermissionV2OldResp,
)
from pylark.api_service_drive_sheet_batch_update import (
    BatchUpdateSheetReqRequestDeleteSheet,
    BatchUpdateSheetReqRequestCopySheetDestination,
    BatchUpdateSheetReqRequestCopySheetSource,
    BatchUpdateSheetReqRequestCopySheet,
    BatchUpdateSheetReqRequestAddSheetProperties,
    BatchUpdateSheetReqRequestAddSheet,
    BatchUpdateSheetReqRequest,
    BatchUpdateSheetReq,
    BatchUpdateSheetRespReplyDeleteSheet,
    BatchUpdateSheetRespReplyCopySheet,
    BatchUpdateSheetRespReplyAddSheet,
    BatchUpdateSheetRespReply,
    BatchUpdateSheetResp,
)
from pylark.api_service_drive_sheet_cell_merge import (
    MergeSheetCellReq,
    MergeSheetCellResp,
)
from pylark.api_service_drive_sheet_cell_unmerge import (
    UnmergeSheetCellReq,
    UnmergeSheetCellResp,
)
from pylark.api_service_drive_sheet_condition_format_create import (
    CreateSheetConditionFormatReqSheetConditionFormatConditionFormatStyleFont,
    CreateSheetConditionFormatReqSheetConditionFormatConditionFormatStyle,
    CreateSheetConditionFormatReqSheetConditionFormatConditionFormatAttrs,
    CreateSheetConditionFormatReqSheetConditionFormatConditionFormat,
    CreateSheetConditionFormatReqSheetConditionFormat,
    CreateSheetConditionFormatReq,
    CreateSheetConditionFormatRespResponse,
    CreateSheetConditionFormatResp,
)
from pylark.api_service_drive_sheet_condition_format_delete import (
    DeleteSheetConditionFormatReqSheetCfIDs,
    DeleteSheetConditionFormatReq,
    DeleteSheetConditionFormatRespResponse,
    DeleteSheetConditionFormatResp,
)
from pylark.api_service_drive_sheet_condition_format_get import (
    GetSheetConditionFormatReq,
    GetSheetConditionFormatRespSheetConditionFormatConditionFormatStyleFont,
    GetSheetConditionFormatRespSheetConditionFormatConditionFormatStyle,
    GetSheetConditionFormatRespSheetConditionFormatConditionFormatAttrs,
    GetSheetConditionFormatRespSheetConditionFormatConditionFormat,
    GetSheetConditionFormatRespSheetConditionFormat,
    GetSheetConditionFormatResp,
)
from pylark.api_service_drive_sheet_condition_format_update import (
    UpdateSheetConditionFormatReqSheetConditionFormatsConditionFormatStyleFont,
    UpdateSheetConditionFormatReqSheetConditionFormatsConditionFormatStyle,
    UpdateSheetConditionFormatReqSheetConditionFormatsConditionFormatAttrs,
    UpdateSheetConditionFormatReqSheetConditionFormatsConditionFormat,
    UpdateSheetConditionFormatReqSheetConditionFormats,
    UpdateSheetConditionFormatReq,
    UpdateSheetConditionFormatRespResponse,
    UpdateSheetConditionFormatResp,
)
from pylark.api_service_drive_sheet_create import (
    CreateSheetReq,
    CreateSheetRespSpreadsheet,
    CreateSheetResp,
)
from pylark.api_service_drive_sheet_data_validation_dropdown_create import (
    CreateSheetDataValidationDropdownReqDataValidationOptions,
    CreateSheetDataValidationDropdownReqDataValidation,
    CreateSheetDataValidationDropdownReq,
    CreateSheetDataValidationDropdownResp,
)
from pylark.api_service_drive_sheet_data_validation_dropdown_delete import (
    DeleteSheetDataValidationDropdownReqDataValidationRange,
    DeleteSheetDataValidationDropdownReq,
    DeleteSheetDataValidationDropdownRespRangeResult,
    DeleteSheetDataValidationDropdownResp,
)
from pylark.api_service_drive_sheet_data_validation_dropdown_get import (
    GetSheetDataValidationDropdownReq,
    GetSheetDataValidationDropdownRespDataValidationOptionsColorValueMap,
    GetSheetDataValidationDropdownRespDataValidationOptions,
    GetSheetDataValidationDropdownRespDataValidation,
    GetSheetDataValidationDropdownResp,
)
from pylark.api_service_drive_sheet_data_validation_dropdown_update import (
    UpdateSheetDataValidationDropdownReqDataValidationOptions,
    UpdateSheetDataValidationDropdownReqDataValidation,
    UpdateSheetDataValidationDropdownReq,
    UpdateSheetDataValidationDropdownRespDataValidationOptionsColorValueMap,
    UpdateSheetDataValidationDropdownRespDataValidationOptions,
    UpdateSheetDataValidationDropdownRespDataValidation,
    UpdateSheetDataValidationDropdownResp,
)
from pylark.api_service_drive_sheet_dimension_move import (
    MoveSheetDimensionReqSource,
    MoveSheetDimensionReq,
    MoveSheetDimensionResp,
)
from pylark.api_service_drive_sheet_dimension_range_add import (
    AddSheetDimensionRangeReqDimension,
    AddSheetDimensionRangeReq,
    AddSheetDimensionRangeResp,
)
from pylark.api_service_drive_sheet_dimension_range_delete import (
    DeleteSheetDimensionRangeReqDimension,
    DeleteSheetDimensionRangeReq,
    DeleteSheetDimensionRangeResp,
)
from pylark.api_service_drive_sheet_dimension_range_insert import (
    InsertSheetDimensionRangeReqDimension,
    InsertSheetDimensionRangeReq,
    InsertSheetDimensionRangeResp,
)
from pylark.api_service_drive_sheet_dimension_range_update import (
    UpdateSheetDimensionRangeReqDimensionProperties,
    UpdateSheetDimensionRangeReqDimension,
    UpdateSheetDimensionRangeReq,
    UpdateSheetDimensionRangeResp,
)
from pylark.api_service_drive_sheet_filter_create import (
    CreateSheetFilterReqCondition,
    CreateSheetFilterReq,
    CreateSheetFilterResp,
)
from pylark.api_service_drive_sheet_filter_delete import (
    DeleteSheetFilterReq,
    DeleteSheetFilterResp,
)
from pylark.api_service_drive_sheet_filter_get import (
    GetSheetFilterReq,
    GetSheetFilterRespSheetFilterInfoFilterInfoCondition,
    GetSheetFilterRespSheetFilterInfoFilterInfo,
    GetSheetFilterRespSheetFilterInfo,
    GetSheetFilterResp,
)
from pylark.api_service_drive_sheet_filter_update import (
    UpdateSheetFilterReqCondition,
    UpdateSheetFilterReq,
    UpdateSheetFilterResp,
)
from pylark.api_service_drive_sheet_filter_view_condition_create import (
    CreateSheetFilterViewConditionReq,
    CreateSheetFilterViewConditionRespCondition,
    CreateSheetFilterViewConditionResp,
)
from pylark.api_service_drive_sheet_filter_view_condition_delete import (
    DeleteSheetFilterViewConditionReq,
    DeleteSheetFilterViewConditionResp,
)
from pylark.api_service_drive_sheet_filter_view_condition_get import (
    GetSheetFilterViewConditionReq,
    GetSheetFilterViewConditionRespCondition,
    GetSheetFilterViewConditionResp,
)
from pylark.api_service_drive_sheet_filter_view_condition_query import (
    QuerySheetFilterViewConditionReq,
    QuerySheetFilterViewConditionRespItem,
    QuerySheetFilterViewConditionResp,
)
from pylark.api_service_drive_sheet_filter_view_condition_update import (
    UpdateSheetFilterViewConditionReq,
    UpdateSheetFilterViewConditionRespCondition,
    UpdateSheetFilterViewConditionResp,
)
from pylark.api_service_drive_sheet_filter_view_create import (
    CreateSheetFilterViewReq,
    CreateSheetFilterViewRespFilterView,
    CreateSheetFilterViewResp,
)
from pylark.api_service_drive_sheet_filter_view_delete import (
    DeleteSheetFilterViewReq,
    DeleteSheetFilterViewResp,
)
from pylark.api_service_drive_sheet_filter_view_get import (
    GetSheetFilterViewReq,
    GetSheetFilterViewRespFilterView,
    GetSheetFilterViewResp,
)
from pylark.api_service_drive_sheet_filter_view_query import (
    QuerySheetFilterViewReq,
    QuerySheetFilterViewRespItem,
    QuerySheetFilterViewResp,
)
from pylark.api_service_drive_sheet_filter_view_update import (
    UpdateSheetFilterViewReq,
    UpdateSheetFilterViewRespFilterView,
    UpdateSheetFilterViewResp,
)
from pylark.api_service_drive_sheet_find import (
    FindSheetReqFindCondition,
    FindSheetReq,
    FindSheetRespFindResult,
    FindSheetResp,
)
from pylark.api_service_drive_sheet_float_image_create import (
    CreateSheetFloatImageReqOffsetY,
    CreateSheetFloatImageReqOffsetX,
    CreateSheetFloatImageReqHeight,
    CreateSheetFloatImageReqWidth,
    CreateSheetFloatImageReq,
    CreateSheetFloatImageRespFloatImageOffsetY,
    CreateSheetFloatImageRespFloatImageOffsetX,
    CreateSheetFloatImageRespFloatImageHeight,
    CreateSheetFloatImageRespFloatImageWidth,
    CreateSheetFloatImageRespFloatImage,
    CreateSheetFloatImageResp,
)
from pylark.api_service_drive_sheet_float_image_delete import (
    DeleteSheetFloatImageReq,
    DeleteSheetFloatImageResp,
)
from pylark.api_service_drive_sheet_float_image_get import (
    GetSheetFloatImageReq,
    GetSheetFloatImageRespFloatImageOffsetY,
    GetSheetFloatImageRespFloatImageOffsetX,
    GetSheetFloatImageRespFloatImageHeight,
    GetSheetFloatImageRespFloatImageWidth,
    GetSheetFloatImageRespFloatImage,
    GetSheetFloatImageResp,
)
from pylark.api_service_drive_sheet_float_image_query import (
    QuerySheetFloatImageReq,
    QuerySheetFloatImageRespItemOffsetY,
    QuerySheetFloatImageRespItemOffsetX,
    QuerySheetFloatImageRespItemHeight,
    QuerySheetFloatImageRespItemWidth,
    QuerySheetFloatImageRespItem,
    QuerySheetFloatImageResp,
)
from pylark.api_service_drive_sheet_float_image_update import (
    UpdateSheetFloatImageReqOffsetY,
    UpdateSheetFloatImageReqOffsetX,
    UpdateSheetFloatImageReqHeight,
    UpdateSheetFloatImageReqWidth,
    UpdateSheetFloatImageReq,
    UpdateSheetFloatImageRespFloatImageOffsetY,
    UpdateSheetFloatImageRespFloatImageOffsetX,
    UpdateSheetFloatImageRespFloatImageHeight,
    UpdateSheetFloatImageRespFloatImageWidth,
    UpdateSheetFloatImageRespFloatImage,
    UpdateSheetFloatImageResp,
)
from pylark.api_service_drive_sheet_image_set import (
    SetSheetValueImageReqImage,
    SetSheetValueImageReq,
    SetSheetValueImageResp,
)
from pylark.api_service_drive_sheet_import import (
    ImportSheetReqFile,
    ImportSheetReq,
    ImportSheetResp,
)
from pylark.api_service_drive_sheet_meta_get import (
    GetSheetMetaReqUserIDType,
    GetSheetMetaReq,
    GetSheetMetaRespSheetBlockInfo,
    GetSheetMetaRespSheetProtectedRangeDimension,
    GetSheetMetaRespSheetProtectedRange,
    GetSheetMetaRespSheetMerge,
    GetSheetMetaRespSheet,
    GetSheetMetaRespProperties,
    GetSheetMetaResp,
)
from pylark.api_service_drive_sheet_property_update import (
    UpdateSheetPropertyReqProperties,
    UpdateSheetPropertyReq,
    UpdateSheetPropertyResp,
)
from pylark.api_service_drive_sheet_protected_dimension_create import (
    CreateSheetProtectedDimensionReqAddProtectedDimensionDimension,
    CreateSheetProtectedDimensionReqAddProtectedDimension,
    CreateSheetProtectedDimensionReqUserIDType,
    CreateSheetProtectedDimensionReq,
    CreateSheetProtectedDimensionRespAddProtectedDimensionDimension,
    CreateSheetProtectedDimensionRespAddProtectedDimension,
    CreateSheetProtectedDimensionResp,
)
from pylark.api_service_drive_sheet_protected_dimension_delete import (
    DeleteSheetProtectedDimensionReq,
    DeleteSheetProtectedDimensionResp,
)
from pylark.api_service_drive_sheet_protected_dimension_get import (
    GetSheetProtectedDimensionReq,
    GetSheetProtectedDimensionRespProtectedRangeEditorsUser,
    GetSheetProtectedDimensionRespProtectedRangeEditors,
    GetSheetProtectedDimensionRespProtectedRangeDimension,
    GetSheetProtectedDimensionRespProtectedRange,
    GetSheetProtectedDimensionResp,
)
from pylark.api_service_drive_sheet_protected_dimension_update import (
    UpdateSheetProtectedDimensionReqRequestsEditorsDelEditors,
    UpdateSheetProtectedDimensionReqRequestsEditorsAddEditors,
    UpdateSheetProtectedDimensionReqRequestsEditors,
    UpdateSheetProtectedDimensionReqRequestsDimension,
    UpdateSheetProtectedDimensionReqRequests,
    UpdateSheetProtectedDimensionReq,
    UpdateSheetProtectedDimensionRespReplyEditorsDelEditor,
    UpdateSheetProtectedDimensionRespReplyEditorsAddEditor,
    UpdateSheetProtectedDimensionRespReplyEditors,
    UpdateSheetProtectedDimensionRespReplyDimension,
    UpdateSheetProtectedDimensionRespReply,
    UpdateSheetProtectedDimensionResp,
)
from pylark.api_service_drive_sheet_replace import (
    ReplaceSheetReqFindCondition,
    ReplaceSheetReq,
    ReplaceSheetRespReplaceResult,
    ReplaceSheetResp,
)
from pylark.api_service_drive_sheet_style_batch_set import (
    BatchSetSheetStyleReqDataStyleFont,
    BatchSetSheetStyleReqDataStyle,
    BatchSetSheetStyleReqData,
    BatchSetSheetStyleReq,
    BatchSetSheetStyleRespResponse,
    BatchSetSheetStyleResp,
)
from pylark.api_service_drive_sheet_style_set import (
    SetSheetStyleReqAppendStyleStyleFont,
    SetSheetStyleReqAppendStyleStyle,
    SetSheetStyleReqAppendStyle,
    SetSheetStyleReq,
    SetSheetStyleResp,
)
from pylark.api_service_drive_sheet_value_append import (
    AppendSheetValueReqValueRangeValues,
    AppendSheetValueReqValueRange,
    AppendSheetValueReq,
    AppendSheetValueRespUpdates,
    AppendSheetValueResp,
)
from pylark.api_service_drive_sheet_value_batch_get import (
    BatchGetSheetValueReqUserIDType,
    BatchGetSheetValueReq,
    BatchGetSheetValueRespValueRangeValue,
    BatchGetSheetValueRespValueRange,
    BatchGetSheetValueResp,
)
from pylark.api_service_drive_sheet_value_batch_set import (
    BatchSetSheetValueReqValueRangeValue,
    BatchSetSheetValueReqValueRange,
    BatchSetSheetValueReq,
    BatchSetSheetValueRespResponse,
    BatchSetSheetValueResp,
)
from pylark.api_service_drive_sheet_value_get import (
    GetSheetValueReqUserIDType,
    GetSheetValueReq,
    GetSheetValueRespValueRangeValues,
    GetSheetValueRespValueRange,
    GetSheetValueResp,
)
from pylark.api_service_drive_sheet_value_prepend import (
    PrependSheetValueReqValueRangeValues,
    PrependSheetValueReqValueRange,
    PrependSheetValueReq,
    PrependSheetValueRespUpdates,
    PrependSheetValueResp,
)
from pylark.api_service_drive_sheet_value_set import (
    SetSheetValueReqValueRangeValues,
    SetSheetValueReqValueRange,
    SetSheetValueReq,
    SetSheetValueResp,
)
from pylark.api_service_ehr import LarkEHRService
from pylark.api_service_ehr_download_attachment import (
    DownloadEHRAttachmentsReq,
    DownloadEHRAttachmentsRespFile,
    DownloadEHRAttachmentsResp,
    DownloadEHRAttachmentsResp,
)
from pylark.api_service_ehr_employee_get_list import (
    GetEHREmployeeListReqUserIDType,
    GetEHREmployeeListReq,
    GetEHREmployeeListRespItemCustomField,
    GetEHREmployeeListRespItemSystemFieldsOffboardingFile,
    GetEHREmployeeListRespItemSystemFieldsCertOfMerit,
    GetEHREmployeeListRespItemSystemFieldsGraduationCert,
    GetEHREmployeeListRespItemSystemFieldsDiplomaPhoto,
    GetEHREmployeeListRespItemSystemFieldsIDPhoto,
    GetEHREmployeeListRespItemSystemFieldsIDPhotoEmSide,
    GetEHREmployeeListRespItemSystemFieldsIDPhotoPoSide,
    GetEHREmployeeListRespItemSystemFieldsWorkExp,
    GetEHREmployeeListRespItemSystemFieldsFormerWorkExp,
    GetEHREmployeeListRespItemSystemFieldsEducation,
    GetEHREmployeeListRespItemSystemFieldsHighestLevelOfEdu,
    GetEHREmployeeListRespItemSystemFieldsEmergencyContact,
    GetEHREmployeeListRespItemSystemFieldsPrimaryEmergencyContact,
    GetEHREmployeeListRespItemSystemFieldsContractCompany,
    GetEHREmployeeListRespItemSystemFieldsProbationMonths,
    GetEHREmployeeListRespItemSystemFieldsIDType,
    GetEHREmployeeListRespItemSystemFieldsNativeRegion,
    GetEHREmployeeListRespItemSystemFieldsWorkLocation,
    GetEHREmployeeListRespItemSystemFieldsJobLevel,
    GetEHREmployeeListRespItemSystemFieldsJob,
    GetEHREmployeeListRespItemSystemFieldsManager,
    GetEHREmployeeListRespItemSystemFields,
    GetEHREmployeeListRespItem,
    GetEHREmployeeListResp,
)
from pylark.api_service_file import LarkFileService
from pylark.api_service_file_download_file import (
    DownloadFileReq,
    DownloadFileRespFile,
    DownloadFileResp,
    DownloadFileResp,
)
from pylark.api_service_file_download_image import (
    DownloadImageReq,
    DownloadImageRespFile,
    DownloadImageResp,
    DownloadImageResp,
)
from pylark.api_service_file_upload_file import (
    UploadFileReqFile,
    UploadFileReqFileType,
    UploadFileReq,
    UploadFileResp,
)
from pylark.api_service_file_upload_image import (
    UploadImageReqImage,
    UploadImageReqImageType,
    UploadImageReq,
    UploadImageResp,
)
from pylark.api_service_helpdesk import LarkHelpdeskService
from pylark.api_service_helpdesk_agent_email_get import (
    GetHelpdeskAgentEmailReq,
    GetHelpdeskAgentEmailResp,
)
from pylark.api_service_helpdesk_agent_patch import (
    UpdateHelpdeskAgentReq,
    UpdateHelpdeskAgentResp,
)
from pylark.api_service_helpdesk_agent_schedule_create import (
    CreateHelpdeskAgentScheduleReqAgentScheduleSchedule,
    CreateHelpdeskAgentScheduleReqAgentSchedule,
    CreateHelpdeskAgentScheduleReq,
    CreateHelpdeskAgentScheduleResp,
)
from pylark.api_service_helpdesk_agent_schedule_delete import (
    DeleteHelpdeskAgentScheduleReq,
    DeleteHelpdeskAgentScheduleResp,
)
from pylark.api_service_helpdesk_agent_schedule_get import (
    GetHelpdeskAgentScheduleReq,
    GetHelpdeskAgentScheduleRespAgentScheduleAgentSkill,
    GetHelpdeskAgentScheduleRespAgentScheduleSchedule,
    GetHelpdeskAgentScheduleRespAgentScheduleAgent,
    GetHelpdeskAgentScheduleRespAgentSchedule,
    GetHelpdeskAgentScheduleResp,
)
from pylark.api_service_helpdesk_agent_schedule_get_list import (
    GetHelpdeskAgentScheduleListReq,
    GetHelpdeskAgentScheduleListRespAgentScheduleAgentSkill,
    GetHelpdeskAgentScheduleListRespAgentScheduleSchedule,
    GetHelpdeskAgentScheduleListRespAgentScheduleAgent,
    GetHelpdeskAgentScheduleListRespAgentSchedule,
    GetHelpdeskAgentScheduleListResp,
)
from pylark.api_service_helpdesk_agent_schedule_update import (
    UpdateHelpdeskAgentScheduleReqAgentScheduleSchedule,
    UpdateHelpdeskAgentScheduleReqAgentSchedule,
    UpdateHelpdeskAgentScheduleReq,
    UpdateHelpdeskAgentScheduleResp,
)
from pylark.api_service_helpdesk_agent_skill_create import (
    CreateHelpdeskAgentSkillReqRule,
    CreateHelpdeskAgentSkillReq,
    CreateHelpdeskAgentSkillResp,
)
from pylark.api_service_helpdesk_agent_skill_delete import (
    DeleteHelpdeskAgentSkillReq,
    DeleteHelpdeskAgentSkillResp,
)
from pylark.api_service_helpdesk_agent_skill_get import (
    GetHelpdeskAgentSkillReq,
    GetHelpdeskAgentSkillRespAgentSkillAgent,
    GetHelpdeskAgentSkillRespAgentSkillRule,
    GetHelpdeskAgentSkillRespAgentSkill,
    GetHelpdeskAgentSkillResp,
)
from pylark.api_service_helpdesk_agent_skill_get_list import (
    GetHelpdeskAgentSkillListReq,
    GetHelpdeskAgentSkillListRespAgentSkill,
    GetHelpdeskAgentSkillListResp,
)
from pylark.api_service_helpdesk_agent_skill_rule_get_list import (
    GetHelpdeskAgentSkillRuleListReq,
    GetHelpdeskAgentSkillRuleListRespRule,
    GetHelpdeskAgentSkillRuleListResp,
)
from pylark.api_service_helpdesk_agent_skill_update import (
    UpdateHelpdeskAgentSkillReqAgentSkillRules,
    UpdateHelpdeskAgentSkillReqAgentSkill,
    UpdateHelpdeskAgentSkillReq,
    UpdateHelpdeskAgentSkillResp,
)
from pylark.api_service_helpdesk_category_create import (
    CreateHelpdeskCategoryReq,
    CreateHelpdeskCategoryRespCategory,
    CreateHelpdeskCategoryResp,
)
from pylark.api_service_helpdesk_category_delete import (
    DeleteHelpdeskCategoryReq,
    DeleteHelpdeskCategoryResp,
)
from pylark.api_service_helpdesk_category_get import (
    GetHelpdeskCategoryReq,
    GetHelpdeskCategoryResp,
)
from pylark.api_service_helpdesk_category_get_list import (
    GetHelpdeskCategoryListReq,
    GetHelpdeskCategoryListRespCategorieChildren,
    GetHelpdeskCategoryListRespCategorie,
    GetHelpdeskCategoryListResp,
)
from pylark.api_service_helpdesk_category_update import (
    UpdateHelpdeskCategoryReq,
    UpdateHelpdeskCategoryResp,
)
from pylark.api_service_helpdesk_event_subscribe import (
    SubscribeHelpdeskEventReqEvent,
    SubscribeHelpdeskEventReq,
    SubscribeHelpdeskEventResp,
)
from pylark.api_service_helpdesk_event_unsubscribe import (
    UnsubscribeHelpdeskEventReqEvent,
    UnsubscribeHelpdeskEventReq,
    UnsubscribeHelpdeskEventResp,
)
from pylark.api_service_helpdesk_faq_create import (
    CreateHelpdeskFAQReqFAQ,
    CreateHelpdeskFAQReq,
    CreateHelpdeskFAQRespFAQCreateUser,
    CreateHelpdeskFAQRespFAQUpdateUser,
    CreateHelpdeskFAQRespFAQCategorie,
    CreateHelpdeskFAQRespFAQ,
    CreateHelpdeskFAQResp,
)
from pylark.api_service_helpdesk_faq_delete import (
    DeleteHelpdeskFAQReq,
    DeleteHelpdeskFAQResp,
)
from pylark.api_service_helpdesk_faq_get import (
    GetHelpdeskFAQReq,
    GetHelpdeskFAQRespFAQCreateUser,
    GetHelpdeskFAQRespFAQUpdateUser,
    GetHelpdeskFAQRespFAQCategorie,
    GetHelpdeskFAQRespFAQ,
    GetHelpdeskFAQResp,
)
from pylark.api_service_helpdesk_faq_get_image import (
    GetHelpdeskFAQImageReq,
    GetHelpdeskFAQImageRespFile,
    GetHelpdeskFAQImageResp,
    GetHelpdeskFAQImageResp,
)
from pylark.api_service_helpdesk_faq_get_list import (
    GetHelpdeskFAQListReq,
    GetHelpdeskFAQListRespItemCreateUser,
    GetHelpdeskFAQListRespItemUpdateUser,
    GetHelpdeskFAQListRespItemCategorie,
    GetHelpdeskFAQListRespItem,
    GetHelpdeskFAQListResp,
)
from pylark.api_service_helpdesk_faq_search import (
    SearchHelpdeskFAQReq,
    SearchHelpdeskFAQRespItemCategorie,
    SearchHelpdeskFAQRespItem,
    SearchHelpdeskFAQResp,
)
from pylark.api_service_helpdesk_faq_update import (
    UpdateHelpdeskFAQReqFAQ,
    UpdateHelpdeskFAQReq,
    UpdateHelpdeskFAQResp,
)
from pylark.api_service_helpdesk_start_service import (
    StartHelpdeskServiceReq,
    StartHelpdeskServiceResp,
)
from pylark.api_service_helpdesk_ticket_answer_user_query import (
    AnswerHelpdeskTicketUserQueryReqFAQScore,
    AnswerHelpdeskTicketUserQueryReqFAQ,
    AnswerHelpdeskTicketUserQueryReq,
    AnswerHelpdeskTicketUserQueryResp,
)
from pylark.api_service_helpdesk_ticket_customized_field_create import (
    CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTagChildren,
    CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTag,
    CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildren,
    CreateHelpdeskTicketCustomizedFieldReqDropdownOptions,
    CreateHelpdeskTicketCustomizedFieldReq,
    CreateHelpdeskTicketCustomizedFieldResp,
)
from pylark.api_service_helpdesk_ticket_customized_field_delete import (
    DeleteHelpdeskTicketCustomizedFieldReq,
    DeleteHelpdeskTicketCustomizedFieldResp,
)
from pylark.api_service_helpdesk_ticket_customized_field_get import (
    GetHelpdeskTicketCustomizedFieldReq,
    GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptionsChildrenChildren,
    GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptionsChildren,
    GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptions,
    GetHelpdeskTicketCustomizedFieldRespUpdatedBy,
    GetHelpdeskTicketCustomizedFieldRespCreatedBy,
    GetHelpdeskTicketCustomizedFieldResp,
)
from pylark.api_service_helpdesk_ticket_customized_field_get_list import (
    GetHelpdeskTicketCustomizedFieldListReq,
    GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptionsChildrenChildren,
    GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptionsChildren,
    GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptions,
    GetHelpdeskTicketCustomizedFieldListRespItemUpdatedBy,
    GetHelpdeskTicketCustomizedFieldListRespItemCreatedBy,
    GetHelpdeskTicketCustomizedFieldListRespItem,
    GetHelpdeskTicketCustomizedFieldListResp,
)
from pylark.api_service_helpdesk_ticket_customized_field_update import (
    UpdateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTagChildren,
    UpdateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTag,
    UpdateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildren,
    UpdateHelpdeskTicketCustomizedFieldReqDropdownOptions,
    UpdateHelpdeskTicketCustomizedFieldReq,
    UpdateHelpdeskTicketCustomizedFieldResp,
)
from pylark.api_service_helpdesk_ticket_get import (
    GetHelpdeskTicketReq,
    GetHelpdeskTicketRespTicketAgentServiceDuration,
    GetHelpdeskTicketRespTicketCustomizedField,
    GetHelpdeskTicketRespTicketCollaborator,
    GetHelpdeskTicketRespTicketClosedBy,
    GetHelpdeskTicketRespTicketAgent,
    GetHelpdeskTicketRespTicketGuest,
    GetHelpdeskTicketRespTicket,
    GetHelpdeskTicketResp,
)
from pylark.api_service_helpdesk_ticket_get_list import (
    GetHelpdeskTicketListReqCustomizedFields,
    GetHelpdeskTicketListReq,
    GetHelpdeskTicketListRespTicketCustomizedField,
    GetHelpdeskTicketListRespTicketCollaborator,
    GetHelpdeskTicketListRespTicketClosedBy,
    GetHelpdeskTicketListRespTicketAgent,
    GetHelpdeskTicketListRespTicketGuest,
    GetHelpdeskTicketListRespTicket,
    GetHelpdeskTicketListResp,
)
from pylark.api_service_helpdesk_ticket_image_download import (
    DownloadHelpdeskTicketImageReq,
    DownloadHelpdeskTicketImageRespFile,
    DownloadHelpdeskTicketImageResp,
    DownloadHelpdeskTicketImageResp,
)
from pylark.api_service_helpdesk_ticket_message_get_list import (
    GetHelpdeskTicketMessageListReq,
    GetHelpdeskTicketMessageListRespMessageMessageType,
    GetHelpdeskTicketMessageListRespMessage,
    GetHelpdeskTicketMessageListResp,
)
from pylark.api_service_helpdesk_ticket_message_send import (
    SendHelpdeskTicketMessageReqMsgType,
    SendHelpdeskTicketMessageReq,
    SendHelpdeskTicketMessageResp,
)
from pylark.api_service_helpdesk_ticket_update import (
    UpdateHelpdeskTicketReqCustomizedField,
    UpdateHelpdeskTicketReq,
    UpdateHelpdeskTicketResp,
)
from pylark.api_service_hire import LarkHireService
from pylark.api_service_hire_application_create import (
    CreateHireApplicationReq,
    CreateHireApplicationResp,
)
from pylark.api_service_hire_application_get import (
    GetHireApplicationReq,
    GetHireApplicationRespApplicationStage,
    GetHireApplicationRespApplication,
    GetHireApplicationResp,
)
from pylark.api_service_hire_application_interview_list import (
    GetHireApplicationInterviewListReqUserIDType,
    GetHireApplicationInterviewListReq,
    GetHireApplicationInterviewListRespItemInterviewRecordInterviewScore,
    GetHireApplicationInterviewListRespItemInterviewRecord,
    GetHireApplicationInterviewListRespItem,
    GetHireApplicationInterviewListResp,
)
from pylark.api_service_hire_application_list import (
    GetHireApplicationListReq,
    GetHireApplicationListResp,
)
from pylark.api_service_hire_application_terminate import (
    TerminateHireApplicationReq,
    TerminateHireApplicationResp,
)
from pylark.api_service_hire_attachment_get import (
    GetHireAttachmentReq,
    GetHireAttachmentRespAttachment,
    GetHireAttachmentResp,
)
from pylark.api_service_hire_attachment_preview_get import (
    GetHireAttachmentPreviewReq,
    GetHireAttachmentPreviewResp,
)
from pylark.api_service_hire_employee_get import (
    GetHireEmployeeReq,
    GetHireEmployeeRespEmployee,
    GetHireEmployeeResp,
)
from pylark.api_service_hire_employee_get_by_application import (
    GetHireEmployeeByApplicationReq,
    GetHireEmployeeByApplicationRespEmployee,
    GetHireEmployeeByApplicationResp,
)
from pylark.api_service_hire_employee_update import (
    UpdateHireEmployeeReqOverboardInfo,
    UpdateHireEmployeeReqConversionInfo,
    UpdateHireEmployeeReq,
    UpdateHireEmployeeRespEmployee,
    UpdateHireEmployeeResp,
)
from pylark.api_service_hire_job_get import (
    GetHireJobReqUserIDType,
    GetHireJobReq,
    GetHireJobRespJobCustomizedDataValueTimeRange,
    GetHireJobRespJobCustomizedDataValueOptionName,
    GetHireJobRespJobCustomizedDataValueOption,
    GetHireJobRespJobCustomizedDataValueOptionName,
    GetHireJobRespJobCustomizedDataValueOption,
    GetHireJobRespJobCustomizedDataValue,
    GetHireJobRespJobCustomizedDataName,
    GetHireJobRespJobCustomizedData,
    GetHireJobRespJobJobType,
    GetHireJobRespJobJobCategory,
    GetHireJobRespJobHighlight,
    GetHireJobRespJobMaxJobLevel,
    GetHireJobRespJobMinJobLevel,
    GetHireJobRespJobCity,
    GetHireJobRespJobDepartment,
    GetHireJobRespJobRecruitmentType,
    GetHireJobRespJob,
    GetHireJobResp,
)
from pylark.api_service_hire_job_manager_get import (
    GetHireJobManagerReqUserIDType,
    GetHireJobManagerReq,
    GetHireJobManagerRespInfo,
    GetHireJobManagerResp,
)
from pylark.api_service_hire_job_process_list import (
    GetHireJobProcessListReq,
    GetHireJobProcessListRespItemStage,
    GetHireJobProcessListRespItem,
    GetHireJobProcessListResp,
)
from pylark.api_service_hire_note_create import (
    CreateHireNoteReqUserIDType,
    CreateHireNoteReq,
    CreateHireNoteRespNote,
    CreateHireNoteResp,
)
from pylark.api_service_hire_note_get import (
    GetHireNoteReqUserIDType,
    GetHireNoteReq,
    GetHireNoteRespNote,
    GetHireNoteResp,
)
from pylark.api_service_hire_note_list import (
    GetHireNoteListReqUserIDType,
    GetHireNoteListReq,
    GetHireNoteListRespItem,
    GetHireNoteListResp,
)
from pylark.api_service_hire_note_update import (
    UpdateHireNoteReqUserIDType,
    UpdateHireNoteReq,
    UpdateHireNoteRespNote,
    UpdateHireNoteResp,
)
from pylark.api_service_hire_offer_get_by_application import (
    GetHireOfferByApplicationReqUserIDType,
    GetHireOfferByApplicationReq,
    GetHireOfferByApplicationRespOfferSalaryPlanCustomizeInfo,
    GetHireOfferByApplicationRespOfferSalaryPlan,
    GetHireOfferByApplicationRespOfferBasicInfoCustomizeInfo,
    GetHireOfferByApplicationRespOfferBasicInfoWorkAddressCountry,
    GetHireOfferByApplicationRespOfferBasicInfoWorkAddressState,
    GetHireOfferByApplicationRespOfferBasicInfoWorkAddressCity,
    GetHireOfferByApplicationRespOfferBasicInfoWorkAddressDistrict,
    GetHireOfferByApplicationRespOfferBasicInfoWorkAddress,
    GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressCountry,
    GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressState,
    GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressCity,
    GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressDistrict,
    GetHireOfferByApplicationRespOfferBasicInfoOnboardAddress,
    GetHireOfferByApplicationRespOfferBasicInfoLevel,
    GetHireOfferByApplicationRespOfferBasicInfoSequence,
    GetHireOfferByApplicationRespOfferBasicInfoRecruitmentType,
    GetHireOfferByApplicationRespOfferBasicInfo,
    GetHireOfferByApplicationRespOffer,
    GetHireOfferByApplicationResp,
)
from pylark.api_service_hire_offer_schema_get import (
    GetHireOfferSchemaReq,
    GetHireOfferSchemaRespObjectOptionName,
    GetHireOfferSchemaRespObjectOption,
    GetHireOfferSchemaRespObjectName,
    GetHireOfferSchemaRespObject,
    GetHireOfferSchemaResp,
)
from pylark.api_service_hire_referral_get_by_application import (
    GetHireReferralByApplicationReqUserIDType,
    GetHireReferralByApplicationReq,
    GetHireReferralByApplicationRespReferral,
    GetHireReferralByApplicationResp,
)
from pylark.api_service_hire_resume_sources_get import (
    GetHireResumeSourceReq,
    GetHireResumeSourceRespItem,
    GetHireResumeSourceResp,
)
from pylark.api_service_hire_talent_get import (
    GetHireTalentReq,
    GetHireTalentRespTalentInterviewRegistration,
    GetHireTalentRespTalentResumeSource,
    GetHireTalentRespTalentSns,
    GetHireTalentRespTalentLanguage,
    GetHireTalentRespTalentCertificate,
    GetHireTalentRespTalentCompetition,
    GetHireTalentRespTalentAward,
    GetHireTalentRespTalentWorks,
    GetHireTalentRespTalentProject,
    GetHireTalentRespTalentCareer,
    GetHireTalentRespTalentEducation,
    GetHireTalentRespTalentBasicInfoPreferredCity,
    GetHireTalentRespTalentBasicInfoHometownCity,
    GetHireTalentRespTalentBasicInfoCurrentCity,
    GetHireTalentRespTalentBasicInfoNationality,
    GetHireTalentRespTalentBasicInfo,
    GetHireTalentRespTalent,
    GetHireTalentResp,
)
from pylark.api_service_hire_transfer_onboard_by_application import (
    MakeHireTransferOnboardByApplicationReq,
    MakeHireTransferOnboardByApplicationResp,
)
from pylark.api_service_human_auth import LarkHumanAuthService
from pylark.api_service_human_auth_face_verify_crop_image import (
    CropFaceVerifyImageReqRawImage,
    CropFaceVerifyImageReq,
    CropFaceVerifyImageResp,
)
from pylark.api_service_human_auth_face_verify_get_auth_result import (
    GetFaceVerifyAuthResultReq,
    GetFaceVerifyAuthResultResp,
)
from pylark.api_service_human_auth_face_verify_upload_image import (
    UploadFaceVerifyImageReqImage,
    UploadFaceVerifyImageReq,
    UploadFaceVerifyImageResp,
)
from pylark.api_service_human_auth_identity import (
    CreateIdentityReqUserIDType,
    CreateIdentityReq,
    CreateIdentityResp,
)
from pylark.api_service_link_open_bot import OpenBotReq, OpenBotResp
from pylark.api_service_link_open_calender import OpenCalenderReq, OpenCalenderResp
from pylark.api_service_link_open_calender_account import (
    OpenCalenderAccountReq,
    OpenCalenderAccountResp,
)
from pylark.api_service_link_open_calender_event_create import (
    OpenCalenderEventCreateReq,
    OpenCalenderEventCreateResp,
)
from pylark.api_service_link_open_calender_view import (
    OpenCalenderViewReq,
    OpenCalenderViewResp,
)
from pylark.api_service_link_open_chat import OpenChatReq, OpenChatResp
from pylark.api_service_link_open_docs import OpenDocsReq, OpenDocsResp
from pylark.api_service_link_open_lark import OpenLarkReq, OpenLarkResp
from pylark.api_service_link_open_mini_program import (
    OpenMiniProgramReq,
    OpenMiniProgramResp,
)
from pylark.api_service_link_open_sso_login import OpenSSOLoginReq, OpenSSOLoginResp
from pylark.api_service_link_open_web_app import OpenWebAppReq, OpenWebAppResp
from pylark.api_service_link_open_web_url import OpenWebURLReq, OpenWebURLResp
from pylark.api_service_mail import LarkMailService
from pylark.api_service_mail_mail_group_create import (
    CreateMailGroupReq,
    CreateMailGroupResp,
)
from pylark.api_service_mail_mail_group_delete import (
    DeleteMailGroupReq,
    DeleteMailGroupResp,
)
from pylark.api_service_mail_mail_group_get import GetMailGroupReq, GetMailGroupResp
from pylark.api_service_mail_mail_group_get_list import (
    GetMailGroupListReq,
    GetMailGroupListRespItem,
    GetMailGroupListResp,
)
from pylark.api_service_mail_mail_group_member_create import (
    CreateMailGroupMemberReqType,
    CreateMailGroupMemberReqDepartmentIDType,
    CreateMailGroupMemberReqUserIDType,
    CreateMailGroupMemberReq,
    CreateMailGroupMemberRespType,
    CreateMailGroupMemberResp,
)
from pylark.api_service_mail_mail_group_member_delete import (
    DeleteMailGroupMemberReq,
    DeleteMailGroupMemberResp,
)
from pylark.api_service_mail_mail_group_member_get import (
    GetMailGroupMemberReqDepartmentIDType,
    GetMailGroupMemberReqUserIDType,
    GetMailGroupMemberReq,
    GetMailGroupMemberRespType,
    GetMailGroupMemberResp,
)
from pylark.api_service_mail_mail_group_member_get_list import (
    GetMailGroupMemberListReqDepartmentIDType,
    GetMailGroupMemberListReqUserIDType,
    GetMailGroupMemberListReq,
    GetMailGroupMemberListRespItemType,
    GetMailGroupMemberListRespItem,
    GetMailGroupMemberListResp,
)
from pylark.api_service_mail_mail_group_patch import (
    UpdateMailGroupPatchReq,
    UpdateMailGroupPatchResp,
)
from pylark.api_service_mail_mail_group_permission_member_create import (
    CreateMailGroupPermissionMemberReqType,
    CreateMailGroupPermissionMemberReqDepartmentIDType,
    CreateMailGroupPermissionMemberReqUserIDType,
    CreateMailGroupPermissionMemberReq,
    CreateMailGroupPermissionMemberRespType,
    CreateMailGroupPermissionMemberResp,
)
from pylark.api_service_mail_mail_group_permission_member_delete import (
    DeleteMailGroupPermissionMemberReq,
    DeleteMailGroupPermissionMemberResp,
)
from pylark.api_service_mail_mail_group_permission_member_get import (
    GetMailGroupPermissionMemberReqDepartmentIDType,
    GetMailGroupPermissionMemberReqUserIDType,
    GetMailGroupPermissionMemberReq,
    GetMailGroupPermissionMemberRespType,
    GetMailGroupPermissionMemberResp,
)
from pylark.api_service_mail_mail_group_permission_member_get_list import (
    GetMailGroupPermissionMemberListReqDepartmentIDType,
    GetMailGroupPermissionMemberListReqUserIDType,
    GetMailGroupPermissionMemberListReq,
    GetMailGroupPermissionMemberListRespItemType,
    GetMailGroupPermissionMemberListRespItem,
    GetMailGroupPermissionMemberListResp,
)
from pylark.api_service_mail_mail_group_update import (
    UpdateMailGroupReq,
    UpdateMailGroupResp,
)
from pylark.api_service_mail_public_mailbox_create import (
    CreatePublicMailboxReq,
    CreatePublicMailboxResp,
)
from pylark.api_service_mail_public_mailbox_get import (
    GetPublicMailboxReq,
    GetPublicMailboxResp,
)
from pylark.api_service_mail_public_mailbox_get_list import (
    GetPublicMailboxListReq,
    GetPublicMailboxListRespItem,
    GetPublicMailboxListResp,
)
from pylark.api_service_mail_public_mailbox_member_clear import (
    ClearPublicMailboxMemberReq,
    ClearPublicMailboxMemberResp,
)
from pylark.api_service_mail_public_mailbox_member_create import (
    CreatePublicMailboxMemberReqType,
    CreatePublicMailboxMemberReqUserIDType,
    CreatePublicMailboxMemberReq,
    CreatePublicMailboxMemberRespType,
    CreatePublicMailboxMemberResp,
)
from pylark.api_service_mail_public_mailbox_member_delete import (
    DeletePublicMailboxMemberReq,
    DeletePublicMailboxMemberResp,
)
from pylark.api_service_mail_public_mailbox_member_get import (
    GetPublicMailboxMemberReqUserIDType,
    GetPublicMailboxMemberReq,
    GetPublicMailboxMemberRespType,
    GetPublicMailboxMemberResp,
)
from pylark.api_service_mail_public_mailbox_member_get_list import (
    GetPublicMailboxMemberListReqUserIDType,
    GetPublicMailboxMemberListReq,
    GetPublicMailboxMemberListRespItemType,
    GetPublicMailboxMemberListRespItem,
    GetPublicMailboxMemberListResp,
)
from pylark.api_service_mail_public_mailbox_patch import (
    UpdatePublicMailboxPatchReq,
    UpdatePublicMailboxPatchResp,
)
from pylark.api_service_mail_public_mailbox_update import (
    UpdatePublicMailboxReq,
    UpdatePublicMailboxResp,
)
from pylark.api_service_meeting_room import LarkMeetingRoomService
from pylark.api_service_meeting_room_building_batch_get import (
    BatchGetMeetingRoomBuildingReq,
    BatchGetMeetingRoomBuildingRespBuilding,
    BatchGetMeetingRoomBuildingResp,
)
from pylark.api_service_meeting_room_building_batch_get_id import (
    BatchGetMeetingRoomBuildingIDReq,
    BatchGetMeetingRoomBuildingIDRespBuilding,
    BatchGetMeetingRoomBuildingIDResp,
)
from pylark.api_service_meeting_room_building_create import (
    CreateMeetingRoomBuildingReq,
    CreateMeetingRoomBuildingResp,
)
from pylark.api_service_meeting_room_building_delete import (
    DeleteMeetingRoomBuildingReq,
    DeleteMeetingRoomBuildingResp,
)
from pylark.api_service_meeting_room_building_get_list import (
    GetMeetingRoomBuildingListReq,
    GetMeetingRoomBuildingListRespBuildings,
    GetMeetingRoomBuildingListResp,
)
from pylark.api_service_meeting_room_building_update import (
    UpdateMeetingRoomBuildingReq,
    UpdateMeetingRoomBuildingResp,
)
from pylark.api_service_meeting_room_country_get_list import (
    GetMeetingRoomCountryListReq,
    GetMeetingRoomCountryListRespCountries,
    GetMeetingRoomCountryListResp,
)
from pylark.api_service_meeting_room_district_get_list import (
    GetMeetingRoomDistrictListReq,
    GetMeetingRoomDistrictListRespDistricts,
    GetMeetingRoomDistrictListResp,
)
from pylark.api_service_meeting_room_freebusy_batch_get import (
    BatchGetMeetingRoomFreebusyReq,
    BatchGetMeetingRoomFreebusyRespFreeBusyRoomIDOrganizerInfo,
    BatchGetMeetingRoomFreebusyRespFreeBusyRoomID,
    BatchGetMeetingRoomFreebusyRespFreeBusy,
    BatchGetMeetingRoomFreebusyResp,
)
from pylark.api_service_meeting_room_instance_reply import (
    ReplyMeetingRoomInstanceReq,
    ReplyMeetingRoomInstanceResp,
)
from pylark.api_service_meeting_room_room_batch_get import (
    BatchGetMeetingRoomRoomReq,
    BatchGetMeetingRoomRoomRespRoom,
    BatchGetMeetingRoomRoomResp,
)
from pylark.api_service_meeting_room_room_batch_get_id import (
    BatchGetMeetingRoomRoomIDReq,
    BatchGetMeetingRoomRoomIDRespRoom,
    BatchGetMeetingRoomRoomIDResp,
)
from pylark.api_service_meeting_room_room_create import (
    CreateMeetingRoomRoomReq,
    CreateMeetingRoomRoomResp,
)
from pylark.api_service_meeting_room_room_delete import (
    DeleteMeetingRoomRoomReq,
    DeleteMeetingRoomRoomResp,
)
from pylark.api_service_meeting_room_room_get_list import (
    GetMeetingRoomRoomListReq,
    GetMeetingRoomRoomListRespRooms,
    GetMeetingRoomRoomListResp,
)
from pylark.api_service_meeting_room_room_update import (
    UpdateMeetingRoomRoomReq,
    UpdateMeetingRoomRoomResp,
)
from pylark.api_service_meeting_room_summary_batch_get import (
    BatchGetMeetingRoomSummaryReqEventUid,
    BatchGetMeetingRoomSummaryReq,
    BatchGetMeetingRoomSummaryRespErrorEventUid,
    BatchGetMeetingRoomSummaryRespEventInfo,
    BatchGetMeetingRoomSummaryResp,
)
from pylark.api_service_message import LarkMessageService
from pylark.api_service_message_delete import DeleteMessageReq, DeleteMessageResp
from pylark.api_service_message_ephemeral_delete import (
    DeleteEphemeralMessageReq,
    DeleteEphemeralMessageResp,
)
from pylark.api_service_message_get import (
    GetMessageReq,
    GetMessageRespItemMentionIDType,
    GetMessageRespItemMention,
    GetMessageRespItemBody,
    GetMessageRespItemSenderIDType,
    GetMessageRespItemSender,
    GetMessageRespItemMsgType,
    GetMessageRespItem,
    GetMessageResp,
)
from pylark.api_service_message_get_file import (
    GetMessageFileReq,
    GetMessageFileRespFile,
    GetMessageFileResp,
    GetMessageFileResp,
)
from pylark.api_service_message_get_read_user_list import (
    GetMessageReadUserListReqUserIDType,
    GetMessageReadUserListReq,
    GetMessageReadUserListRespItemUserIDType,
    GetMessageReadUserListRespItem,
    GetMessageReadUserListResp,
)
from pylark.api_service_message_list import (
    GetMessageListReqContainerIDType,
    GetMessageListReq,
    GetMessageListRespItemMentionIDType,
    GetMessageListRespItemMention,
    GetMessageListRespItemBody,
    GetMessageListRespItemSenderIDType,
    GetMessageListRespItemSender,
    GetMessageListRespItemMsgType,
    GetMessageListRespItem,
    GetMessageListResp,
)
from pylark.api_service_message_reply import (
    ReplyRawMessageReqMsgType,
    ReplyRawMessageReq,
    ReplyRawMessageRespMentionIDType,
    ReplyRawMessageRespMention,
    ReplyRawMessageRespBody,
    ReplyRawMessageRespSenderIDType,
    ReplyRawMessageRespSender,
    ReplyRawMessageRespMsgType,
    ReplyRawMessageResp,
)
from pylark.api_service_message_send import (
    SendRawMessageReqMsgType,
    SendRawMessageReqReceiveIDType,
    SendRawMessageReq,
    SendRawMessageRespMentionIDType,
    SendRawMessageRespMention,
    SendRawMessageRespBody,
    SendRawMessageRespSenderIDType,
    SendRawMessageRespSender,
    SendRawMessageRespMsgType,
    SendRawMessageResp,
)
from pylark.api_service_message_send_old import (
    SendRawMessageOldReqContent,
    SendRawMessageOldReqMsgType,
    SendRawMessageOldReq,
    SendRawMessageOldResp,
)
from pylark.api_service_message_update import UpdateMessageReq, UpdateMessageResp
from pylark.api_service_okr import LarkOKRService
from pylark.api_service_okr_okr_batch_get import (
    BatchGetOKRReqUserIDType,
    BatchGetOKRReq,
    BatchGetOKRRespOKRObjectiveAligningObjectiveOwner,
    BatchGetOKRRespOKRObjectiveAligningObjective,
    BatchGetOKRRespOKRObjectiveAlignedObjectiveOwner,
    BatchGetOKRRespOKRObjectiveAlignedObjective,
    BatchGetOKRRespOKRObjectiveKrProgressRate,
    BatchGetOKRRespOKRObjectiveKrKrWeight,
    BatchGetOKRRespOKRObjectiveKr,
    BatchGetOKRRespOKRObjectiveProgressRate,
    BatchGetOKRRespOKRObjectiveWeight,
    BatchGetOKRRespOKRObjective,
    BatchGetOKRRespOKR,
    BatchGetOKRResp,
)
from pylark.api_service_okr_period_get_list import (
    GetOKRPeriodListReq,
    GetOKRPeriodListRespItem,
    GetOKRPeriodListResp,
)
from pylark.api_service_okr_user_okr_get_list import (
    GetUserOKRListReqUserIDType,
    GetUserOKRListReq,
    GetUserOKRListRespOKRObjectiveAligningObjectiveOwner,
    GetUserOKRListRespOKRObjectiveAligningObjective,
    GetUserOKRListRespOKRObjectiveAlignedObjectiveOwner,
    GetUserOKRListRespOKRObjectiveAlignedObjective,
    GetUserOKRListRespOKRObjectiveKrProgressRate,
    GetUserOKRListRespOKRObjectiveKrKrWeight,
    GetUserOKRListRespOKRObjectiveKr,
    GetUserOKRListRespOKRObjectiveProgressRate,
    GetUserOKRListRespOKRObjectiveWeight,
    GetUserOKRListRespOKRObjective,
    GetUserOKRListRespOKR,
    GetUserOKRListResp,
)
from pylark.api_service_search import LarkSearchService
from pylark.api_service_search_data_source_create import (
    CreateSearchDataSourceReq,
    CreateSearchDataSourceRespDataSource,
    CreateSearchDataSourceResp,
)
from pylark.api_service_search_data_source_delete import (
    DeleteSearchDataSourceReq,
    DeleteSearchDataSourceResp,
)
from pylark.api_service_search_data_source_get import (
    GetSearchDataSourceReq,
    GetSearchDataSourceRespDataSource,
    GetSearchDataSourceResp,
)
from pylark.api_service_search_data_source_item_create import (
    CreateSearchDataSourceItemReqContent,
    CreateSearchDataSourceItemReqMetadata,
    CreateSearchDataSourceItemReqACL,
    CreateSearchDataSourceItemReq,
    CreateSearchDataSourceItemResp,
)
from pylark.api_service_search_data_source_item_delete import (
    DeleteSearchDataSourceItemReq,
    DeleteSearchDataSourceItemResp,
)
from pylark.api_service_search_data_source_item_get import (
    GetSearchDataSourceItemReq,
    GetSearchDataSourceItemRespItemContent,
    GetSearchDataSourceItemRespItemMetadata,
    GetSearchDataSourceItemRespItemACL,
    GetSearchDataSourceItemRespItem,
    GetSearchDataSourceItemResp,
)
from pylark.api_service_search_data_source_list import (
    GetSearchDataSourceListReq,
    GetSearchDataSourceListRespItem,
    GetSearchDataSourceListResp,
)
from pylark.api_service_search_data_source_patch import (
    UpdateSearchDataSourceReq,
    UpdateSearchDataSourceRespDataSource,
    UpdateSearchDataSourceResp,
)
from pylark.api_service_task import LarkTaskService
from pylark.api_service_task_collaborator_create import (
    CreateTaskCollaboratorReqUserIDType,
    CreateTaskCollaboratorReq,
    CreateTaskCollaboratorRespCollaborator,
    CreateTaskCollaboratorResp,
)
from pylark.api_service_task_collaborator_delete import (
    DeleteTaskCollaboratorReq,
    DeleteTaskCollaboratorResp,
)
from pylark.api_service_task_collaborator_list import (
    GetTaskCollaboratorListReqUserIDType,
    GetTaskCollaboratorListReq,
    GetTaskCollaboratorListRespItem,
    GetTaskCollaboratorListResp,
)
from pylark.api_service_task_follower_create import (
    CreateTaskFollowerReqUserIDType,
    CreateTaskFollowerReq,
    CreateTaskFollowerRespFollower,
    CreateTaskFollowerResp,
)
from pylark.api_service_task_follower_delete import (
    DeleteTaskFollowerReq,
    DeleteTaskFollowerResp,
)
from pylark.api_service_task_follower_list import (
    GetTaskFollowerListReqUserIDType,
    GetTaskFollowerListReq,
    GetTaskFollowerListRespItem,
    GetTaskFollowerListResp,
)
from pylark.api_service_task_reminder_create import (
    CreateTaskReminderReq,
    CreateTaskReminderRespReminder,
    CreateTaskReminderResp,
)
from pylark.api_service_task_reminder_delete import (
    DeleteTaskReminderReq,
    DeleteTaskReminderResp,
)
from pylark.api_service_task_reminder_list import (
    GetTaskReminderListReq,
    GetTaskReminderListRespItem,
    GetTaskReminderListResp,
)
from pylark.api_service_task_task import (
    GetTaskReqUserIDType,
    GetTaskReq,
    GetTaskRespTaskOriginHref,
    GetTaskRespTaskOrigin,
    GetTaskRespTaskDue,
    GetTaskRespTask,
    GetTaskResp,
)
from pylark.api_service_task_task_complete import CompleteTaskReq, CompleteTaskResp
from pylark.api_service_task_task_create import (
    CreateTaskReqOriginHref,
    CreateTaskReqOrigin,
    CreateTaskReqDue,
    CreateTaskReqUserIDType,
    CreateTaskReq,
    CreateTaskRespTaskOriginHref,
    CreateTaskRespTaskOrigin,
    CreateTaskRespTaskDue,
    CreateTaskRespTask,
    CreateTaskResp,
)
from pylark.api_service_task_task_delete import DeleteTaskReq, DeleteTaskResp
from pylark.api_service_task_task_uncomplete import (
    UncompleteTaskReq,
    UncompleteTaskResp,
)
from pylark.api_service_task_task_update import (
    UpdateTaskReqTaskOriginHref,
    UpdateTaskReqTaskOrigin,
    UpdateTaskReqTaskDue,
    UpdateTaskReqTask,
    UpdateTaskReqUserIDType,
    UpdateTaskReq,
    UpdateTaskRespTaskOriginHref,
    UpdateTaskRespTaskOrigin,
    UpdateTaskRespTaskDue,
    UpdateTaskRespTask,
    UpdateTaskResp,
)
from pylark.api_service_tenant import LarkTenantService
from pylark.api_service_tenant_tenant_get import (
    GetTenantReq,
    GetTenantRespTenantAvatar,
    GetTenantRespTenant,
    GetTenantResp,
)
from pylark.api_service_vc import LarkVCService
from pylark.api_service_vc_meeting_end import EndVCMeetingReq, EndVCMeetingResp
from pylark.api_service_vc_meeting_get import (
    GetVCMeetingReqUserIDType,
    GetVCMeetingReq,
    GetVCMeetingRespMeetingAbility,
    GetVCMeetingRespMeetingParticipant,
    GetVCMeetingRespMeetingHostUser,
    GetVCMeetingRespMeeting,
    GetVCMeetingResp,
)
from pylark.api_service_vc_meeting_invite import (
    InviteVCMeetingReqInvitee,
    InviteVCMeetingReqUserIDType,
    InviteVCMeetingReq,
    InviteVCMeetingRespInviteResult,
    InviteVCMeetingResp,
)
from pylark.api_service_vc_meeting_recording_get import (
    GetVCMeetingRecordingReq,
    GetVCMeetingRecordingRespRecording,
    GetVCMeetingRecordingResp,
)
from pylark.api_service_vc_meeting_recording_set_permission import (
    SetVCPermissionMeetingRecordingReqPermissionObject,
    SetVCPermissionMeetingRecordingReqUserIDType,
    SetVCPermissionMeetingRecordingReq,
    SetVCPermissionMeetingRecordingResp,
)
from pylark.api_service_vc_meeting_recording_start import (
    StartVCMeetingRecordingReq,
    StartVCMeetingRecordingResp,
)
from pylark.api_service_vc_meeting_recording_stop import (
    StopVCMeetingRecordingReq,
    StopVCMeetingRecordingResp,
)
from pylark.api_service_vc_meeting_set_host import (
    SetVCHostMeetingReqOldHostUser,
    SetVCHostMeetingReqHostUser,
    SetVCHostMeetingReqUserIDType,
    SetVCHostMeetingReq,
    SetVCHostMeetingRespHostUser,
    SetVCHostMeetingResp,
)
from pylark.api_service_vc_report_get_daily import (
    GetVCDailyReportReq,
    GetVCDailyReportRespMeetingReportDailyReport,
    GetVCDailyReportRespMeetingReport,
    GetVCDailyReportResp,
)
from pylark.api_service_vc_report_get_top_user import (
    GetVCTopUserReportReq,
    GetVCTopUserReportRespTopUserReport,
    GetVCTopUserReportResp,
)
from pylark.api_service_vc_reserve_apply import (
    ApplyVCReserveReqMeetingSettingsCallSettingCalleePstnSipInfo,
    ApplyVCReserveReqMeetingSettingsCallSettingCallee,
    ApplyVCReserveReqMeetingSettingsCallSetting,
    ApplyVCReserveReqMeetingSettingsActionPermissionPermissionChecker,
    ApplyVCReserveReqMeetingSettingsActionPermission,
    ApplyVCReserveReqMeetingSettings,
    ApplyVCReserveReqUserIDType,
    ApplyVCReserveReq,
    ApplyVCReserveRespReserve,
    ApplyVCReserveResp,
)
from pylark.api_service_vc_reserve_delete import DeleteVCReserveReq, DeleteVCReserveResp
from pylark.api_service_vc_reserve_get import (
    GetVCReserveReq,
    GetVCReserveRespReserveMeetingSettingsCallSettingCalleePstnSipInfo,
    GetVCReserveRespReserveMeetingSettingsCallSettingCallee,
    GetVCReserveRespReserveMeetingSettingsCallSetting,
    GetVCReserveRespReserveMeetingSettingsActionPermissionPermissionChecker,
    GetVCReserveRespReserveMeetingSettingsActionPermission,
    GetVCReserveRespReserveMeetingSettings,
    GetVCReserveRespReserve,
    GetVCReserveResp,
)
from pylark.api_service_vc_reserve_get_active_meeting import (
    GetVCReserveActiveMeetingReq,
    GetVCReserveActiveMeetingRespMeetingAbility,
    GetVCReserveActiveMeetingRespMeetingParticipant,
    GetVCReserveActiveMeetingRespMeetingHostUser,
    GetVCReserveActiveMeetingRespMeeting,
    GetVCReserveActiveMeetingResp,
)
from pylark.api_service_vc_reserve_update import (
    UpdateVCReserveReqMeetingSettingsCallSettingCalleePstnSipInfo,
    UpdateVCReserveReqMeetingSettingsCallSettingCallee,
    UpdateVCReserveReqMeetingSettingsCallSetting,
    UpdateVCReserveReqMeetingSettingsActionPermissionPermissionChecker,
    UpdateVCReserveReqMeetingSettingsActionPermission,
    UpdateVCReserveReqMeetingSettings,
    UpdateVCReserveReqUserIDType,
    UpdateVCReserveReq,
    UpdateVCReserveRespReserve,
    UpdateVCReserveResp,
)
from pylark.api_service_vc_room_config_get import (
    GetVCRoomConfigReq,
    GetVCRoomConfigRespDigitalSignageMaterial,
    GetVCRoomConfigRespDigitalSignage,
    GetVCRoomConfigResp,
)
from pylark.api_service_vc_room_config_set import (
    SetVCRoomConfigReqRoomConfigDigitalSignageMaterial,
    SetVCRoomConfigReqRoomConfigDigitalSignage,
    SetVCRoomConfigReqRoomConfig,
    SetVCRoomConfigReq,
    SetVCRoomConfigResp,
)
from pylark.lark import Lark
from pylark.lark_exception import PyLarkError
from pylark.lark_request import Response, MethodOption, RawRequestReq, Request
from pylark.type import DepartmentIDType
from pylark.type_message_post import (
    MessageContentPostItem,
    MessageContentPost,
    MessageContentPostAll,
)
from pylark.log import logger


__version__ = "0.0.6"

__all__ = [
    LarkACSService,
    GetACSAccessRecordListReqUserIDType,
    GetACSAccessRecordListReq,
    GetACSAccessRecordListRespItem,
    GetACSAccessRecordListResp,
    GetACSAccessRecordPhotoReq,
    GetACSAccessRecordPhotoRespFile,
    GetACSAccessRecordPhotoResp,
    GetACSAccessRecordPhotoResp,
    GetACSDeviceListReq,
    GetACSDeviceListRespItem,
    GetACSDeviceListResp,
    GetACSUserFaceReqUserIDType,
    GetACSUserFaceReq,
    GetACSUserFaceRespFile,
    GetACSUserFaceResp,
    GetACSUserFaceResp,
    UpdateACSUserFaceReqFileType,
    UpdateACSUserFaceReqFiles,
    UpdateACSUserFaceReqUserIDType,
    UpdateACSUserFaceReq,
    UpdateACSUserFaceResp,
    GetACSUserReqUserIDType,
    GetACSUserReq,
    GetACSUserRespUserFeature,
    GetACSUserRespUser,
    GetACSUserResp,
    GetACSUserListReqUserIDType,
    GetACSUserListReq,
    GetACSUserListRespItemFeature,
    GetACSUserListRespItem,
    GetACSUserListResp,
    UpdateACSUserReqFeature,
    UpdateACSUserReqUserIDType,
    UpdateACSUserReq,
    UpdateACSUserResp,
    LarkAdminService,
    GetAdminDeptStatsReqDepartmentIDType,
    GetAdminDeptStatsReq,
    GetAdminDeptStatsRespItem,
    GetAdminDeptStatsResp,
    GetAdminUserStatsReqDepartmentIDType,
    GetAdminUserStatsReqUserIDType,
    GetAdminUserStatsReq,
    GetAdminUserStatsRespItem,
    GetAdminUserStatsResp,
    LarkAIService,
    DetectFaceAttributesReq,
    DetectFaceAttributesRespFaceInfoQualityOccludeRightEye,
    DetectFaceAttributesRespFaceInfoQualityOccludeLeftEye,
    DetectFaceAttributesRespFaceInfoQualityOccludeChin,
    DetectFaceAttributesRespFaceInfoQualityOccludeMouth,
    DetectFaceAttributesRespFaceInfoQualityOccludeCheek,
    DetectFaceAttributesRespFaceInfoQualityOccludeNose,
    DetectFaceAttributesRespFaceInfoQualityOccludeEyebrow,
    DetectFaceAttributesRespFaceInfoQualityOcclude,
    DetectFaceAttributesRespFaceInfoQualityBrightness,
    DetectFaceAttributesRespFaceInfoQualitySharpness,
    DetectFaceAttributesRespFaceInfoQuality,
    DetectFaceAttributesRespFaceInfoAttributeMaskProbability,
    DetectFaceAttributesRespFaceInfoAttributeMask,
    DetectFaceAttributesRespFaceInfoAttributeGlassProbability,
    DetectFaceAttributesRespFaceInfoAttributeGlass,
    DetectFaceAttributesRespFaceInfoAttributeHatProbability,
    DetectFaceAttributesRespFaceInfoAttributeHat,
    DetectFaceAttributesRespFaceInfoAttributePose,
    DetectFaceAttributesRespFaceInfoAttributeEmotionProbability,
    DetectFaceAttributesRespFaceInfoAttributeEmotion,
    DetectFaceAttributesRespFaceInfoAttributeGenderProbability,
    DetectFaceAttributesRespFaceInfoAttributeGender,
    DetectFaceAttributesRespFaceInfoAttribute,
    DetectFaceAttributesRespFaceInfoPositionLowerRightY,
    DetectFaceAttributesRespFaceInfoPositionLowerRightX,
    DetectFaceAttributesRespFaceInfoPositionLowerRight,
    DetectFaceAttributesRespFaceInfoPositionUpperLeftY,
    DetectFaceAttributesRespFaceInfoPositionUpperLeftX,
    DetectFaceAttributesRespFaceInfoPositionUpperLeft,
    DetectFaceAttributesRespFaceInfoPosition,
    DetectFaceAttributesRespFaceInfo,
    DetectFaceAttributesRespImageInfo,
    DetectFaceAttributesResp,
    DetectTextLanguageReq,
    DetectTextLanguageResp,
    RecognizeBasicImageReq,
    RecognizeBasicImageResp,
    RecognizeSpeechFileReqConfig,
    RecognizeSpeechFileReqSpeech,
    RecognizeSpeechFileReq,
    RecognizeSpeechFileResp,
    RecognizeSpeechStreamReqConfig,
    RecognizeSpeechStreamReqSpeech,
    RecognizeSpeechStreamReq,
    RecognizeSpeechStreamResp,
    TranslateTextReqGlossary,
    TranslateTextReq,
    TranslateTextResp,
    LarkApplicationService,
    GetApplicationAppAdminUserListReq,
    GetApplicationAppAdminUserListRespUserOpenID,
    GetApplicationAppAdminUserListRespUser,
    GetApplicationAppAdminUserListResp,
    GetApplicationAppListReq,
    GetApplicationAppListRespAppList,
    GetApplicationAppListResp,
    GetApplicationAppVisibilityReq,
    GetApplicationAppVisibilityRespUsers,
    GetApplicationAppVisibilityRespDepartments,
    GetApplicationAppVisibilityResp,
    UpdateApplicationAppVisibilityReqAddUsers,
    UpdateApplicationAppVisibilityReqDelUsers,
    UpdateApplicationAppVisibilityReq,
    UpdateApplicationAppVisibilityResp,
    IsApplicationUserAdminReq,
    IsApplicationUserAdminResp,
    GetApplicationMessageDetailReq,
    GetApplicationMessageDetailRespUsersRead,
    GetApplicationMessageDetailRespTarget,
    GetApplicationMessageDetailRespMessageType,
    GetApplicationMessageDetailRespChatType,
    GetApplicationMessageDetailResp,
    GetApplicationMessageOverviewReqMessageType,
    GetApplicationMessageOverviewReqChatType,
    GetApplicationMessageOverviewReq,
    GetApplicationMessageOverviewRespGroupReadPv,
    GetApplicationMessageOverviewRespGroupRead,
    GetApplicationMessageOverviewRespGroupReceivedPv,
    GetApplicationMessageOverviewRespGroupReceived,
    GetApplicationMessageOverviewRespGroupSentPv,
    GetApplicationMessageOverviewRespGroupSent,
    GetApplicationMessageOverviewRespP2pReadPv,
    GetApplicationMessageOverviewRespP2pRead,
    GetApplicationMessageOverviewRespP2pReceivedPv,
    GetApplicationMessageOverviewRespP2pReceived,
    GetApplicationMessageOverviewRespP2pSentPv,
    GetApplicationMessageOverviewRespP2pSent,
    GetApplicationMessageOverviewResp,
    GetApplicationMessageTrendReqMessageType,
    GetApplicationMessageTrendReqChatType,
    GetApplicationMessageTrendReq,
    GetApplicationMessageTrendRespGroupReadTimestamp,
    GetApplicationMessageTrendRespGroupRead,
    GetApplicationMessageTrendRespGroupReceivedTimestamp,
    GetApplicationMessageTrendRespGroupReceived,
    GetApplicationMessageTrendRespGroupSentTimestamp,
    GetApplicationMessageTrendRespGroupSent,
    GetApplicationMessageTrendRespP2pReadTimestamp,
    GetApplicationMessageTrendRespP2pRead,
    GetApplicationMessageTrendRespP2pReceivedTimestamp,
    GetApplicationMessageTrendRespP2pReceived,
    GetApplicationMessageTrendRespP2pSentTimestamp,
    GetApplicationMessageTrendRespP2pSent,
    GetApplicationMessageTrendResp,
    GetApplicationOrderReq,
    GetApplicationOrderRespOrder,
    GetApplicationOrderResp,
    GetApplicationOrderListReq,
    GetApplicationOrderListRespOrderList,
    GetApplicationOrderListResp,
    CheckUserIsInApplicationPaidScopeReq,
    CheckUserIsInApplicationPaidScopeResp,
    GetApplicationUsageDetailReqFilter,
    GetApplicationUsageDetailReq,
    GetApplicationUsageDetailRespUser,
    GetApplicationUsageDetailResp,
    GetApplicationUsageOverviewReqFilter,
    GetApplicationUsageOverviewReq,
    GetApplicationUsageOverviewRespItem,
    GetApplicationUsageOverviewResp,
    GetApplicationUsageTrendReqFilter,
    GetApplicationUsageTrendReq,
    GetApplicationUsageTrendRespItemTrend,
    GetApplicationUsageTrendRespItem,
    GetApplicationUsageTrendResp,
    GetApplicationUserAdminScopeReq,
    GetApplicationUserAdminScopeResp,
    GetApplicationUserVisibleAppReq,
    GetApplicationUserVisibleAppRespAppList,
    GetApplicationUserVisibleAppResp,
    LarkApprovalService,
    GetApprovalReq,
    GetApprovalRespViewer,
    GetApprovalRespNode,
    GetApprovalRespForm,
    GetApprovalResp,
    CreateApprovalCarbonCopyReq,
    CreateApprovalCarbonCopyResp,
    SearchApprovalCarbonCopyReq,
    SearchApprovalCarbonCopyRespCcLink,
    SearchApprovalCarbonCopyRespCc,
    SearchApprovalCarbonCopyRespInstanceLink,
    SearchApprovalCarbonCopyRespInstance,
    SearchApprovalCarbonCopyRespGroup,
    SearchApprovalCarbonCopyRespApprovalExternal,
    SearchApprovalCarbonCopyRespApproval,
    SearchApprovalCarbonCopyResp,
    SearchApprovalCarbonCopyResp,
    UploadApprovalFileReqContent,
    UploadApprovalFileReq,
    UploadApprovalFileResp,
    ApproveApprovalInstanceReq,
    ApproveApprovalInstanceResp,
    CancelApprovalInstanceReq,
    CancelApprovalInstanceResp,
    CreateApprovalInstanceReqNodeApproverOpenIDList,
    CreateApprovalInstanceReqNodeApproverUserIDList,
    CreateApprovalInstanceReqForm,
    CreateApprovalInstanceReq,
    CreateApprovalInstanceResp,
    GetApprovalInstanceReq,
    GetApprovalInstanceRespTimelineExt,
    GetApprovalInstanceRespTimelineCcUser,
    GetApprovalInstanceRespTimeline,
    GetApprovalInstanceRespComment,
    GetApprovalInstanceRespTask,
    GetApprovalInstanceRespForm,
    GetApprovalInstanceResp,
    GetApprovalInstanceListReq,
    GetApprovalInstanceListResp,
    RejectApprovalInstanceReq,
    RejectApprovalInstanceResp,
    SearchApprovalInstanceReq,
    SearchApprovalInstanceRespInstanceInstanceLink,
    SearchApprovalInstanceRespInstanceInstance,
    SearchApprovalInstanceRespInstanceApprovalGroup,
    SearchApprovalInstanceRespInstanceApprovalExternal,
    SearchApprovalInstanceRespInstanceApproval,
    SearchApprovalInstanceRespInstance,
    SearchApprovalInstanceResp,
    TransferApprovalInstanceReq,
    TransferApprovalInstanceResp,
    SearchApprovalTaskReq,
    SearchApprovalTaskRespTaskTaskLink,
    SearchApprovalTaskRespTaskTask,
    SearchApprovalTaskRespTaskInstanceLink,
    SearchApprovalTaskRespTaskInstance,
    SearchApprovalTaskRespTaskGroup,
    SearchApprovalTaskRespTaskApprovalExternal,
    SearchApprovalTaskRespTaskApproval,
    SearchApprovalTaskRespTask,
    SearchApprovalTaskResp,
    LarkAttendanceService,
    DownloadAttendanceFileReq,
    DownloadAttendanceFileRespFile,
    DownloadAttendanceFileResp,
    DownloadAttendanceFileResp,
    UploadAttendanceFileReqFile,
    UploadAttendanceFileReq,
    UploadAttendanceFileRespFile,
    UploadAttendanceFileResp,
    CreateUpdateAttendanceGroupReqGroupNoNeedPunchSpecialDay,
    CreateUpdateAttendanceGroupReqGroupNeedPunchSpecialDay,
    CreateUpdateAttendanceGroupReqGroupFreePunchCfg,
    CreateUpdateAttendanceGroupReqGroupLocationLongitude,
    CreateUpdateAttendanceGroupReqGroupLocationLatitude,
    CreateUpdateAttendanceGroupReqGroupLocation,
    CreateUpdateAttendanceGroupReqGroupMachine,
    CreateUpdateAttendanceGroupReqGroup,
    CreateUpdateAttendanceGroupReqEmployeeType,
    CreateUpdateAttendanceGroupReq,
    CreateUpdateAttendanceGroupRespGroupNoNeedPunchSpecialDay,
    CreateUpdateAttendanceGroupRespGroupNeedPunchSpecialDay,
    CreateUpdateAttendanceGroupRespGroupFreePunchCfg,
    CreateUpdateAttendanceGroupRespGroupLocationLongitude,
    CreateUpdateAttendanceGroupRespGroupLocationLatitude,
    CreateUpdateAttendanceGroupRespGroupLocation,
    CreateUpdateAttendanceGroupRespGroupMachine,
    CreateUpdateAttendanceGroupRespGroup,
    CreateUpdateAttendanceGroupResp,
    DeleteAttendanceGroupReq,
    DeleteAttendanceGroupResp,
    GetAttendanceGroupReqEmployeeType,
    GetAttendanceGroupReq,
    GetAttendanceGroupRespGroupIDNoNeedPunchSpecialDay,
    GetAttendanceGroupRespGroupIDNeedPunchSpecialDay,
    GetAttendanceGroupRespGroupIDFreePunchCfg,
    GetAttendanceGroupRespGroupIDLocationLongitude,
    GetAttendanceGroupRespGroupIDLocationLatitude,
    GetAttendanceGroupRespGroupIDLocation,
    GetAttendanceGroupRespGroupIDMachine,
    GetAttendanceGroupRespGroupID,
    GetAttendanceGroupResp,
    InitAttendanceRemedyApprovalReqEmployeeType,
    InitAttendanceRemedyApprovalReq,
    InitAttendanceRemedyApprovalRespUserRemedy,
    InitAttendanceRemedyApprovalResp,
    UpdateAttendanceRemedyApprovalReq,
    UpdateAttendanceRemedyApprovalRespApprovalInfo,
    UpdateAttendanceRemedyApprovalResp,
    CreateAttendanceShiftReqRestTimeRule,
    CreateAttendanceShiftReqLateOffLateOnRule,
    CreateAttendanceShiftReqPunchTimeRule,
    CreateAttendanceShiftReq,
    CreateAttendanceShiftRespShiftRestTimeRule,
    CreateAttendanceShiftRespShiftLateOffLateOnRule,
    CreateAttendanceShiftRespShiftPunchTimeRule,
    CreateAttendanceShiftRespShift,
    CreateAttendanceShiftResp,
    DeleteAttendanceShiftReq,
    DeleteAttendanceShiftResp,
    GetAttendanceShiftByIDReq,
    GetAttendanceShiftByIDRespRestTimeRule,
    GetAttendanceShiftByIDRespLateOffLateOnRule,
    GetAttendanceShiftByIDRespPunchTimeRule,
    GetAttendanceShiftByIDResp,
    GetAttendanceShiftByNameReq,
    GetAttendanceShiftByNameRespRestTimeRule,
    GetAttendanceShiftByNameRespLateOffLateOnRule,
    GetAttendanceShiftByNameRespPunchTimeRule,
    GetAttendanceShiftByNameResp,
    GetAttendanceStatisticsDataReqEmployeeType,
    GetAttendanceStatisticsDataReq,
    GetAttendanceStatisticsDataRespUserDataDataFeature,
    GetAttendanceStatisticsDataRespUserDataData,
    GetAttendanceStatisticsDataRespUserData,
    GetAttendanceStatisticsDataResp,
    GetAttendanceStatisticsHeaderReqEmployeeType,
    GetAttendanceStatisticsHeaderReq,
    GetAttendanceStatisticsHeaderRespUserStatsFieldFieldChildField,
    GetAttendanceStatisticsHeaderRespUserStatsFieldField,
    GetAttendanceStatisticsHeaderRespUserStatsField,
    GetAttendanceStatisticsHeaderResp,
    GetAttendanceUserAllowedRemedyReqEmployeeType,
    GetAttendanceUserAllowedRemedyReq,
    GetAttendanceUserAllowedRemedyRespUserAllowedRemedys,
    GetAttendanceUserAllowedRemedyResp,
    CreateAttendanceUserApprovalReqUserApprovalTrip,
    CreateAttendanceUserApprovalReqUserApprovalOvertimeWorkDuration,
    CreateAttendanceUserApprovalReqUserApprovalOvertimeWork,
    CreateAttendanceUserApprovalReqUserApprovalLeaveI18nNames,
    CreateAttendanceUserApprovalReqUserApprovalLeave,
    CreateAttendanceUserApprovalReqUserApprovalOutI18nNamesJa,
    CreateAttendanceUserApprovalReqUserApprovalOutI18nNames,
    CreateAttendanceUserApprovalReqUserApprovalOut,
    CreateAttendanceUserApprovalReqUserApproval,
    CreateAttendanceUserApprovalReqEmployeeType,
    CreateAttendanceUserApprovalReq,
    CreateAttendanceUserApprovalRespUserApprovalTrip,
    CreateAttendanceUserApprovalRespUserApprovalOvertimeWorkDuration,
    CreateAttendanceUserApprovalRespUserApprovalOvertimeWork,
    CreateAttendanceUserApprovalRespUserApprovalLeaveI18nNames,
    CreateAttendanceUserApprovalRespUserApprovalLeave,
    CreateAttendanceUserApprovalRespUserApprovalOutI18nNames,
    CreateAttendanceUserApprovalRespUserApprovalOut,
    CreateAttendanceUserApprovalRespUserApproval,
    CreateAttendanceUserApprovalResp,
    GetAttendanceUserApprovalReqEmployeeType,
    GetAttendanceUserApprovalReq,
    GetAttendanceUserApprovalRespUserApprovalTrip,
    GetAttendanceUserApprovalRespUserApprovalOvertimeWorkDuration,
    GetAttendanceUserApprovalRespUserApprovalOvertimeWork,
    GetAttendanceUserApprovalRespUserApprovalLeaveI18nNames,
    GetAttendanceUserApprovalRespUserApprovalLeave,
    GetAttendanceUserApprovalRespUserApprovalOutI18nNames,
    GetAttendanceUserApprovalRespUserApprovalOut,
    GetAttendanceUserApprovalRespUserApproval,
    GetAttendanceUserApprovalResp,
    CreateUpdateAttendanceUserDailyShiftReqUserDailyShift,
    CreateUpdateAttendanceUserDailyShiftReqEmployeeType,
    CreateUpdateAttendanceUserDailyShiftReq,
    CreateUpdateAttendanceUserDailyShiftRespUserDailyShift,
    CreateUpdateAttendanceUserDailyShiftResp,
    GetAttendanceUserDailyShiftReqEmployeeType,
    GetAttendanceUserDailyShiftReq,
    GetAttendanceUserDailyShiftRespUserDailyShift,
    GetAttendanceUserDailyShiftResp,
    BatchCreateAttendanceUserFlowReqFlowRecord,
    BatchCreateAttendanceUserFlowReqEmployeeType,
    BatchCreateAttendanceUserFlowReq,
    BatchCreateAttendanceUserFlowRespFlowRecord,
    BatchCreateAttendanceUserFlowResp,
    BatchGetAttendanceUserFlowReqEmployeeType,
    BatchGetAttendanceUserFlowReq,
    BatchGetAttendanceUserFlowRespUserFlowResultLatitude,
    BatchGetAttendanceUserFlowRespUserFlowResultLongitude,
    BatchGetAttendanceUserFlowRespUserFlowResult,
    BatchGetAttendanceUserFlowResp,
    GetAttendanceUserFlowReqEmployeeType,
    GetAttendanceUserFlowReq,
    GetAttendanceUserFlowRespLatitude,
    GetAttendanceUserFlowRespLongitude,
    GetAttendanceUserFlowResp,
    QueryAttendanceUserSettingsReqEmployeeType,
    QueryAttendanceUserSettingsReq,
    QueryAttendanceUserSettingsRespUserSetting,
    QueryAttendanceUserSettingsResp,
    UpdateAttendanceUserSettingsReqUserSetting,
    UpdateAttendanceUserSettingsReqEmployeeType,
    UpdateAttendanceUserSettingsReq,
    UpdateAttendanceUserSettingsRespUserSetting,
    UpdateAttendanceUserSettingsResp,
    GetAttendanceUserStatisticsSettingsReqEmployeeType,
    GetAttendanceUserStatisticsSettingsReq,
    GetAttendanceUserStatisticsSettingsRespViewItemChildItem,
    GetAttendanceUserStatisticsSettingsRespViewItem,
    GetAttendanceUserStatisticsSettingsRespView,
    GetAttendanceUserStatisticsSettingsResp,
    UpdateAttendanceUserStatisticsSettingsReqViewItemChildItem,
    UpdateAttendanceUserStatisticsSettingsReqViewItem,
    UpdateAttendanceUserStatisticsSettingsReqView,
    UpdateAttendanceUserStatisticsSettingsReqEmployeeType,
    UpdateAttendanceUserStatisticsSettingsReq,
    UpdateAttendanceUserStatisticsSettingsRespViewItemChildItem,
    UpdateAttendanceUserStatisticsSettingsRespViewItem,
    UpdateAttendanceUserStatisticsSettingsRespView,
    UpdateAttendanceUserStatisticsSettingsResp,
    GetAttendanceUserTaskReqEmployeeType,
    GetAttendanceUserTaskReq,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckOutRecordLatitude,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckOutRecordLongitude,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckOutRecord,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckInRecordLatitude,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckInRecordLongitude,
    GetAttendanceUserTaskRespUserTaskResultRecordCheckInRecord,
    GetAttendanceUserTaskRespUserTaskResultRecord,
    GetAttendanceUserTaskRespUserTaskResult,
    GetAttendanceUserTaskResp,
    GetAttendanceUserTaskRemedyReqEmployeeType,
    GetAttendanceUserTaskRemedyReq,
    GetAttendanceUserTaskRemedyRespUserRemedy,
    GetAttendanceUserTaskRemedyResp,
    LarkAuthService,
    GetAccessTokenReq,
    GetAccessTokenResp,
    RefreshAccessTokenReq,
    RefreshAccessTokenResp,
    ResendAppTicketReq,
    ResendAppTicketResp,
    GetTenantAccessTokenReq,
    TokenExpire,
    GetUserInfoReq,
    GetUserInfoResp,
    LarkBitableService,
    CreateBitableFieldReqPropertyOption,
    CreateBitableFieldReqProperty,
    CreateBitableFieldReqUserIDType,
    CreateBitableFieldReq,
    CreateBitableFieldRespFieldPropertyOption,
    CreateBitableFieldRespFieldProperty,
    CreateBitableFieldRespField,
    CreateBitableFieldResp,
    DeleteBitableFieldReq,
    DeleteBitableFieldResp,
    GetBitableFieldListReq,
    GetBitableFieldListRespItemPropertyOption,
    GetBitableFieldListRespItemProperty,
    GetBitableFieldListRespItem,
    GetBitableFieldListResp,
    UpdateBitableFieldReqPropertyOption,
    UpdateBitableFieldReqProperty,
    UpdateBitableFieldReq,
    UpdateBitableFieldRespFieldPropertyOption,
    UpdateBitableFieldRespFieldProperty,
    UpdateBitableFieldRespField,
    UpdateBitableFieldResp,
    GetBitableMetaReq,
    GetBitableMetaRespApp,
    GetBitableMetaResp,
    BatchCreateBitableRecordReqRecordFieldValue,
    BatchCreateBitableRecordReqRecordField,
    BatchCreateBitableRecordReqRecord,
    BatchCreateBitableRecordReqUserIDType,
    BatchCreateBitableRecordReq,
    BatchCreateBitableRecordRespRecordFieldValue,
    BatchCreateBitableRecordRespRecordField,
    BatchCreateBitableRecordRespRecord,
    BatchCreateBitableRecordResp,
    BatchDeleteBitableRecordReq,
    BatchDeleteBitableRecordRespRecord,
    BatchDeleteBitableRecordResp,
    BatchUpdateBitableRecordReqRecordFieldValue,
    BatchUpdateBitableRecordReqRecordField,
    BatchUpdateBitableRecordReqRecord,
    BatchUpdateBitableRecordReqUserIDType,
    BatchUpdateBitableRecordReq,
    BatchUpdateBitableRecordRespRecordFieldValue,
    BatchUpdateBitableRecordRespRecordField,
    BatchUpdateBitableRecordRespRecord,
    BatchUpdateBitableRecordResp,
    CreateBitableRecordReqFieldsValue,
    CreateBitableRecordReqFields,
    CreateBitableRecordReqUserIDType,
    CreateBitableRecordReq,
    CreateBitableRecordRespRecordFieldsValue,
    CreateBitableRecordRespRecordFields,
    CreateBitableRecordRespRecord,
    CreateBitableRecordResp,
    DeleteBitableRecordReq,
    DeleteBitableRecordResp,
    GetBitableRecordReq,
    GetBitableRecordRespRecordFieldsValue,
    GetBitableRecordRespRecordFields,
    GetBitableRecordRespRecord,
    GetBitableRecordResp,
    GetBitableRecordListReq,
    GetBitableRecordListRespItemFieldsValue,
    GetBitableRecordListRespItemFields,
    GetBitableRecordListRespItem,
    GetBitableRecordListResp,
    UpdateBitableRecordReqFieldsValue,
    UpdateBitableRecordReqFields,
    UpdateBitableRecordReqUserIDType,
    UpdateBitableRecordReq,
    UpdateBitableRecordRespRecordFieldsValue,
    UpdateBitableRecordRespRecordFields,
    UpdateBitableRecordRespRecord,
    UpdateBitableRecordResp,
    BatchCreateBitableTableReqTable,
    BatchCreateBitableTableReqUserIDType,
    BatchCreateBitableTableReq,
    BatchCreateBitableTableResp,
    BatchDeleteBitableTableReq,
    BatchDeleteBitableTableResp,
    CreateBitableTableReqTable,
    CreateBitableTableReqUserIDType,
    CreateBitableTableReq,
    CreateBitableTableResp,
    DeleteBitableTableReq,
    DeleteBitableTableResp,
    GetBitableTableListReq,
    GetBitableTableListRespItem,
    GetBitableTableListResp,
    CreateBitableViewReq,
    CreateBitableViewRespApptableview,
    CreateBitableViewResp,
    DeleteBitableViewReq,
    DeleteBitableViewResp,
    GetBitableViewListReq,
    GetBitableViewListRespItem,
    GetBitableViewListResp,
    LarkBotService,
    AddBotToChatReq,
    AddBotToChatResp,
    GetBotInfoReq,
    GetBotInfoResp,
    LarkCalendarService,
    CreateCalendarACLReqScope,
    CreateCalendarACLReqRole,
    CreateCalendarACLReqUserIDType,
    CreateCalendarACLReq,
    CreateCalendarACLRespScope,
    CreateCalendarACLRespRole,
    CreateCalendarACLResp,
    DeleteCalendarACLReq,
    DeleteCalendarACLResp,
    GetCalendarACLListReqUserIDType,
    GetCalendarACLListReq,
    GetCalendarACLListRespACLScope,
    GetCalendarACLListRespACLRole,
    GetCalendarACLListRespACL,
    GetCalendarACLListResp,
    SubscribeCalendarACLReq,
    SubscribeCalendarACLResp,
    CreateCalendarReqPermissions,
    CreateCalendarReq,
    CreateCalendarRespCalendarRole,
    CreateCalendarRespCalendarType,
    CreateCalendarRespCalendarPermissions,
    CreateCalendarRespCalendar,
    CreateCalendarResp,
    DeleteCalendarReq,
    DeleteCalendarResp,
    GetCalendarEventAttendeeChatMemberListReq,
    GetCalendarEventAttendeeChatMemberListRespItem,
    GetCalendarEventAttendeeChatMemberListResp,
    CreateCalendarEventAttendeeReqAttendeeType,
    CreateCalendarEventAttendeeReqAttendee,
    CreateCalendarEventAttendeeReqUserIDType,
    CreateCalendarEventAttendeeReq,
    CreateCalendarEventAttendeeRespAttendeeChatMember,
    CreateCalendarEventAttendeeRespAttendeeType,
    CreateCalendarEventAttendeeRespAttendee,
    CreateCalendarEventAttendeeResp,
    DeleteCalendarEventAttendeeReq,
    DeleteCalendarEventAttendeeResp,
    GetCalendarEventAttendeeListReqUserIDType,
    GetCalendarEventAttendeeListReq,
    GetCalendarEventAttendeeListRespItemChatMember,
    GetCalendarEventAttendeeListRespItemType,
    GetCalendarEventAttendeeListRespItem,
    GetCalendarEventAttendeeListResp,
    CreateCalendarEventReqSchema,
    CreateCalendarEventReqReminder,
    CreateCalendarEventReqLocationLongitude,
    CreateCalendarEventReqLocationLatitude,
    CreateCalendarEventReqLocation,
    CreateCalendarEventReqVchat,
    CreateCalendarEventReqEndTime,
    CreateCalendarEventReqStartTime,
    CreateCalendarEventReq,
    CreateCalendarEventRespEventSchema,
    CreateCalendarEventRespEventReminder,
    CreateCalendarEventRespEventLocationLongitude,
    CreateCalendarEventRespEventLocationLatitude,
    CreateCalendarEventRespEventLocation,
    CreateCalendarEventRespEventVchat,
    CreateCalendarEventRespEventEndTime,
    CreateCalendarEventRespEventStartTime,
    CreateCalendarEventRespEvent,
    CreateCalendarEventResp,
    DeleteCalendarEventReq,
    DeleteCalendarEventResp,
    GetCalendarEventReq,
    GetCalendarEventRespEventSchema,
    GetCalendarEventRespEventReminder,
    GetCalendarEventRespEventLocationLongitude,
    GetCalendarEventRespEventLocationLatitude,
    GetCalendarEventRespEventLocation,
    GetCalendarEventRespEventVchat,
    GetCalendarEventRespEventEndTime,
    GetCalendarEventRespEventStartTime,
    GetCalendarEventRespEvent,
    GetCalendarEventResp,
    GetCalendarEventListReq,
    GetCalendarEventListRespItemSchema,
    GetCalendarEventListRespItemReminder,
    GetCalendarEventListRespItemLocationLongitude,
    GetCalendarEventListRespItemLocationLatitude,
    GetCalendarEventListRespItemLocation,
    GetCalendarEventListRespItemVchat,
    GetCalendarEventListRespItemEndTime,
    GetCalendarEventListRespItemStartTime,
    GetCalendarEventListRespItem,
    GetCalendarEventListResp,
    UpdateCalendarEventReqSchema,
    UpdateCalendarEventReqReminder,
    UpdateCalendarEventReqLocationLongitude,
    UpdateCalendarEventReqLocationLatitude,
    UpdateCalendarEventReqLocation,
    UpdateCalendarEventReqVchat,
    UpdateCalendarEventReqEndTime,
    UpdateCalendarEventReqStartTime,
    UpdateCalendarEventReq,
    UpdateCalendarEventRespEventSchema,
    UpdateCalendarEventRespEventReminder,
    UpdateCalendarEventRespEventLocationLongitude,
    UpdateCalendarEventRespEventLocationLatitude,
    UpdateCalendarEventRespEventLocation,
    UpdateCalendarEventRespEventVchat,
    UpdateCalendarEventRespEventEndTime,
    UpdateCalendarEventRespEventStartTime,
    UpdateCalendarEventRespEvent,
    UpdateCalendarEventResp,
    SearchCalendarEventReqFilterEndTime,
    SearchCalendarEventReqFilterStartTime,
    SearchCalendarEventReqFilter,
    SearchCalendarEventReqUserIDType,
    SearchCalendarEventReq,
    SearchCalendarEventRespItemSchema,
    SearchCalendarEventRespItemReminder,
    SearchCalendarEventRespItemLocationLongitude,
    SearchCalendarEventRespItemLocationLatitude,
    SearchCalendarEventRespItemLocation,
    SearchCalendarEventRespItemVchat,
    SearchCalendarEventRespItemEndTime,
    SearchCalendarEventRespItemStartTime,
    SearchCalendarEventRespItem,
    SearchCalendarEventResp,
    SubscribeCalendarEventReq,
    SubscribeCalendarEventResp,
    GetCalendarFreeBusyListReqUserIDType,
    GetCalendarFreeBusyListReq,
    GetCalendarFreeBusyListRespFreebusy,
    GetCalendarFreeBusyListResp,
    GetCalendarReq,
    GetCalendarRespRole,
    GetCalendarRespType,
    GetCalendarRespPermissions,
    GetCalendarResp,
    GetCalendarListReq,
    GetCalendarListRespCalendarRole,
    GetCalendarListRespCalendarType,
    GetCalendarListRespCalendarPermissions,
    GetCalendarListRespCalendar,
    GetCalendarListResp,
    UpdateCalendarReqPermissions,
    UpdateCalendarReq,
    UpdateCalendarRespCalendarRole,
    UpdateCalendarRespCalendarType,
    UpdateCalendarRespCalendarPermissions,
    UpdateCalendarRespCalendar,
    UpdateCalendarResp,
    SearchCalendarReq,
    SearchCalendarRespItemRole,
    SearchCalendarRespItemType,
    SearchCalendarRespItemPermissions,
    SearchCalendarRespItem,
    SearchCalendarResp,
    SubscribeCalendarReq,
    SubscribeCalendarRespCalendarRole,
    SubscribeCalendarRespCalendarType,
    SubscribeCalendarRespCalendarPermissions,
    SubscribeCalendarRespCalendar,
    SubscribeCalendarResp,
    SubscribeCalendarChangeEventReq,
    SubscribeCalendarChangeEventResp,
    CreateCalendarTimeoffEventReqUserIDType,
    CreateCalendarTimeoffEventReq,
    CreateCalendarTimeoffEventResp,
    DeleteCalendarTimeoffEventReq,
    DeleteCalendarTimeoffEventResp,
    UnsubscribeCalendarReq,
    UnsubscribeCalendarResp,
    GenerateCaldavConfReq,
    GenerateCaldavConfResp,
    LarkChatService,
    GetChatAnnouncementReqUserIDType,
    GetChatAnnouncementReq,
    GetChatAnnouncementRespModifierIDType,
    GetChatAnnouncementRespOwnerIDType,
    GetChatAnnouncementResp,
    UpdateChatAnnouncementReq,
    UpdateChatAnnouncementResp,
    CreateChatReqMembershipApproval,
    CreateChatReqLeaveMessageVisibility,
    CreateChatReqJoinMessageVisibility,
    CreateChatReqChatType,
    CreateChatReqI18nNames,
    CreateChatReq,
    CreateChatRespModerationPermission,
    CreateChatRespMembershipApproval,
    CreateChatRespLeaveMessageVisibility,
    CreateChatRespJoinMessageVisibility,
    CreateChatRespChatType,
    CreateChatRespEditPermission,
    CreateChatRespAtAllPermission,
    CreateChatRespShareCardPermission,
    CreateChatRespAddMemberPermission,
    CreateChatRespI18nNames,
    CreateChatResp,
    DeleteChatReq,
    DeleteChatResp,
    GetChatReqUserIDType,
    GetChatReq,
    GetChatRespModerationPermission,
    GetChatRespMembershipApproval,
    GetChatRespLeaveMessageVisibility,
    GetChatRespJoinMessageVisibility,
    GetChatRespChatType,
    GetChatRespOwnerIDType,
    GetChatRespEditPermission,
    GetChatRespAtAllPermission,
    GetChatRespShareCardPermission,
    GetChatRespAddMemberPermission,
    GetChatRespI18nNames,
    GetChatResp,
    GetChatListOfSelfReqUserIDType,
    GetChatListOfSelfReq,
    GetChatListOfSelfRespItemOwnerIDType,
    GetChatListOfSelfRespItem,
    GetChatListOfSelfResp,
    JoinChatReq,
    JoinChatResp,
    AddChatMemberReqMemberIDType,
    AddChatMemberReq,
    AddChatMemberResp,
    DeleteChatMemberReqMemberIDType,
    DeleteChatMemberReq,
    DeleteChatMemberResp,
    GetChatMemberListReqMemberIDType,
    GetChatMemberListReq,
    GetChatMemberListRespItemMemberIDType,
    GetChatMemberListRespItem,
    GetChatMemberListResp,
    IsInChatReq,
    IsInChatResp,
    SearchChatReqUserIDType,
    SearchChatReq,
    SearchChatRespItemOwnerIDType,
    SearchChatRespItem,
    SearchChatResp,
    UpdateChatReqMembershipApproval,
    UpdateChatReqLeaveMessageVisibility,
    UpdateChatReqJoinMessageVisibility,
    UpdateChatReqEditPermission,
    UpdateChatReqAtAllPermission,
    UpdateChatReqShareCardPermission,
    UpdateChatReqAddMemberPermission,
    UpdateChatReqI18nNames,
    UpdateChatReqUserIDType,
    UpdateChatReq,
    UpdateChatResp,
    LarkContactService,
    GetContactCustomAttrListReq,
    GetContactCustomAttrListRespItemI18nName,
    GetContactCustomAttrListRespItemOptionsOption,
    GetContactCustomAttrListRespItemOptions,
    GetContactCustomAttrListRespItem,
    GetContactCustomAttrListResp,
    CreateDepartmentReqI18nName,
    CreateDepartmentReqDepartmentIDType,
    CreateDepartmentReqUserIDType,
    CreateDepartmentReq,
    CreateDepartmentRespDepartmentStatus,
    CreateDepartmentRespDepartmentI18nName,
    CreateDepartmentRespDepartment,
    CreateDepartmentResp,
    DeleteDepartmentReqDepartmentIDType,
    DeleteDepartmentReq,
    DeleteDepartmentResp,
    GetDepartmentReqDepartmentIDType,
    GetDepartmentReqUserIDType,
    GetDepartmentReq,
    GetDepartmentRespDepartmentStatus,
    GetDepartmentRespDepartmentI18nName,
    GetDepartmentRespDepartment,
    GetDepartmentResp,
    GetDepartmentListReqDepartmentIDType,
    GetDepartmentListReqUserIDType,
    GetDepartmentListReq,
    GetDepartmentListRespItemStatus,
    GetDepartmentListRespItemI18nName,
    GetDepartmentListRespItem,
    GetDepartmentListResp,
    GetParentDepartmentReqDepartmentIDType,
    GetParentDepartmentReqUserIDType,
    GetParentDepartmentReq,
    GetParentDepartmentRespItemStatus,
    GetParentDepartmentRespItemI18nName,
    GetParentDepartmentRespItem,
    GetParentDepartmentResp,
    SearchDepartmentReqDepartmentIDType,
    SearchDepartmentReqUserIDType,
    SearchDepartmentReq,
    SearchDepartmentRespItemStatus,
    SearchDepartmentRespItemI18nName,
    SearchDepartmentRespItem,
    SearchDepartmentResp,
    UpdateDepartmentReqI18nName,
    UpdateDepartmentReqDepartmentIDType,
    UpdateDepartmentReqUserIDType,
    UpdateDepartmentReq,
    UpdateDepartmentRespDepartmentStatus,
    UpdateDepartmentRespDepartmentI18nName,
    UpdateDepartmentRespDepartment,
    UpdateDepartmentResp,
    UpdateDepartmentPatchReqI18nName,
    UpdateDepartmentPatchReqDepartmentIDType,
    UpdateDepartmentPatchReqUserIDType,
    UpdateDepartmentPatchReq,
    UpdateDepartmentPatchRespDepartmentStatus,
    UpdateDepartmentPatchRespDepartmentI18nName,
    UpdateDepartmentPatchRespDepartment,
    UpdateDepartmentPatchResp,
    CreateEmployeeTypeEnumReqI18nContent,
    CreateEmployeeTypeEnumReq,
    CreateEmployeeTypeEnumRespEmployeeTypeEnumI18nContent,
    CreateEmployeeTypeEnumRespEmployeeTypeEnum,
    CreateEmployeeTypeEnumResp,
    DeleteEmployeeTypeEnumReq,
    DeleteEmployeeTypeEnumResp,
    GetEmployeeTypeEnumListReq,
    GetEmployeeTypeEnumListRespItemI18nContent,
    GetEmployeeTypeEnumListRespItem,
    GetEmployeeTypeEnumListResp,
    UpdateEmployeeTypeEnumPatchReqI18nContent,
    UpdateEmployeeTypeEnumPatchReq,
    UpdateEmployeeTypeEnumPatchRespEmployeeTypeEnumI18nContent,
    UpdateEmployeeTypeEnumPatchRespEmployeeTypeEnum,
    UpdateEmployeeTypeEnumPatchResp,
    CreateUserReqNotificationOption,
    CreateUserReqCustomAttrValueGenericUser,
    CreateUserReqCustomAttrValue,
    CreateUserReqCustomAttr,
    CreateUserReqOrder,
    CreateUserReqDepartmentIDType,
    CreateUserReqUserIDType,
    CreateUserReq,
    CreateUserRespUserNotificationOption,
    CreateUserRespUserCustomAttrValueGenericUser,
    CreateUserRespUserCustomAttrValue,
    CreateUserRespUserCustomAttr,
    CreateUserRespUserOrder,
    CreateUserRespUserStatus,
    CreateUserRespUserAvatar,
    CreateUserRespUser,
    CreateUserResp,
    DeleteUserReqUserIDType,
    DeleteUserReq,
    DeleteUserResp,
    GetUserReqDepartmentIDType,
    GetUserReqUserIDType,
    GetUserReq,
    GetUserRespUserCustomAttrValueGenericUser,
    GetUserRespUserCustomAttrValue,
    GetUserRespUserCustomAttr,
    GetUserRespUserOrder,
    GetUserRespUserStatus,
    GetUserRespUserAvatar,
    GetUserRespUser,
    GetUserResp,
    BatchGetUserReq,
    BatchGetUserRespUserInfoCustomAttr,
    BatchGetUserRespUserInfo,
    BatchGetUserResp,
    BatchGetUserByIDReq,
    BatchGetUserByIDRespEmailUser,
    BatchGetUserByIDRespEmailUser,
    BatchGetUserByIDResp,
    GetUserListReqDepartmentIDType,
    GetUserListReqUserIDType,
    GetUserListReq,
    GetUserListRespItemCustomAttrValueGenericUser,
    GetUserListRespItemCustomAttrValue,
    GetUserListRespItemCustomAttr,
    GetUserListRespItemOrder,
    GetUserListRespItemStatus,
    GetUserListRespItemAvatar,
    GetUserListRespItem,
    GetUserListResp,
    UpdateUserReqCustomAttrValueGenericUser,
    UpdateUserReqCustomAttrValue,
    UpdateUserReqCustomAttr,
    UpdateUserReqOrder,
    UpdateUserReqDepartmentIDType,
    UpdateUserReqUserIDType,
    UpdateUserReq,
    UpdateUserRespUserNotificationOption,
    UpdateUserRespUserCustomAttrValueGenericUser,
    UpdateUserRespUserCustomAttrValue,
    UpdateUserRespUserCustomAttr,
    UpdateUserRespUserOrder,
    UpdateUserRespUserStatus,
    UpdateUserRespUserAvatar,
    UpdateUserRespUser,
    UpdateUserResp,
    UpdateUserPatchReqCustomAttrValueGenericUser,
    UpdateUserPatchReqCustomAttrValue,
    UpdateUserPatchReqCustomAttr,
    UpdateUserPatchReqOrder,
    UpdateUserPatchReqDepartmentIDType,
    UpdateUserPatchReqUserIDType,
    UpdateUserPatchReq,
    UpdateUserPatchRespUserNotificationOption,
    UpdateUserPatchRespUserCustomAttrValueGenericUser,
    UpdateUserPatchRespUserCustomAttrValue,
    UpdateUserPatchRespUserCustomAttr,
    UpdateUserPatchRespUserOrder,
    UpdateUserPatchRespUserStatus,
    UpdateUserPatchRespUserAvatar,
    UpdateUserPatchRespUser,
    UpdateUserPatchResp,
    LarkDriveService,
    CreateDriveCommentReqReplyListReplyContentElementPerson,
    CreateDriveCommentReqReplyListReplyContentElementDocsLink,
    CreateDriveCommentReqReplyListReplyContentElementTextRun,
    CreateDriveCommentReqReplyListReplyContentElement,
    CreateDriveCommentReqReplyListReplyContent,
    CreateDriveCommentReqReplyListReply,
    CreateDriveCommentReqReplyList,
    CreateDriveCommentReqUserIDType,
    CreateDriveCommentReqFileType,
    CreateDriveCommentReq,
    CreateDriveCommentRespReplyListReplyContentElementPerson,
    CreateDriveCommentRespReplyListReplyContentElementDocsLink,
    CreateDriveCommentRespReplyListReplyContentElementTextRun,
    CreateDriveCommentRespReplyListReplyContentElement,
    CreateDriveCommentRespReplyListReplyContent,
    CreateDriveCommentRespReplyListReply,
    CreateDriveCommentRespReplyList,
    CreateDriveCommentResp,
    DeleteDriveCommentReqFileType,
    DeleteDriveCommentReq,
    DeleteDriveCommentResp,
    GetDriveCommentReqUserIDType,
    GetDriveCommentReqFileType,
    GetDriveCommentReq,
    GetDriveCommentRespReplyListReplyContentElementPerson,
    GetDriveCommentRespReplyListReplyContentElementDocsLink,
    GetDriveCommentRespReplyListReplyContentElementTextRun,
    GetDriveCommentRespReplyListReplyContentElement,
    GetDriveCommentRespReplyListReplyContent,
    GetDriveCommentRespReplyListReply,
    GetDriveCommentRespReplyList,
    GetDriveCommentResp,
    GetDriveCommentListReqUserIDType,
    GetDriveCommentListReqFileType,
    GetDriveCommentListReq,
    GetDriveCommentListRespItemReplyListReplyContentElementPerson,
    GetDriveCommentListRespItemReplyListReplyContentElementDocsLink,
    GetDriveCommentListRespItemReplyListReplyContentElementTextRun,
    GetDriveCommentListRespItemReplyListReplyContentElement,
    GetDriveCommentListRespItemReplyListReplyContent,
    GetDriveCommentListRespItemReplyListReply,
    GetDriveCommentListRespItemReplyList,
    GetDriveCommentListRespItem,
    GetDriveCommentListResp,
    UpdateDriveCommentPatchReqFileType,
    UpdateDriveCommentPatchReq,
    UpdateDriveCommentPatchResp,
    UpdateDriveCommentReqContentElementPerson,
    UpdateDriveCommentReqContentElementDocsLink,
    UpdateDriveCommentReqContentElementTextRun,
    UpdateDriveCommentReqContentElement,
    UpdateDriveCommentReqContent,
    UpdateDriveCommentReqFileType,
    UpdateDriveCommentReq,
    UpdateDriveCommentResp,
    GetDriveDocContentReq,
    GetDriveDocContentResp,
    CreateDriveDocReq,
    CreateDriveDocResp,
    GetDriveDocMetaReq,
    GetDriveDocMetaResp,
    GetDriveDocRawContentReq,
    GetDriveDocRawContentResp,
    CopyDriveFileReq,
    CopyDriveFileResp,
    CreateDriveFileReq,
    CreateDriveFileResp,
    DeleteDriveFileReq,
    DeleteDriveFileResp,
    DownloadDriveFileReqRange,
    DownloadDriveFileReq,
    DownloadDriveFileRespFile,
    DownloadDriveFileResp,
    DownloadDriveFileResp,
    GetDriveFileMetaReqRequestDocs,
    GetDriveFileMetaReq,
    GetDriveFileMetaRespDocsMetas,
    GetDriveFileMetaResp,
    SearchDriveFileReq,
    SearchDriveFileRespDocsEntity,
    SearchDriveFileResp,
    DeleteDriveSheetFileReq,
    DeleteDriveSheetFileResp,
    GetDriveFileStatisticsReqFileType,
    GetDriveFileStatisticsReq,
    GetDriveFileStatisticsRespStatistics,
    GetDriveFileStatisticsRespFileType,
    GetDriveFileStatisticsResp,
    UploadDriveFileReqFile,
    UploadDriveFileReq,
    UploadDriveFileResp,
    FinishUploadDriveFileReq,
    FinishUploadDriveFileResp,
    PartUploadDriveFileReqFile,
    PartUploadDriveFileReq,
    PartUploadDriveFileResp,
    PrepareUploadDriveFileReq,
    PrepareUploadDriveFileResp,
    GetDriveFolderChildrenReq,
    GetDriveFolderChildrenRespChildren,
    GetDriveFolderChildrenResp,
    CreateDriveFolderReq,
    CreateDriveFolderResp,
    GetDriveFolderMetaReq,
    GetDriveFolderMetaResp,
    GetDriveRootFolderMetaReq,
    GetDriveRootFolderMetaResp,
    CreateDriveImportTaskReqPoint,
    CreateDriveImportTaskReq,
    CreateDriveImportTaskResp,
    GetDriveImportTaskReq,
    GetDriveImportTaskRespResult,
    GetDriveImportTaskResp,
    BatchGetDriveMediaTmpDownloadURLReq,
    BatchGetDriveMediaTmpDownloadURLRespTmpDownloadURL,
    BatchGetDriveMediaTmpDownloadURLResp,
    DownloadDriveMediaReqRange,
    DownloadDriveMediaReq,
    DownloadDriveMediaRespFile,
    DownloadDriveMediaResp,
    DownloadDriveMediaResp,
    UploadDriveMediaReqFile,
    UploadDriveMediaReq,
    UploadDriveMediaResp,
    FinishUploadDriveMediaReq,
    FinishUploadDriveMediaResp,
    PartUploadDriveMediaReqFile,
    PartUploadDriveMediaReq,
    PartUploadDriveMediaResp,
    PrepareUploadDriveMediaReq,
    PrepareUploadDriveMediaResp,
    CheckDriveMemberPermissionReq,
    CheckDriveMemberPermissionResp,
    CreateDriveMemberPermissionReq,
    CreateDriveMemberPermissionRespMember,
    CreateDriveMemberPermissionResp,
    CreateDriveMemberPermissionOldReqMembers,
    CreateDriveMemberPermissionOldReq,
    CreateDriveMemberPermissionOldRespFailMembers,
    CreateDriveMemberPermissionOldResp,
    DeleteDriveMemberPermissionReq,
    DeleteDriveMemberPermissionResp,
    GetDriveMemberPermissionListReq,
    GetDriveMemberPermissionListRespMember,
    GetDriveMemberPermissionListResp,
    TransferDriveMemberPermissionReqOwner,
    TransferDriveMemberPermissionReq,
    TransferDriveMemberPermissionRespOwner,
    TransferDriveMemberPermissionResp,
    UpdateDriveMemberPermissionReq,
    UpdateDriveMemberPermissionResp,
    GetDrivePublicPermissionV2Req,
    GetDrivePublicPermissionV2Resp,
    UpdateDrivePublicPermissionReq,
    UpdateDrivePublicPermissionRespPermissionPublic,
    UpdateDrivePublicPermissionResp,
    UpdateDrivePublicPermissionV1OldReq,
    UpdateDrivePublicPermissionV1OldResp,
    UpdateDrivePublicPermissionV2OldReq,
    UpdateDrivePublicPermissionV2OldResp,
    BatchUpdateSheetReqRequestDeleteSheet,
    BatchUpdateSheetReqRequestCopySheetDestination,
    BatchUpdateSheetReqRequestCopySheetSource,
    BatchUpdateSheetReqRequestCopySheet,
    BatchUpdateSheetReqRequestAddSheetProperties,
    BatchUpdateSheetReqRequestAddSheet,
    BatchUpdateSheetReqRequest,
    BatchUpdateSheetReq,
    BatchUpdateSheetRespReplyDeleteSheet,
    BatchUpdateSheetRespReplyCopySheet,
    BatchUpdateSheetRespReplyAddSheet,
    BatchUpdateSheetRespReply,
    BatchUpdateSheetResp,
    MergeSheetCellReq,
    MergeSheetCellResp,
    UnmergeSheetCellReq,
    UnmergeSheetCellResp,
    CreateSheetConditionFormatReqSheetConditionFormatConditionFormatStyleFont,
    CreateSheetConditionFormatReqSheetConditionFormatConditionFormatStyle,
    CreateSheetConditionFormatReqSheetConditionFormatConditionFormatAttrs,
    CreateSheetConditionFormatReqSheetConditionFormatConditionFormat,
    CreateSheetConditionFormatReqSheetConditionFormat,
    CreateSheetConditionFormatReq,
    CreateSheetConditionFormatRespResponse,
    CreateSheetConditionFormatResp,
    DeleteSheetConditionFormatReqSheetCfIDs,
    DeleteSheetConditionFormatReq,
    DeleteSheetConditionFormatRespResponse,
    DeleteSheetConditionFormatResp,
    GetSheetConditionFormatReq,
    GetSheetConditionFormatRespSheetConditionFormatConditionFormatStyleFont,
    GetSheetConditionFormatRespSheetConditionFormatConditionFormatStyle,
    GetSheetConditionFormatRespSheetConditionFormatConditionFormatAttrs,
    GetSheetConditionFormatRespSheetConditionFormatConditionFormat,
    GetSheetConditionFormatRespSheetConditionFormat,
    GetSheetConditionFormatResp,
    UpdateSheetConditionFormatReqSheetConditionFormatsConditionFormatStyleFont,
    UpdateSheetConditionFormatReqSheetConditionFormatsConditionFormatStyle,
    UpdateSheetConditionFormatReqSheetConditionFormatsConditionFormatAttrs,
    UpdateSheetConditionFormatReqSheetConditionFormatsConditionFormat,
    UpdateSheetConditionFormatReqSheetConditionFormats,
    UpdateSheetConditionFormatReq,
    UpdateSheetConditionFormatRespResponse,
    UpdateSheetConditionFormatResp,
    CreateSheetReq,
    CreateSheetRespSpreadsheet,
    CreateSheetResp,
    CreateSheetDataValidationDropdownReqDataValidationOptions,
    CreateSheetDataValidationDropdownReqDataValidation,
    CreateSheetDataValidationDropdownReq,
    CreateSheetDataValidationDropdownResp,
    DeleteSheetDataValidationDropdownReqDataValidationRange,
    DeleteSheetDataValidationDropdownReq,
    DeleteSheetDataValidationDropdownRespRangeResult,
    DeleteSheetDataValidationDropdownResp,
    GetSheetDataValidationDropdownReq,
    GetSheetDataValidationDropdownRespDataValidationOptionsColorValueMap,
    GetSheetDataValidationDropdownRespDataValidationOptions,
    GetSheetDataValidationDropdownRespDataValidation,
    GetSheetDataValidationDropdownResp,
    UpdateSheetDataValidationDropdownReqDataValidationOptions,
    UpdateSheetDataValidationDropdownReqDataValidation,
    UpdateSheetDataValidationDropdownReq,
    UpdateSheetDataValidationDropdownRespDataValidationOptionsColorValueMap,
    UpdateSheetDataValidationDropdownRespDataValidationOptions,
    UpdateSheetDataValidationDropdownRespDataValidation,
    UpdateSheetDataValidationDropdownResp,
    MoveSheetDimensionReqSource,
    MoveSheetDimensionReq,
    MoveSheetDimensionResp,
    AddSheetDimensionRangeReqDimension,
    AddSheetDimensionRangeReq,
    AddSheetDimensionRangeResp,
    DeleteSheetDimensionRangeReqDimension,
    DeleteSheetDimensionRangeReq,
    DeleteSheetDimensionRangeResp,
    InsertSheetDimensionRangeReqDimension,
    InsertSheetDimensionRangeReq,
    InsertSheetDimensionRangeResp,
    UpdateSheetDimensionRangeReqDimensionProperties,
    UpdateSheetDimensionRangeReqDimension,
    UpdateSheetDimensionRangeReq,
    UpdateSheetDimensionRangeResp,
    CreateSheetFilterReqCondition,
    CreateSheetFilterReq,
    CreateSheetFilterResp,
    DeleteSheetFilterReq,
    DeleteSheetFilterResp,
    GetSheetFilterReq,
    GetSheetFilterRespSheetFilterInfoFilterInfoCondition,
    GetSheetFilterRespSheetFilterInfoFilterInfo,
    GetSheetFilterRespSheetFilterInfo,
    GetSheetFilterResp,
    UpdateSheetFilterReqCondition,
    UpdateSheetFilterReq,
    UpdateSheetFilterResp,
    CreateSheetFilterViewConditionReq,
    CreateSheetFilterViewConditionRespCondition,
    CreateSheetFilterViewConditionResp,
    DeleteSheetFilterViewConditionReq,
    DeleteSheetFilterViewConditionResp,
    GetSheetFilterViewConditionReq,
    GetSheetFilterViewConditionRespCondition,
    GetSheetFilterViewConditionResp,
    QuerySheetFilterViewConditionReq,
    QuerySheetFilterViewConditionRespItem,
    QuerySheetFilterViewConditionResp,
    UpdateSheetFilterViewConditionReq,
    UpdateSheetFilterViewConditionRespCondition,
    UpdateSheetFilterViewConditionResp,
    CreateSheetFilterViewReq,
    CreateSheetFilterViewRespFilterView,
    CreateSheetFilterViewResp,
    DeleteSheetFilterViewReq,
    DeleteSheetFilterViewResp,
    GetSheetFilterViewReq,
    GetSheetFilterViewRespFilterView,
    GetSheetFilterViewResp,
    QuerySheetFilterViewReq,
    QuerySheetFilterViewRespItem,
    QuerySheetFilterViewResp,
    UpdateSheetFilterViewReq,
    UpdateSheetFilterViewRespFilterView,
    UpdateSheetFilterViewResp,
    FindSheetReqFindCondition,
    FindSheetReq,
    FindSheetRespFindResult,
    FindSheetResp,
    CreateSheetFloatImageReqOffsetY,
    CreateSheetFloatImageReqOffsetX,
    CreateSheetFloatImageReqHeight,
    CreateSheetFloatImageReqWidth,
    CreateSheetFloatImageReq,
    CreateSheetFloatImageRespFloatImageOffsetY,
    CreateSheetFloatImageRespFloatImageOffsetX,
    CreateSheetFloatImageRespFloatImageHeight,
    CreateSheetFloatImageRespFloatImageWidth,
    CreateSheetFloatImageRespFloatImage,
    CreateSheetFloatImageResp,
    DeleteSheetFloatImageReq,
    DeleteSheetFloatImageResp,
    GetSheetFloatImageReq,
    GetSheetFloatImageRespFloatImageOffsetY,
    GetSheetFloatImageRespFloatImageOffsetX,
    GetSheetFloatImageRespFloatImageHeight,
    GetSheetFloatImageRespFloatImageWidth,
    GetSheetFloatImageRespFloatImage,
    GetSheetFloatImageResp,
    QuerySheetFloatImageReq,
    QuerySheetFloatImageRespItemOffsetY,
    QuerySheetFloatImageRespItemOffsetX,
    QuerySheetFloatImageRespItemHeight,
    QuerySheetFloatImageRespItemWidth,
    QuerySheetFloatImageRespItem,
    QuerySheetFloatImageResp,
    UpdateSheetFloatImageReqOffsetY,
    UpdateSheetFloatImageReqOffsetX,
    UpdateSheetFloatImageReqHeight,
    UpdateSheetFloatImageReqWidth,
    UpdateSheetFloatImageReq,
    UpdateSheetFloatImageRespFloatImageOffsetY,
    UpdateSheetFloatImageRespFloatImageOffsetX,
    UpdateSheetFloatImageRespFloatImageHeight,
    UpdateSheetFloatImageRespFloatImageWidth,
    UpdateSheetFloatImageRespFloatImage,
    UpdateSheetFloatImageResp,
    SetSheetValueImageReqImage,
    SetSheetValueImageReq,
    SetSheetValueImageResp,
    ImportSheetReqFile,
    ImportSheetReq,
    ImportSheetResp,
    GetSheetMetaReqUserIDType,
    GetSheetMetaReq,
    GetSheetMetaRespSheetBlockInfo,
    GetSheetMetaRespSheetProtectedRangeDimension,
    GetSheetMetaRespSheetProtectedRange,
    GetSheetMetaRespSheetMerge,
    GetSheetMetaRespSheet,
    GetSheetMetaRespProperties,
    GetSheetMetaResp,
    UpdateSheetPropertyReqProperties,
    UpdateSheetPropertyReq,
    UpdateSheetPropertyResp,
    CreateSheetProtectedDimensionReqAddProtectedDimensionDimension,
    CreateSheetProtectedDimensionReqAddProtectedDimension,
    CreateSheetProtectedDimensionReqUserIDType,
    CreateSheetProtectedDimensionReq,
    CreateSheetProtectedDimensionRespAddProtectedDimensionDimension,
    CreateSheetProtectedDimensionRespAddProtectedDimension,
    CreateSheetProtectedDimensionResp,
    DeleteSheetProtectedDimensionReq,
    DeleteSheetProtectedDimensionResp,
    GetSheetProtectedDimensionReq,
    GetSheetProtectedDimensionRespProtectedRangeEditorsUser,
    GetSheetProtectedDimensionRespProtectedRangeEditors,
    GetSheetProtectedDimensionRespProtectedRangeDimension,
    GetSheetProtectedDimensionRespProtectedRange,
    GetSheetProtectedDimensionResp,
    UpdateSheetProtectedDimensionReqRequestsEditorsDelEditors,
    UpdateSheetProtectedDimensionReqRequestsEditorsAddEditors,
    UpdateSheetProtectedDimensionReqRequestsEditors,
    UpdateSheetProtectedDimensionReqRequestsDimension,
    UpdateSheetProtectedDimensionReqRequests,
    UpdateSheetProtectedDimensionReq,
    UpdateSheetProtectedDimensionRespReplyEditorsDelEditor,
    UpdateSheetProtectedDimensionRespReplyEditorsAddEditor,
    UpdateSheetProtectedDimensionRespReplyEditors,
    UpdateSheetProtectedDimensionRespReplyDimension,
    UpdateSheetProtectedDimensionRespReply,
    UpdateSheetProtectedDimensionResp,
    ReplaceSheetReqFindCondition,
    ReplaceSheetReq,
    ReplaceSheetRespReplaceResult,
    ReplaceSheetResp,
    BatchSetSheetStyleReqDataStyleFont,
    BatchSetSheetStyleReqDataStyle,
    BatchSetSheetStyleReqData,
    BatchSetSheetStyleReq,
    BatchSetSheetStyleRespResponse,
    BatchSetSheetStyleResp,
    SetSheetStyleReqAppendStyleStyleFont,
    SetSheetStyleReqAppendStyleStyle,
    SetSheetStyleReqAppendStyle,
    SetSheetStyleReq,
    SetSheetStyleResp,
    AppendSheetValueReqValueRangeValues,
    AppendSheetValueReqValueRange,
    AppendSheetValueReq,
    AppendSheetValueRespUpdates,
    AppendSheetValueResp,
    BatchGetSheetValueReqUserIDType,
    BatchGetSheetValueReq,
    BatchGetSheetValueRespValueRangeValue,
    BatchGetSheetValueRespValueRange,
    BatchGetSheetValueResp,
    BatchSetSheetValueReqValueRangeValue,
    BatchSetSheetValueReqValueRange,
    BatchSetSheetValueReq,
    BatchSetSheetValueRespResponse,
    BatchSetSheetValueResp,
    GetSheetValueReqUserIDType,
    GetSheetValueReq,
    GetSheetValueRespValueRangeValues,
    GetSheetValueRespValueRange,
    GetSheetValueResp,
    PrependSheetValueReqValueRangeValues,
    PrependSheetValueReqValueRange,
    PrependSheetValueReq,
    PrependSheetValueRespUpdates,
    PrependSheetValueResp,
    SetSheetValueReqValueRangeValues,
    SetSheetValueReqValueRange,
    SetSheetValueReq,
    SetSheetValueResp,
    LarkEHRService,
    DownloadEHRAttachmentsReq,
    DownloadEHRAttachmentsRespFile,
    DownloadEHRAttachmentsResp,
    DownloadEHRAttachmentsResp,
    GetEHREmployeeListReqUserIDType,
    GetEHREmployeeListReq,
    GetEHREmployeeListRespItemCustomField,
    GetEHREmployeeListRespItemSystemFieldsOffboardingFile,
    GetEHREmployeeListRespItemSystemFieldsCertOfMerit,
    GetEHREmployeeListRespItemSystemFieldsGraduationCert,
    GetEHREmployeeListRespItemSystemFieldsDiplomaPhoto,
    GetEHREmployeeListRespItemSystemFieldsIDPhoto,
    GetEHREmployeeListRespItemSystemFieldsIDPhotoEmSide,
    GetEHREmployeeListRespItemSystemFieldsIDPhotoPoSide,
    GetEHREmployeeListRespItemSystemFieldsWorkExp,
    GetEHREmployeeListRespItemSystemFieldsFormerWorkExp,
    GetEHREmployeeListRespItemSystemFieldsEducation,
    GetEHREmployeeListRespItemSystemFieldsHighestLevelOfEdu,
    GetEHREmployeeListRespItemSystemFieldsEmergencyContact,
    GetEHREmployeeListRespItemSystemFieldsPrimaryEmergencyContact,
    GetEHREmployeeListRespItemSystemFieldsContractCompany,
    GetEHREmployeeListRespItemSystemFieldsProbationMonths,
    GetEHREmployeeListRespItemSystemFieldsIDType,
    GetEHREmployeeListRespItemSystemFieldsNativeRegion,
    GetEHREmployeeListRespItemSystemFieldsWorkLocation,
    GetEHREmployeeListRespItemSystemFieldsJobLevel,
    GetEHREmployeeListRespItemSystemFieldsJob,
    GetEHREmployeeListRespItemSystemFieldsManager,
    GetEHREmployeeListRespItemSystemFields,
    GetEHREmployeeListRespItem,
    GetEHREmployeeListResp,
    LarkFileService,
    DownloadFileReq,
    DownloadFileRespFile,
    DownloadFileResp,
    DownloadFileResp,
    DownloadImageReq,
    DownloadImageRespFile,
    DownloadImageResp,
    DownloadImageResp,
    UploadFileReqFile,
    UploadFileReqFileType,
    UploadFileReq,
    UploadFileResp,
    UploadImageReqImage,
    UploadImageReqImageType,
    UploadImageReq,
    UploadImageResp,
    LarkHelpdeskService,
    GetHelpdeskAgentEmailReq,
    GetHelpdeskAgentEmailResp,
    UpdateHelpdeskAgentReq,
    UpdateHelpdeskAgentResp,
    CreateHelpdeskAgentScheduleReqAgentScheduleSchedule,
    CreateHelpdeskAgentScheduleReqAgentSchedule,
    CreateHelpdeskAgentScheduleReq,
    CreateHelpdeskAgentScheduleResp,
    DeleteHelpdeskAgentScheduleReq,
    DeleteHelpdeskAgentScheduleResp,
    GetHelpdeskAgentScheduleReq,
    GetHelpdeskAgentScheduleRespAgentScheduleAgentSkill,
    GetHelpdeskAgentScheduleRespAgentScheduleSchedule,
    GetHelpdeskAgentScheduleRespAgentScheduleAgent,
    GetHelpdeskAgentScheduleRespAgentSchedule,
    GetHelpdeskAgentScheduleResp,
    GetHelpdeskAgentScheduleListReq,
    GetHelpdeskAgentScheduleListRespAgentScheduleAgentSkill,
    GetHelpdeskAgentScheduleListRespAgentScheduleSchedule,
    GetHelpdeskAgentScheduleListRespAgentScheduleAgent,
    GetHelpdeskAgentScheduleListRespAgentSchedule,
    GetHelpdeskAgentScheduleListResp,
    UpdateHelpdeskAgentScheduleReqAgentScheduleSchedule,
    UpdateHelpdeskAgentScheduleReqAgentSchedule,
    UpdateHelpdeskAgentScheduleReq,
    UpdateHelpdeskAgentScheduleResp,
    CreateHelpdeskAgentSkillReqRule,
    CreateHelpdeskAgentSkillReq,
    CreateHelpdeskAgentSkillResp,
    DeleteHelpdeskAgentSkillReq,
    DeleteHelpdeskAgentSkillResp,
    GetHelpdeskAgentSkillReq,
    GetHelpdeskAgentSkillRespAgentSkillAgent,
    GetHelpdeskAgentSkillRespAgentSkillRule,
    GetHelpdeskAgentSkillRespAgentSkill,
    GetHelpdeskAgentSkillResp,
    GetHelpdeskAgentSkillListReq,
    GetHelpdeskAgentSkillListRespAgentSkill,
    GetHelpdeskAgentSkillListResp,
    GetHelpdeskAgentSkillRuleListReq,
    GetHelpdeskAgentSkillRuleListRespRule,
    GetHelpdeskAgentSkillRuleListResp,
    UpdateHelpdeskAgentSkillReqAgentSkillRules,
    UpdateHelpdeskAgentSkillReqAgentSkill,
    UpdateHelpdeskAgentSkillReq,
    UpdateHelpdeskAgentSkillResp,
    CreateHelpdeskCategoryReq,
    CreateHelpdeskCategoryRespCategory,
    CreateHelpdeskCategoryResp,
    DeleteHelpdeskCategoryReq,
    DeleteHelpdeskCategoryResp,
    GetHelpdeskCategoryReq,
    GetHelpdeskCategoryResp,
    GetHelpdeskCategoryListReq,
    GetHelpdeskCategoryListRespCategorieChildren,
    GetHelpdeskCategoryListRespCategorie,
    GetHelpdeskCategoryListResp,
    UpdateHelpdeskCategoryReq,
    UpdateHelpdeskCategoryResp,
    SubscribeHelpdeskEventReqEvent,
    SubscribeHelpdeskEventReq,
    SubscribeHelpdeskEventResp,
    UnsubscribeHelpdeskEventReqEvent,
    UnsubscribeHelpdeskEventReq,
    UnsubscribeHelpdeskEventResp,
    CreateHelpdeskFAQReqFAQ,
    CreateHelpdeskFAQReq,
    CreateHelpdeskFAQRespFAQCreateUser,
    CreateHelpdeskFAQRespFAQUpdateUser,
    CreateHelpdeskFAQRespFAQCategorie,
    CreateHelpdeskFAQRespFAQ,
    CreateHelpdeskFAQResp,
    DeleteHelpdeskFAQReq,
    DeleteHelpdeskFAQResp,
    GetHelpdeskFAQReq,
    GetHelpdeskFAQRespFAQCreateUser,
    GetHelpdeskFAQRespFAQUpdateUser,
    GetHelpdeskFAQRespFAQCategorie,
    GetHelpdeskFAQRespFAQ,
    GetHelpdeskFAQResp,
    GetHelpdeskFAQImageReq,
    GetHelpdeskFAQImageRespFile,
    GetHelpdeskFAQImageResp,
    GetHelpdeskFAQImageResp,
    GetHelpdeskFAQListReq,
    GetHelpdeskFAQListRespItemCreateUser,
    GetHelpdeskFAQListRespItemUpdateUser,
    GetHelpdeskFAQListRespItemCategorie,
    GetHelpdeskFAQListRespItem,
    GetHelpdeskFAQListResp,
    SearchHelpdeskFAQReq,
    SearchHelpdeskFAQRespItemCategorie,
    SearchHelpdeskFAQRespItem,
    SearchHelpdeskFAQResp,
    UpdateHelpdeskFAQReqFAQ,
    UpdateHelpdeskFAQReq,
    UpdateHelpdeskFAQResp,
    StartHelpdeskServiceReq,
    StartHelpdeskServiceResp,
    AnswerHelpdeskTicketUserQueryReqFAQScore,
    AnswerHelpdeskTicketUserQueryReqFAQ,
    AnswerHelpdeskTicketUserQueryReq,
    AnswerHelpdeskTicketUserQueryResp,
    CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTagChildren,
    CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTag,
    CreateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildren,
    CreateHelpdeskTicketCustomizedFieldReqDropdownOptions,
    CreateHelpdeskTicketCustomizedFieldReq,
    CreateHelpdeskTicketCustomizedFieldResp,
    DeleteHelpdeskTicketCustomizedFieldReq,
    DeleteHelpdeskTicketCustomizedFieldResp,
    GetHelpdeskTicketCustomizedFieldReq,
    GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptionsChildrenChildren,
    GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptionsChildren,
    GetHelpdeskTicketCustomizedFieldRespUpdatedByDropdownOptions,
    GetHelpdeskTicketCustomizedFieldRespUpdatedBy,
    GetHelpdeskTicketCustomizedFieldRespCreatedBy,
    GetHelpdeskTicketCustomizedFieldResp,
    GetHelpdeskTicketCustomizedFieldListReq,
    GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptionsChildrenChildren,
    GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptionsChildren,
    GetHelpdeskTicketCustomizedFieldListRespItemDropdownOptions,
    GetHelpdeskTicketCustomizedFieldListRespItemUpdatedBy,
    GetHelpdeskTicketCustomizedFieldListRespItemCreatedBy,
    GetHelpdeskTicketCustomizedFieldListRespItem,
    GetHelpdeskTicketCustomizedFieldListResp,
    UpdateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTagChildren,
    UpdateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildrenTag,
    UpdateHelpdeskTicketCustomizedFieldReqDropdownOptionsChildren,
    UpdateHelpdeskTicketCustomizedFieldReqDropdownOptions,
    UpdateHelpdeskTicketCustomizedFieldReq,
    UpdateHelpdeskTicketCustomizedFieldResp,
    GetHelpdeskTicketReq,
    GetHelpdeskTicketRespTicketAgentServiceDuration,
    GetHelpdeskTicketRespTicketCustomizedField,
    GetHelpdeskTicketRespTicketCollaborator,
    GetHelpdeskTicketRespTicketClosedBy,
    GetHelpdeskTicketRespTicketAgent,
    GetHelpdeskTicketRespTicketGuest,
    GetHelpdeskTicketRespTicket,
    GetHelpdeskTicketResp,
    GetHelpdeskTicketListReqCustomizedFields,
    GetHelpdeskTicketListReq,
    GetHelpdeskTicketListRespTicketCustomizedField,
    GetHelpdeskTicketListRespTicketCollaborator,
    GetHelpdeskTicketListRespTicketClosedBy,
    GetHelpdeskTicketListRespTicketAgent,
    GetHelpdeskTicketListRespTicketGuest,
    GetHelpdeskTicketListRespTicket,
    GetHelpdeskTicketListResp,
    DownloadHelpdeskTicketImageReq,
    DownloadHelpdeskTicketImageRespFile,
    DownloadHelpdeskTicketImageResp,
    DownloadHelpdeskTicketImageResp,
    GetHelpdeskTicketMessageListReq,
    GetHelpdeskTicketMessageListRespMessageMessageType,
    GetHelpdeskTicketMessageListRespMessage,
    GetHelpdeskTicketMessageListResp,
    SendHelpdeskTicketMessageReqMsgType,
    SendHelpdeskTicketMessageReq,
    SendHelpdeskTicketMessageResp,
    UpdateHelpdeskTicketReqCustomizedField,
    UpdateHelpdeskTicketReq,
    UpdateHelpdeskTicketResp,
    LarkHireService,
    CreateHireApplicationReq,
    CreateHireApplicationResp,
    GetHireApplicationReq,
    GetHireApplicationRespApplicationStage,
    GetHireApplicationRespApplication,
    GetHireApplicationResp,
    GetHireApplicationInterviewListReqUserIDType,
    GetHireApplicationInterviewListReq,
    GetHireApplicationInterviewListRespItemInterviewRecordInterviewScore,
    GetHireApplicationInterviewListRespItemInterviewRecord,
    GetHireApplicationInterviewListRespItem,
    GetHireApplicationInterviewListResp,
    GetHireApplicationListReq,
    GetHireApplicationListResp,
    TerminateHireApplicationReq,
    TerminateHireApplicationResp,
    GetHireAttachmentReq,
    GetHireAttachmentRespAttachment,
    GetHireAttachmentResp,
    GetHireAttachmentPreviewReq,
    GetHireAttachmentPreviewResp,
    GetHireEmployeeReq,
    GetHireEmployeeRespEmployee,
    GetHireEmployeeResp,
    GetHireEmployeeByApplicationReq,
    GetHireEmployeeByApplicationRespEmployee,
    GetHireEmployeeByApplicationResp,
    UpdateHireEmployeeReqOverboardInfo,
    UpdateHireEmployeeReqConversionInfo,
    UpdateHireEmployeeReq,
    UpdateHireEmployeeRespEmployee,
    UpdateHireEmployeeResp,
    GetHireJobReqUserIDType,
    GetHireJobReq,
    GetHireJobRespJobCustomizedDataValueTimeRange,
    GetHireJobRespJobCustomizedDataValueOptionName,
    GetHireJobRespJobCustomizedDataValueOption,
    GetHireJobRespJobCustomizedDataValueOptionName,
    GetHireJobRespJobCustomizedDataValueOption,
    GetHireJobRespJobCustomizedDataValue,
    GetHireJobRespJobCustomizedDataName,
    GetHireJobRespJobCustomizedData,
    GetHireJobRespJobJobType,
    GetHireJobRespJobJobCategory,
    GetHireJobRespJobHighlight,
    GetHireJobRespJobMaxJobLevel,
    GetHireJobRespJobMinJobLevel,
    GetHireJobRespJobCity,
    GetHireJobRespJobDepartment,
    GetHireJobRespJobRecruitmentType,
    GetHireJobRespJob,
    GetHireJobResp,
    GetHireJobManagerReqUserIDType,
    GetHireJobManagerReq,
    GetHireJobManagerRespInfo,
    GetHireJobManagerResp,
    GetHireJobProcessListReq,
    GetHireJobProcessListRespItemStage,
    GetHireJobProcessListRespItem,
    GetHireJobProcessListResp,
    CreateHireNoteReqUserIDType,
    CreateHireNoteReq,
    CreateHireNoteRespNote,
    CreateHireNoteResp,
    GetHireNoteReqUserIDType,
    GetHireNoteReq,
    GetHireNoteRespNote,
    GetHireNoteResp,
    GetHireNoteListReqUserIDType,
    GetHireNoteListReq,
    GetHireNoteListRespItem,
    GetHireNoteListResp,
    UpdateHireNoteReqUserIDType,
    UpdateHireNoteReq,
    UpdateHireNoteRespNote,
    UpdateHireNoteResp,
    GetHireOfferByApplicationReqUserIDType,
    GetHireOfferByApplicationReq,
    GetHireOfferByApplicationRespOfferSalaryPlanCustomizeInfo,
    GetHireOfferByApplicationRespOfferSalaryPlan,
    GetHireOfferByApplicationRespOfferBasicInfoCustomizeInfo,
    GetHireOfferByApplicationRespOfferBasicInfoWorkAddressCountry,
    GetHireOfferByApplicationRespOfferBasicInfoWorkAddressState,
    GetHireOfferByApplicationRespOfferBasicInfoWorkAddressCity,
    GetHireOfferByApplicationRespOfferBasicInfoWorkAddressDistrict,
    GetHireOfferByApplicationRespOfferBasicInfoWorkAddress,
    GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressCountry,
    GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressState,
    GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressCity,
    GetHireOfferByApplicationRespOfferBasicInfoOnboardAddressDistrict,
    GetHireOfferByApplicationRespOfferBasicInfoOnboardAddress,
    GetHireOfferByApplicationRespOfferBasicInfoLevel,
    GetHireOfferByApplicationRespOfferBasicInfoSequence,
    GetHireOfferByApplicationRespOfferBasicInfoRecruitmentType,
    GetHireOfferByApplicationRespOfferBasicInfo,
    GetHireOfferByApplicationRespOffer,
    GetHireOfferByApplicationResp,
    GetHireOfferSchemaReq,
    GetHireOfferSchemaRespObjectOptionName,
    GetHireOfferSchemaRespObjectOption,
    GetHireOfferSchemaRespObjectName,
    GetHireOfferSchemaRespObject,
    GetHireOfferSchemaResp,
    GetHireReferralByApplicationReqUserIDType,
    GetHireReferralByApplicationReq,
    GetHireReferralByApplicationRespReferral,
    GetHireReferralByApplicationResp,
    GetHireResumeSourceReq,
    GetHireResumeSourceRespItem,
    GetHireResumeSourceResp,
    GetHireTalentReq,
    GetHireTalentRespTalentInterviewRegistration,
    GetHireTalentRespTalentResumeSource,
    GetHireTalentRespTalentSns,
    GetHireTalentRespTalentLanguage,
    GetHireTalentRespTalentCertificate,
    GetHireTalentRespTalentCompetition,
    GetHireTalentRespTalentAward,
    GetHireTalentRespTalentWorks,
    GetHireTalentRespTalentProject,
    GetHireTalentRespTalentCareer,
    GetHireTalentRespTalentEducation,
    GetHireTalentRespTalentBasicInfoPreferredCity,
    GetHireTalentRespTalentBasicInfoHometownCity,
    GetHireTalentRespTalentBasicInfoCurrentCity,
    GetHireTalentRespTalentBasicInfoNationality,
    GetHireTalentRespTalentBasicInfo,
    GetHireTalentRespTalent,
    GetHireTalentResp,
    MakeHireTransferOnboardByApplicationReq,
    MakeHireTransferOnboardByApplicationResp,
    LarkHumanAuthService,
    CropFaceVerifyImageReqRawImage,
    CropFaceVerifyImageReq,
    CropFaceVerifyImageResp,
    GetFaceVerifyAuthResultReq,
    GetFaceVerifyAuthResultResp,
    UploadFaceVerifyImageReqImage,
    UploadFaceVerifyImageReq,
    UploadFaceVerifyImageResp,
    CreateIdentityReqUserIDType,
    CreateIdentityReq,
    CreateIdentityResp,
    OpenBotReq,
    OpenBotResp,
    OpenCalenderReq,
    OpenCalenderResp,
    OpenCalenderAccountReq,
    OpenCalenderAccountResp,
    OpenCalenderEventCreateReq,
    OpenCalenderEventCreateResp,
    OpenCalenderViewReq,
    OpenCalenderViewResp,
    OpenChatReq,
    OpenChatResp,
    OpenDocsReq,
    OpenDocsResp,
    OpenLarkReq,
    OpenLarkResp,
    OpenMiniProgramReq,
    OpenMiniProgramResp,
    OpenSSOLoginReq,
    OpenSSOLoginResp,
    OpenWebAppReq,
    OpenWebAppResp,
    OpenWebURLReq,
    OpenWebURLResp,
    LarkMailService,
    CreateMailGroupReq,
    CreateMailGroupResp,
    DeleteMailGroupReq,
    DeleteMailGroupResp,
    GetMailGroupReq,
    GetMailGroupResp,
    GetMailGroupListReq,
    GetMailGroupListRespItem,
    GetMailGroupListResp,
    CreateMailGroupMemberReqType,
    CreateMailGroupMemberReqDepartmentIDType,
    CreateMailGroupMemberReqUserIDType,
    CreateMailGroupMemberReq,
    CreateMailGroupMemberRespType,
    CreateMailGroupMemberResp,
    DeleteMailGroupMemberReq,
    DeleteMailGroupMemberResp,
    GetMailGroupMemberReqDepartmentIDType,
    GetMailGroupMemberReqUserIDType,
    GetMailGroupMemberReq,
    GetMailGroupMemberRespType,
    GetMailGroupMemberResp,
    GetMailGroupMemberListReqDepartmentIDType,
    GetMailGroupMemberListReqUserIDType,
    GetMailGroupMemberListReq,
    GetMailGroupMemberListRespItemType,
    GetMailGroupMemberListRespItem,
    GetMailGroupMemberListResp,
    UpdateMailGroupPatchReq,
    UpdateMailGroupPatchResp,
    CreateMailGroupPermissionMemberReqType,
    CreateMailGroupPermissionMemberReqDepartmentIDType,
    CreateMailGroupPermissionMemberReqUserIDType,
    CreateMailGroupPermissionMemberReq,
    CreateMailGroupPermissionMemberRespType,
    CreateMailGroupPermissionMemberResp,
    DeleteMailGroupPermissionMemberReq,
    DeleteMailGroupPermissionMemberResp,
    GetMailGroupPermissionMemberReqDepartmentIDType,
    GetMailGroupPermissionMemberReqUserIDType,
    GetMailGroupPermissionMemberReq,
    GetMailGroupPermissionMemberRespType,
    GetMailGroupPermissionMemberResp,
    GetMailGroupPermissionMemberListReqDepartmentIDType,
    GetMailGroupPermissionMemberListReqUserIDType,
    GetMailGroupPermissionMemberListReq,
    GetMailGroupPermissionMemberListRespItemType,
    GetMailGroupPermissionMemberListRespItem,
    GetMailGroupPermissionMemberListResp,
    UpdateMailGroupReq,
    UpdateMailGroupResp,
    CreatePublicMailboxReq,
    CreatePublicMailboxResp,
    GetPublicMailboxReq,
    GetPublicMailboxResp,
    GetPublicMailboxListReq,
    GetPublicMailboxListRespItem,
    GetPublicMailboxListResp,
    ClearPublicMailboxMemberReq,
    ClearPublicMailboxMemberResp,
    CreatePublicMailboxMemberReqType,
    CreatePublicMailboxMemberReqUserIDType,
    CreatePublicMailboxMemberReq,
    CreatePublicMailboxMemberRespType,
    CreatePublicMailboxMemberResp,
    DeletePublicMailboxMemberReq,
    DeletePublicMailboxMemberResp,
    GetPublicMailboxMemberReqUserIDType,
    GetPublicMailboxMemberReq,
    GetPublicMailboxMemberRespType,
    GetPublicMailboxMemberResp,
    GetPublicMailboxMemberListReqUserIDType,
    GetPublicMailboxMemberListReq,
    GetPublicMailboxMemberListRespItemType,
    GetPublicMailboxMemberListRespItem,
    GetPublicMailboxMemberListResp,
    UpdatePublicMailboxPatchReq,
    UpdatePublicMailboxPatchResp,
    UpdatePublicMailboxReq,
    UpdatePublicMailboxResp,
    LarkMeetingRoomService,
    BatchGetMeetingRoomBuildingReq,
    BatchGetMeetingRoomBuildingRespBuilding,
    BatchGetMeetingRoomBuildingResp,
    BatchGetMeetingRoomBuildingIDReq,
    BatchGetMeetingRoomBuildingIDRespBuilding,
    BatchGetMeetingRoomBuildingIDResp,
    CreateMeetingRoomBuildingReq,
    CreateMeetingRoomBuildingResp,
    DeleteMeetingRoomBuildingReq,
    DeleteMeetingRoomBuildingResp,
    GetMeetingRoomBuildingListReq,
    GetMeetingRoomBuildingListRespBuildings,
    GetMeetingRoomBuildingListResp,
    UpdateMeetingRoomBuildingReq,
    UpdateMeetingRoomBuildingResp,
    GetMeetingRoomCountryListReq,
    GetMeetingRoomCountryListRespCountries,
    GetMeetingRoomCountryListResp,
    GetMeetingRoomDistrictListReq,
    GetMeetingRoomDistrictListRespDistricts,
    GetMeetingRoomDistrictListResp,
    BatchGetMeetingRoomFreebusyReq,
    BatchGetMeetingRoomFreebusyRespFreeBusyRoomIDOrganizerInfo,
    BatchGetMeetingRoomFreebusyRespFreeBusyRoomID,
    BatchGetMeetingRoomFreebusyRespFreeBusy,
    BatchGetMeetingRoomFreebusyResp,
    ReplyMeetingRoomInstanceReq,
    ReplyMeetingRoomInstanceResp,
    BatchGetMeetingRoomRoomReq,
    BatchGetMeetingRoomRoomRespRoom,
    BatchGetMeetingRoomRoomResp,
    BatchGetMeetingRoomRoomIDReq,
    BatchGetMeetingRoomRoomIDRespRoom,
    BatchGetMeetingRoomRoomIDResp,
    CreateMeetingRoomRoomReq,
    CreateMeetingRoomRoomResp,
    DeleteMeetingRoomRoomReq,
    DeleteMeetingRoomRoomResp,
    GetMeetingRoomRoomListReq,
    GetMeetingRoomRoomListRespRooms,
    GetMeetingRoomRoomListResp,
    UpdateMeetingRoomRoomReq,
    UpdateMeetingRoomRoomResp,
    BatchGetMeetingRoomSummaryReqEventUid,
    BatchGetMeetingRoomSummaryReq,
    BatchGetMeetingRoomSummaryRespErrorEventUid,
    BatchGetMeetingRoomSummaryRespEventInfo,
    BatchGetMeetingRoomSummaryResp,
    LarkMessageService,
    DeleteMessageReq,
    DeleteMessageResp,
    DeleteEphemeralMessageReq,
    DeleteEphemeralMessageResp,
    GetMessageReq,
    GetMessageRespItemMentionIDType,
    GetMessageRespItemMention,
    GetMessageRespItemBody,
    GetMessageRespItemSenderIDType,
    GetMessageRespItemSender,
    GetMessageRespItemMsgType,
    GetMessageRespItem,
    GetMessageResp,
    GetMessageFileReq,
    GetMessageFileRespFile,
    GetMessageFileResp,
    GetMessageFileResp,
    GetMessageReadUserListReqUserIDType,
    GetMessageReadUserListReq,
    GetMessageReadUserListRespItemUserIDType,
    GetMessageReadUserListRespItem,
    GetMessageReadUserListResp,
    GetMessageListReqContainerIDType,
    GetMessageListReq,
    GetMessageListRespItemMentionIDType,
    GetMessageListRespItemMention,
    GetMessageListRespItemBody,
    GetMessageListRespItemSenderIDType,
    GetMessageListRespItemSender,
    GetMessageListRespItemMsgType,
    GetMessageListRespItem,
    GetMessageListResp,
    ReplyRawMessageReqMsgType,
    ReplyRawMessageReq,
    ReplyRawMessageRespMentionIDType,
    ReplyRawMessageRespMention,
    ReplyRawMessageRespBody,
    ReplyRawMessageRespSenderIDType,
    ReplyRawMessageRespSender,
    ReplyRawMessageRespMsgType,
    ReplyRawMessageResp,
    SendRawMessageReqMsgType,
    SendRawMessageReqReceiveIDType,
    SendRawMessageReq,
    SendRawMessageRespMentionIDType,
    SendRawMessageRespMention,
    SendRawMessageRespBody,
    SendRawMessageRespSenderIDType,
    SendRawMessageRespSender,
    SendRawMessageRespMsgType,
    SendRawMessageResp,
    SendRawMessageOldReqContent,
    SendRawMessageOldReqMsgType,
    SendRawMessageOldReq,
    SendRawMessageOldResp,
    UpdateMessageReq,
    UpdateMessageResp,
    LarkOKRService,
    BatchGetOKRReqUserIDType,
    BatchGetOKRReq,
    BatchGetOKRRespOKRObjectiveAligningObjectiveOwner,
    BatchGetOKRRespOKRObjectiveAligningObjective,
    BatchGetOKRRespOKRObjectiveAlignedObjectiveOwner,
    BatchGetOKRRespOKRObjectiveAlignedObjective,
    BatchGetOKRRespOKRObjectiveKrProgressRate,
    BatchGetOKRRespOKRObjectiveKrKrWeight,
    BatchGetOKRRespOKRObjectiveKr,
    BatchGetOKRRespOKRObjectiveProgressRate,
    BatchGetOKRRespOKRObjectiveWeight,
    BatchGetOKRRespOKRObjective,
    BatchGetOKRRespOKR,
    BatchGetOKRResp,
    GetOKRPeriodListReq,
    GetOKRPeriodListRespItem,
    GetOKRPeriodListResp,
    GetUserOKRListReqUserIDType,
    GetUserOKRListReq,
    GetUserOKRListRespOKRObjectiveAligningObjectiveOwner,
    GetUserOKRListRespOKRObjectiveAligningObjective,
    GetUserOKRListRespOKRObjectiveAlignedObjectiveOwner,
    GetUserOKRListRespOKRObjectiveAlignedObjective,
    GetUserOKRListRespOKRObjectiveKrProgressRate,
    GetUserOKRListRespOKRObjectiveKrKrWeight,
    GetUserOKRListRespOKRObjectiveKr,
    GetUserOKRListRespOKRObjectiveProgressRate,
    GetUserOKRListRespOKRObjectiveWeight,
    GetUserOKRListRespOKRObjective,
    GetUserOKRListRespOKR,
    GetUserOKRListResp,
    LarkSearchService,
    CreateSearchDataSourceReq,
    CreateSearchDataSourceRespDataSource,
    CreateSearchDataSourceResp,
    DeleteSearchDataSourceReq,
    DeleteSearchDataSourceResp,
    GetSearchDataSourceReq,
    GetSearchDataSourceRespDataSource,
    GetSearchDataSourceResp,
    CreateSearchDataSourceItemReqContent,
    CreateSearchDataSourceItemReqMetadata,
    CreateSearchDataSourceItemReqACL,
    CreateSearchDataSourceItemReq,
    CreateSearchDataSourceItemResp,
    DeleteSearchDataSourceItemReq,
    DeleteSearchDataSourceItemResp,
    GetSearchDataSourceItemReq,
    GetSearchDataSourceItemRespItemContent,
    GetSearchDataSourceItemRespItemMetadata,
    GetSearchDataSourceItemRespItemACL,
    GetSearchDataSourceItemRespItem,
    GetSearchDataSourceItemResp,
    GetSearchDataSourceListReq,
    GetSearchDataSourceListRespItem,
    GetSearchDataSourceListResp,
    UpdateSearchDataSourceReq,
    UpdateSearchDataSourceRespDataSource,
    UpdateSearchDataSourceResp,
    LarkTaskService,
    CreateTaskCollaboratorReqUserIDType,
    CreateTaskCollaboratorReq,
    CreateTaskCollaboratorRespCollaborator,
    CreateTaskCollaboratorResp,
    DeleteTaskCollaboratorReq,
    DeleteTaskCollaboratorResp,
    GetTaskCollaboratorListReqUserIDType,
    GetTaskCollaboratorListReq,
    GetTaskCollaboratorListRespItem,
    GetTaskCollaboratorListResp,
    CreateTaskFollowerReqUserIDType,
    CreateTaskFollowerReq,
    CreateTaskFollowerRespFollower,
    CreateTaskFollowerResp,
    DeleteTaskFollowerReq,
    DeleteTaskFollowerResp,
    GetTaskFollowerListReqUserIDType,
    GetTaskFollowerListReq,
    GetTaskFollowerListRespItem,
    GetTaskFollowerListResp,
    CreateTaskReminderReq,
    CreateTaskReminderRespReminder,
    CreateTaskReminderResp,
    DeleteTaskReminderReq,
    DeleteTaskReminderResp,
    GetTaskReminderListReq,
    GetTaskReminderListRespItem,
    GetTaskReminderListResp,
    GetTaskReqUserIDType,
    GetTaskReq,
    GetTaskRespTaskOriginHref,
    GetTaskRespTaskOrigin,
    GetTaskRespTaskDue,
    GetTaskRespTask,
    GetTaskResp,
    CompleteTaskReq,
    CompleteTaskResp,
    CreateTaskReqOriginHref,
    CreateTaskReqOrigin,
    CreateTaskReqDue,
    CreateTaskReqUserIDType,
    CreateTaskReq,
    CreateTaskRespTaskOriginHref,
    CreateTaskRespTaskOrigin,
    CreateTaskRespTaskDue,
    CreateTaskRespTask,
    CreateTaskResp,
    DeleteTaskReq,
    DeleteTaskResp,
    UncompleteTaskReq,
    UncompleteTaskResp,
    UpdateTaskReqTaskOriginHref,
    UpdateTaskReqTaskOrigin,
    UpdateTaskReqTaskDue,
    UpdateTaskReqTask,
    UpdateTaskReqUserIDType,
    UpdateTaskReq,
    UpdateTaskRespTaskOriginHref,
    UpdateTaskRespTaskOrigin,
    UpdateTaskRespTaskDue,
    UpdateTaskRespTask,
    UpdateTaskResp,
    LarkTenantService,
    GetTenantReq,
    GetTenantRespTenantAvatar,
    GetTenantRespTenant,
    GetTenantResp,
    LarkVCService,
    EndVCMeetingReq,
    EndVCMeetingResp,
    GetVCMeetingReqUserIDType,
    GetVCMeetingReq,
    GetVCMeetingRespMeetingAbility,
    GetVCMeetingRespMeetingParticipant,
    GetVCMeetingRespMeetingHostUser,
    GetVCMeetingRespMeeting,
    GetVCMeetingResp,
    InviteVCMeetingReqInvitee,
    InviteVCMeetingReqUserIDType,
    InviteVCMeetingReq,
    InviteVCMeetingRespInviteResult,
    InviteVCMeetingResp,
    GetVCMeetingRecordingReq,
    GetVCMeetingRecordingRespRecording,
    GetVCMeetingRecordingResp,
    SetVCPermissionMeetingRecordingReqPermissionObject,
    SetVCPermissionMeetingRecordingReqUserIDType,
    SetVCPermissionMeetingRecordingReq,
    SetVCPermissionMeetingRecordingResp,
    StartVCMeetingRecordingReq,
    StartVCMeetingRecordingResp,
    StopVCMeetingRecordingReq,
    StopVCMeetingRecordingResp,
    SetVCHostMeetingReqOldHostUser,
    SetVCHostMeetingReqHostUser,
    SetVCHostMeetingReqUserIDType,
    SetVCHostMeetingReq,
    SetVCHostMeetingRespHostUser,
    SetVCHostMeetingResp,
    GetVCDailyReportReq,
    GetVCDailyReportRespMeetingReportDailyReport,
    GetVCDailyReportRespMeetingReport,
    GetVCDailyReportResp,
    GetVCTopUserReportReq,
    GetVCTopUserReportRespTopUserReport,
    GetVCTopUserReportResp,
    ApplyVCReserveReqMeetingSettingsCallSettingCalleePstnSipInfo,
    ApplyVCReserveReqMeetingSettingsCallSettingCallee,
    ApplyVCReserveReqMeetingSettingsCallSetting,
    ApplyVCReserveReqMeetingSettingsActionPermissionPermissionChecker,
    ApplyVCReserveReqMeetingSettingsActionPermission,
    ApplyVCReserveReqMeetingSettings,
    ApplyVCReserveReqUserIDType,
    ApplyVCReserveReq,
    ApplyVCReserveRespReserve,
    ApplyVCReserveResp,
    DeleteVCReserveReq,
    DeleteVCReserveResp,
    GetVCReserveReq,
    GetVCReserveRespReserveMeetingSettingsCallSettingCalleePstnSipInfo,
    GetVCReserveRespReserveMeetingSettingsCallSettingCallee,
    GetVCReserveRespReserveMeetingSettingsCallSetting,
    GetVCReserveRespReserveMeetingSettingsActionPermissionPermissionChecker,
    GetVCReserveRespReserveMeetingSettingsActionPermission,
    GetVCReserveRespReserveMeetingSettings,
    GetVCReserveRespReserve,
    GetVCReserveResp,
    GetVCReserveActiveMeetingReq,
    GetVCReserveActiveMeetingRespMeetingAbility,
    GetVCReserveActiveMeetingRespMeetingParticipant,
    GetVCReserveActiveMeetingRespMeetingHostUser,
    GetVCReserveActiveMeetingRespMeeting,
    GetVCReserveActiveMeetingResp,
    UpdateVCReserveReqMeetingSettingsCallSettingCalleePstnSipInfo,
    UpdateVCReserveReqMeetingSettingsCallSettingCallee,
    UpdateVCReserveReqMeetingSettingsCallSetting,
    UpdateVCReserveReqMeetingSettingsActionPermissionPermissionChecker,
    UpdateVCReserveReqMeetingSettingsActionPermission,
    UpdateVCReserveReqMeetingSettings,
    UpdateVCReserveReqUserIDType,
    UpdateVCReserveReq,
    UpdateVCReserveRespReserve,
    UpdateVCReserveResp,
    GetVCRoomConfigReq,
    GetVCRoomConfigRespDigitalSignageMaterial,
    GetVCRoomConfigRespDigitalSignage,
    GetVCRoomConfigResp,
    SetVCRoomConfigReqRoomConfigDigitalSignageMaterial,
    SetVCRoomConfigReqRoomConfigDigitalSignage,
    SetVCRoomConfigReqRoomConfig,
    SetVCRoomConfigReq,
    SetVCRoomConfigResp,
    Lark,
    PyLarkError,
    Response,
    MethodOption,
    RawRequestReq,
    Request,
    DepartmentIDType,
    MessageContentPostItem,
    MessageContentPost,
    MessageContentPostAll,
    logger,
]
